@@ -1,24 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.63 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-#ifdef HAVE_PABLO
-#define PABLO_mask ID_hblocks_c
-#endif
-
-/* $Id: hblocks.c,v 1.63 1999/06/16 21:10:52 dwells Exp $ */
+/* $Id: hblocks.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*LINTLIBRARY */
 /* ------------------------------ hblocks.c -------------------------------
@@ -245,13 +242,6 @@ HLcreate(int32  file_id,
     uint8       local_ptbuf[16];
     int32       ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_HLcreate);
-#endif /* HAVE_PABLO */
-
-#ifdef QAK
-printf("%s: block_length=%ld, number_blocks=%ld\n",FUNC,block_length,number_blocks);
-#endif /* QAK */
     /* clear error stack and validate file record id */
     HEclear();
     file_rec = HAatom_object(file_id);
@@ -392,10 +382,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-  TRACE_OFF(PABLO_mask,ID_HLcreate);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 } /* HLcreate() */
 
@@ -458,13 +444,6 @@ HLconvert(int32 aid,
     int32       old_posn;       /* position in the access element */
     intn        ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_HLconvert);
-#endif /* HAVE_PABLO */
-
-#ifdef QAK
-printf("%s: block_length=%ld, number_blocks=%ld\n",FUNC,block_length,number_blocks);
-#endif /* QAK */
     /* clear error stack */
     HEclear();
 
@@ -596,10 +575,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-  TRACE_OFF(PABLO_mask,ID_HLconvert);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end HLconvert() */
 
@@ -1058,9 +1033,6 @@ HLPread(accrec_t *access_rec,
     int32       ret_value = SUCCEED;
 
     /* validate length */
-#ifdef QAK
-printf("%s: length=%ld, info->length=%d, access_rec->posn=%d\n",FUNC,(long)length,(int)info->length,(int)access_rec->posn);
-#endif /* QAK */
     if (length == 0)
         length = info->length - access_rec->posn;
     else
@@ -1070,31 +1042,19 @@ printf("%s: length=%ld, info->length=%d, access_rec->posn=%d\n",FUNC,(long)lengt
     if (access_rec->posn + length > info->length)
         length = info->length - access_rec->posn;
 
-#ifdef QAK
-printf("%s: check 0\n",FUNC);
-#endif /* QAK */
     /* search for linked block to start reading from */
     if (relative_posn < info->first_length)
       { /* first block */
-#ifdef QAK
-printf("%s: check 1\n",FUNC);
-#endif /* QAK */
           block_idx = 0;
           current_length = info->first_length;
       }
     else /* not first block? */
       {
-#ifdef QAK
-printf("%s: check 2\n",FUNC);
-#endif /* QAK */
           relative_posn -= info->first_length;
           block_idx = relative_posn / info->block_length + 1;
           relative_posn %= info->block_length;
           current_length = info->block_length;
       }
-#ifdef QAK
-printf("%s: check 3\n",FUNC);
-#endif /* QAK */
 
 /* calculate which block to start from? */
     {
@@ -1109,9 +1069,6 @@ printf("%s: check 3\n",FUNC);
     }
     block_idx %= info->number_blocks;
 
-#ifdef QAK
-printf("%s: check 4, block_idx=%d\n",FUNC,block_idx);
-#endif /* QAK */
     /* found the starting block, now read in the data */
     do
       {
@@ -1121,18 +1078,12 @@ printf("%s: check 4, block_idx=%d\n",FUNC,block_idx);
           /* read in the data in this block */
           if (remaining > length)
               remaining = length;
-#ifdef QAK
-printf("%s: check 5, remaining=%d\n",FUNC,remaining);
-#endif /* QAK */
           if (t_link->block_list[block_idx].ref != 0)
             {
                 int32       access_id;  /* access record id for this block */
                 block_t    *current_block =     /* record on the current block */
                     &(t_link->block_list[block_idx]);
 
-#ifdef QAK
-printf("%s: check 6, relative_posn=%d\n",FUNC,(int)relative_posn);
-#endif /* QAK */
                 access_id = Hstartread(access_rec->file_id, DFTAG_LINKED,
                                        current_block->ref);
                 if (access_id == (int32) FAIL
@@ -1146,16 +1097,10 @@ printf("%s: check 6, relative_posn=%d\n",FUNC,(int)relative_posn);
             }
           else
             {   /*if block is missing, fill this part of buffer with zero's */
-#ifdef QAK
-printf("%s: check 7\n",FUNC);
-#endif /* QAK */
                 HDmemset(data, 0, (size_t)remaining);
                 bytes_read += nbytes;
             }
 
-#ifdef QAK
-printf("%s: check 7.2\n",FUNC);
-#endif /* QAK */
           /* move variables for the next block */
           data += remaining;
           length -= remaining;
@@ -1171,9 +1116,6 @@ printf("%s: check 7.2\n",FUNC);
       }
     while (length > 0);     /* if still somemore to read in, repeat */
 
-#ifdef QAK
-printf("%s: check 8, bytes_read=%d\n",FUNC,bytes_read);
-#endif /* QAK */
     access_rec->posn += bytes_read;
     ret_value = bytes_read;
 
@@ -1212,8 +1154,7 @@ HLPwrite(accrec_t   *access_rec,
 {
     CONSTR(FUNC, "HLPwrite");   /* for HERROR */
     const uint8      *data = datap;
-    filerec_t  *file_rec =      /* file record */
-        HAatom_object(access_rec->file_id);
+    filerec_t  *file_rec;       /* file record */
     int32       dd_aid;         /* AID for writing the special info */
     uint16      data_tag, data_ref;  /* Tag/ref of the data in the file */
     linkinfo_t *info =          /* linked blocks information record */
@@ -1223,7 +1164,7 @@ HLPwrite(accrec_t   *access_rec,
     int32       relative_posn = /* relative position in linked block */
         access_rec->posn;
     int32       block_idx;      /* block table index of current block */
-    link_t     *prev_link = NULL;   /* ptr to block table before current block table.
+    link_t     *prev_link = NULL; /* ptr to block table before current block table.
                                        for groking the offset of
                                        current block table */
     int32       current_length; /* length of current block */
@@ -1232,14 +1173,9 @@ HLPwrite(accrec_t   *access_rec,
     uint8       local_ptbuf[4];
     int32       ret_value = SUCCEED;
 
-#ifdef QAK
-printf("%s: length=%d\n",FUNC,(int)length);
-printf("%s: info->first_length=%d\n",FUNC,(int)info->first_length);
-printf("%s: info->block_length=%d\n",FUNC,(int)info->block_length);
-printf("%s: info->number_blocks=%d\n",FUNC,(int)info->number_blocks);
-printf("%s: info->length=%d\n",FUNC,(int)info->length);
-printf("%s: access_rec->posn=%d\n",FUNC,(int)access_rec->posn);
-#endif /* QAK */
+    /* convert file id to file record */
+    file_rec = HAatom_object(access_rec->file_id);
+
     /* validate length and file records */
     if (length <= 0)
         HGOTO_ERROR(DFE_RANGE, FAIL);
@@ -1261,11 +1197,6 @@ printf("%s: access_rec->posn=%d\n",FUNC,(int)access_rec->posn);
           relative_posn %= info->block_length;
           current_length = info->block_length;
       }
-#ifdef QAK
-printf("%s: relative_posn=%d\n",FUNC,(int)relative_posn);
-printf("%s: current_length=%d\n",FUNC,(int)current_length);
-printf("%s: (a) block_idx=%d\n",FUNC,(int)block_idx);
-#endif /* QAK */
     {
         /* follow the links of block tables and create missing
            block tables along the way */
@@ -1273,9 +1204,6 @@ printf("%s: (a) block_idx=%d\n",FUNC,(int)block_idx);
 
         for (num_links = block_idx / info->number_blocks; num_links > 0; num_links--)
           {
-#ifdef QAK
-printf("%s: num_links=%d\n",FUNC,num_links);
-#endif /* QAK */
               if (!t_link->next)
                 {   /* create missing link (block table) */
                     t_link->nextref = Htagnewref(access_rec->file_id,DFTAG_LINKED);
@@ -1314,9 +1242,6 @@ printf("%s: num_links=%d\n",FUNC,num_links);
     }   /* end block statement(bad) */
 
     block_idx %= info->number_blocks;
-#ifdef QAK
-printf("%s: (b) block_idx=%d\n",FUNC,(int)block_idx);
-#endif /* QAK */
 
     /* start writing in that block */
     do
@@ -1330,9 +1255,6 @@ printf("%s: (b) block_idx=%d\n",FUNC,(int)block_idx);
           if (remaining > length)
               remaining = length;
 
-#ifdef QAK
-printf("%s: remaining=%d\n",FUNC,(int)remaining);
-#endif /* QAK */
           /* this block already exist, so just set up access to it */
           if (t_link->block_list[block_idx].ref != 0)
             {
@@ -1456,9 +1378,6 @@ printf("%s: remaining=%d\n",FUNC,(int)remaining);
     /* return SUCCEED; */
     /* if wrong # bytes written, FAIL has already been returned */
     ret_value = bytes_written;
-#ifdef QAK
-printf("%s: ret_value=%ld\n",FUNC,(long)bytes_written);
-#endif /* QAK */
 
 done:
   if(ret_value == FAIL)   
@@ -1660,10 +1579,12 @@ intn
 HLPendaccess(accrec_t * access_rec)
 {
     CONSTR(FUNC, "HLPendaccess");   /* for HERROR */
-    filerec_t  *file_rec =      /* file record */
-        HAatom_object(access_rec->file_id);
+    filerec_t  *file_rec;           /* file record */
     intn      ret_value = SUCCEED;
 
+    /* convert file id to file record */
+    file_rec = HAatom_object(access_rec->file_id);
+
     /* detach the special information record.
        If no more references to that, free the record */
     HLPcloseAID(access_rec);
@@ -1800,3 +1721,135 @@ done:
 
   return ret_value;
 }   /* HLPinfo */
+
+/*--------------------------------------------------------------------------
+NAME
+   HLsetblocksize -- set the block length of a linked-block element
+
+USAGE
+   intn HLsetblockinfo(
+   int32 aid		IN: access record id
+   int32 block_size	IN: length to be used for each linked-block 
+   int32 num_blocks	IN: number of blocks the element will have
+
+RETURNS
+   SUCCEED / FAIL
+
+DESCRIPTION
+   HLsetblocksize sets (accrec_t).block_size and (accrec_t).num_blocks
+   to block_size and num_blocks, respectively.  An error will occur, if
+   either of the parameters is a 0 or a negative number, that is not
+   -1, which is used to indicate that the respective field is not to be
+   changed.
+
+   In the library, this routine is used by:
+	VSsetblocksize 
+	VSsetnumblocks
+
+MODIFICATION
+   BMR - added in June 2001 to fix bug# 267
+
+--------------------------------------------------------------------------*/
+intn
+HLsetblockinfo(int32 aid,	/* access record id */
+              int32 block_size, /* length to be used for each linked-block */
+              int32 num_blocks) /* number of blocks the element will have */
+{
+    CONSTR(FUNC, "HLsetblockinfo");  	/* for HERROR */
+    accrec_t   *access_rec;               /* access record */
+    intn	ret_value = SUCCEED;
+
+    /* clear error stack */
+    HEclear();
+
+    /* validate aid */
+    if (HAatom_group(aid)!=AIDGROUP)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* block_size and num_blocks should be either -1, to keep the original 
+       values, or positive values to change the block size and/or the 
+       number of blocks */ 
+    if ((block_size <= 0 && block_size != -1) || 
+        (num_blocks <= 0 && num_blocks != -1))
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* get the access record */
+    if ((access_rec = HAatom_object(aid)) == NULL)        
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* change the linked-block size if requested */
+    if (block_size != -1)
+        access_rec->block_size = block_size;
+
+    /* change the number of linked-blocks if requested */
+    if (num_blocks != -1)
+        access_rec->num_blocks = num_blocks;
+
+done:
+    if(ret_value == FAIL)
+    { /* Error condition cleanup */
+
+    } /* end if */
+
+  /* Normal function cleanup */
+    return ret_value;
+}       /* end HLsetblockinfo */
+
+/*--------------------------------------------------------------------------
+NAME
+   HLgetblocksize -- get the block size and the number of blocks of a 
+		    linked-block element
+
+USAGE
+   intn HLgetblockinfo(aid, block_size, num_blocks)
+   int32  aid		IN: access record id
+   int32* block_size	OUT: the returned block size of each linked-block 
+   int32* num_blocks	OUT: the returned number of blocks of the element
+
+RETURNS
+   SUCCEED / FAIL
+
+DESCRIPTION
+   HLgetblocksize retrieves the values of (accrec_t).block_size and 
+   (accrec_t).num_blocks to block_size and num_blocks, respectively.  
+   A NULL can be passed in for an unwanted value.
+
+   In the library, this routine is used by:
+	VSgetblockinfo 
+
+MODIFICATION
+   BMR - added in June 2001 to fix bug# 267
+
+--------------------------------------------------------------------------*/
+intn
+HLgetblockinfo(int32 aid,	/* access record id */
+              int32* block_size, /* length being used for each linked-block */
+              int32* num_blocks) /* number of blocks the element will have */
+{
+    CONSTR(FUNC, "HLgetblockinfo");  /* for HERROR */
+    accrec_t   *access_rec;               /* access record */
+    intn	ret_value = SUCCEED;
+
+    /* clear error stack */
+    HEclear();
+
+    /* get the access record */
+    if ((access_rec = HAatom_object(aid)) == NULL)        
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* get the linked-block size and the number of linked-blocks if requested */
+    if (block_size != NULL)
+        *block_size = access_rec->block_size;
+    if (num_blocks != NULL)
+        *num_blocks = access_rec->num_blocks;
+
+done:
+    if(ret_value == FAIL)
+    { /* Error condition cleanup */
+
+    } /* end if */
+
+  /* Normal function cleanup */
+    return ret_value;
+}       /* end HLgetblockinfo */
+
