@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.57 $";
+static char RcsId[] = "@(#)$Revision: 5108 $";
 #endif
 
-/* $Id: hcomp.c,v 1.57 1999/03/27 19:44:01 epourmal Exp $ */
+/* $Id: hcomp.c 5108 2008-10-22 18:49:22Z bmribler $ */
 
 /*
 FILE
@@ -80,6 +81,10 @@ MODIFICATION HISTORY
 #define COMPRESS_MASTER
 #include "hdf.h"
 
+#ifdef H4_HAVE_LIBSZ
+#include "szlib.h"                                                                                 
+#endif 
+
 /* HDF compression includes */
 #include "hcompi.h"     /* Internal definitions for compression */
 
@@ -155,8 +160,15 @@ PRIVATE int32
 HCIinit_coder(int16 acc_mode, comp_coder_info_t * cinfo, comp_coder_t coder_type,
               comp_info * c_info)
 {
+    uint32 comp_info;
     CONSTR(FUNC, "HCIinit_coder");  /* for HERROR */
 
+    HCget_config_info(coder_type, &comp_info);
+    if ((comp_info & COMP_DECODER_ENABLED|COMP_ENCODER_ENABLED) == 0) {
+	/* coder not present?? */
+              HRETURN_ERROR(DFE_BADCODER, FAIL)
+    }
+
     switch (coder_type)
       {     /* determin the type of encoding */
           case COMP_CODE_NONE:      /* "none" (i.e. no) encoding */
@@ -188,29 +200,56 @@ HCIinit_coder(int16 acc_mode, comp_coder_info_t * cinfo, comp_coder_t coder_type
               if(c_info->skphuff.skp_size<1)
                   HRETURN_ERROR(DFE_BADCODER, FAIL)
 
-              cinfo->coder_type = COMP_CODE_SKPHUFF;    /* set the coding type */
-              cinfo->coder_funcs = cskphuff_funcs;  /* set the skipping huffman func. ptrs */
+              /* set the coding type and the skipping huffman func. ptrs */
+              cinfo->coder_type = COMP_CODE_SKPHUFF;
+              cinfo->coder_funcs = cskphuff_funcs;
 
               /* copy encoding info */
               cinfo->coder_info.skphuff_info.skip_size = c_info->skphuff.skp_size;
               break;
 
           case COMP_CODE_DEFLATE:   /* gzip 'deflate' encoding */
-   /* valid deflate levels are from 0 to 9, this error checking
-      caused the problem in HDF4r1.2 , fixed by Apu Kapadia    
-              if(c_info->deflate.level<1 || c_info->deflate.level>9)
-   */
+	      /* valid deflate levels are from 0 to 9, this error checking
+		 caused the problem in HDF4r1.2 , fixed by Apu Kapadia    
+	      if(c_info->deflate.level<1 || c_info->deflate.level>9)
+	      */
               if(c_info->deflate.level<0 || c_info->deflate.level>9)
                   HRETURN_ERROR(DFE_BADCODER, FAIL)
 
-              cinfo->coder_type = COMP_CODE_DEFLATE;    /* set the coding type */
-              cinfo->coder_funcs = cdeflate_funcs;  /* set the gzip 'deflate' func. ptrs */
+              /* set the coding type and the gzip 'deflate' func. ptrs */
+              cinfo->coder_type = COMP_CODE_DEFLATE;
+              cinfo->coder_funcs = cdeflate_funcs;
 
               /* copy encoding info */
               if(acc_mode&DFACC_WRITE)
                   cinfo->coder_info.deflate_info.deflate_level = c_info->deflate.level;
               break;
 
+           case COMP_CODE_SZIP:
+              /* set the coding type */
+              cinfo->coder_type = COMP_CODE_SZIP;
+
+	      /* when libsz presents, initialize other info - BMR, 08/25/2007
+		 (changed from eliminating this case completely) */
+	      /* completely removed the libsz limitation, we shouldn't need 
+		 szip library to initialize here - BMR, 10/21/2008 */
+
+              /* set the szip func. ptrs */
+              cinfo->coder_funcs = cszip_funcs;
+
+              /* copy encoding info */
+              cinfo->coder_info.szip_info.pixels = c_info->szip.pixels;
+              cinfo->coder_info.szip_info.bits_per_pixel = c_info->szip.bits_per_pixel;
+              cinfo->coder_info.szip_info.pixels_per_block = c_info->szip.pixels_per_block;
+              cinfo->coder_info.szip_info.pixels_per_scanline = c_info->szip.pixels_per_scanline;
+              cinfo->coder_info.szip_info.options_mask = c_info->szip.options_mask;
+              cinfo->coder_info.szip_info.buffer = NULL;
+              cinfo->coder_info.szip_info.buffer_size = 0;
+              cinfo->coder_info.szip_info.offset = 0;
+              cinfo->coder_info.szip_info.szip_state = SZIP_INIT;
+              cinfo->coder_info.szip_info.szip_dirty = SZIP_CLEAN;
+              break;
+
           default:
               HRETURN_ERROR(DFE_BADCODER, FAIL)
       }     /* end switch */
@@ -306,18 +345,22 @@ HCPquery_encode_header(comp_model_t model_type, model_info * m_info,
     /* add any additional information needed for coding type */
     switch (coder_type)
       {
-          case COMP_CODE_NBIT:      /* N-bit coding needs 16 bytes of info */
+          case COMP_CODE_NBIT:    /* N-bit coding needs 16 bytes of info */
               coder_len+=16;
               break;
 
-          case COMP_CODE_SKPHUFF:   /* Skipping Huffman coding needs 8 bytes of info */
+          case COMP_CODE_SKPHUFF: /* Skipping Huffman coding needs 8 bytes of info */
               coder_len+=8;
               break;
 
-          case COMP_CODE_DEFLATE:   /* Deflation coding stores deflation level */
+          case COMP_CODE_DEFLATE: /* Deflation coding stores deflation level */
               coder_len+=2;
               break;
 
+          case COMP_CODE_SZIP:   /* Szip coding ...? */
+	      coder_len += 14;
+	      break;
+
           default:      /* no additional information needed */
               break;
       }     /* end switch */
@@ -414,6 +457,14 @@ HCPencode_header(uint8 *p, comp_model_t model_type, model_info * m_info,
               UINT16ENCODE(p, (uint16) c_info->deflate.level);
               break;
 
+          case COMP_CODE_SZIP:  /* Szip coding ...? */
+              UINT32ENCODE(p, (uint32) c_info->szip.pixels);
+              UINT32ENCODE(p, (uint32) c_info->szip.pixels_per_scanline);
+              UINT32ENCODE(p, (uint32) (c_info->szip.options_mask | SZ_H4_REV_2));
+              *p++ = (uint8) c_info->szip.bits_per_pixel;
+              *p++ = (uint8) c_info->szip.pixels_per_block;
+              break;
+
           default:      /* no additional information needed */
               break;
       }     /* end switch */
@@ -523,6 +574,16 @@ HCPdecode_header(uint8 *p, comp_model_t *model_type, model_info * m_info,
               }     /* end case */
               break;
 
+          case COMP_CODE_SZIP:   /* Szip coding stores the following values*/
+	      {
+                  UINT32DECODE(p, c_info->szip.pixels);
+                  UINT32DECODE(p, c_info->szip.pixels_per_scanline);
+                  UINT32DECODE(p, c_info->szip.options_mask);
+                  c_info->szip.bits_per_pixel = *p++;
+                  c_info->szip.pixels_per_block = *p++;
+	      }
+              break;
+
           default:      /* no additional information needed */
               break;
       }     /* end switch */
@@ -608,6 +669,14 @@ HCIwrite_header(atom_t file_id, compinfo_t * info, uint16 special_tag, uint16 re
               UINT32ENCODE(p, (uint32) info->cinfo.coder_info.skphuff_info.skip_size);
               break;
 
+          case COMP_CODE_SZIP:
+              UINT32ENCODE(p, (uint32) c_info->szip.pixels);
+              UINT32ENCODE(p, (uint32) c_info->szip.pixels_per_scanline);
+              UINT32ENCODE(p, (uint32) c_info->szip.options_mask);
+              UINT8ENCODE(p, (uint8) c_info->szip.bits_per_pixel);
+              UINT8ENCODE(p, (uint8) c_info->szip.pixels_per_block);
+              break;
+
           default:      /* no additional information needed */
               break;
       }     /* end switch */
@@ -689,7 +758,7 @@ HCIread_header(accrec_t * access_rec,
         HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
 
     p = local_ptbuf+2;
-    UINT16DECODE(p, header_version);    /* get header length */
+    UINT16DECODE(p, header_version);    /* get compression version */
     INT32DECODE(p, info->length);   /* get _uncompressed_ data length */
     UINT16DECODE(p, info->comp_ref);    /* get ref # of comp. data */
 
@@ -827,7 +896,6 @@ HCcreate(int32 file_id, uint16 tag, uint16 ref, comp_model_t model_type,
     /* compress the old DD and get rid of it, if there was one */
     if (data_id != FAIL)
       {
-
           /* write the data through to the compression layer */
           if (HCPwrite(access_rec, data_len, buf) == FAIL)
               HGOTO_ERROR(DFE_MODEL, FAIL);
@@ -855,6 +923,214 @@ done:
     return ret_value; 
 }   /* end HCcreate() */
 
+/*--------------------------------------------------------------------------
+ NAME
+    HCPgetcompress -- Retrieves compression information of an element
+ USAGE
+    intn HCPgetcompress(aid, coder_type, c_info)
+    int32 aid;                  IN: access record ID
+    comp_coder_t* coder_type;   OUT: the type of compression
+    comp_info* c_info;          OUT: ptr to compression information
+                                structure for storing the retrieved info
+ RETURNS
+    SUCCEED/FAIL
+ DESCRIPTION
+    This routine retrieves the compression type and the compression
+    information of the element, identified by 'aid'.  The routine is 
+    used by GRgetcompress and SDgetcompress at this time.
+
+ GLOBAL VARIABLES
+ COMMENTS, BUGS, ASSUMPTIONS
+ EXAMPLES
+ REVISION LOG
+    July 2001: Added to fix bug #307 - BMR
+    Dec. 2004: Changed name to HCPgetcompress, to be consistent with other
+               practice.  REM
+--------------------------------------------------------------------------*/
+intn
+HCPgetcompress(int32 file_id,
+              uint16 data_tag, uint16 data_ref,
+              comp_coder_t* comp_type,  /* OUT: compression type */
+              comp_info* c_info)        /* OUT: retrieved compression info */
+{
+    CONSTR(FUNC, "HCPgetcompress");   /* for HGOTO_ERROR */
+    int32   aid=0, status;
+    accrec_t*    access_rec=NULL;/* access element record */
+    compinfo_t*  info=NULL;  /* compressed element information */
+    model_info  m_info;         /* modeling information - dummy */
+    int32       ret_value=SUCCEED;
+
+    /* clear error stack */
+    HEclear();
+
+    /* start read access on the access record of the data element, which
+       is being inquired for its compression information */
+    aid = Hstartread(file_id, data_tag, data_ref);
+
+    /* get the access_rec pointer */
+    access_rec = HAatom_object(aid);
+    if (access_rec == NULL) HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* if the element is compressed, get the compression info as requested*/
+    if (access_rec->special == SPECIAL_COMP)
+    {
+        info = (compinfo_t *) access_rec->special_info;
+        if (info == NULL) HGOTO_ERROR(DFE_COMPINFO, FAIL);
+
+        status = HCIread_header(access_rec, info, c_info, &m_info);
+        if (status == FAIL) HGOTO_ERROR(DFE_COMPINFO, FAIL);
+
+        /* get the compression type */
+        *comp_type = info->cinfo.coder_type;
+
+    }  /* end if element is compressed */
+
+    /* if the element is chunked, call HMCgetcompress to get the 
+	compression info as appropriate */
+    else if (access_rec->special == SPECIAL_CHUNKED)
+    {
+	status = HMCgetcompress(access_rec, comp_type, c_info);
+        if (status == FAIL) HGOTO_ERROR(DFE_COMPINFO, FAIL);
+    }
+
+    /* flag the error when attempting to get compression info on a
+       non-compressed element */
+    else 
+    /* EIP 9/16/03  Fail but return compression type COMP_CODE_NONE
+       instead of junk in this case.
+    */
+     {
+        /*Mac OSX screams here (comp_coder_t)*comp_type = COMP_CODE_NONE; */
+        *comp_type = COMP_CODE_NONE; 
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+     }
+    /* end access to the aid appropriately */
+    if (Hendaccess(aid)== FAIL)
+        HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
+
+done:
+  if(ret_value == FAIL)
+    { /* Error condition cleanup */
+       /* end access to the aid if it's been accessed */
+        if (aid != 0)
+            if (Hendaccess(aid)== FAIL)
+                HERROR(DFE_CANTENDACCESS);
+    } /* end if */
+
+  /* Normal function cleanup */
+  return ret_value;
+} /* HCPgetcompress */
+
+
+/*--------------------------------------------------------------------------
+ NAME
+    HCPgetcompinfo -- Retrieves compression information of an element
+ USAGE
+    intn HCPgetcompinfo(aid, coder_type, c_info)
+    int32 aid;                  IN: access record ID
+    comp_coder_t* coder_type;   OUT: the type of compression
+    comp_info* c_info;          OUT: ptr to compression information
+                                structure for storing the retrieved info
+ RETURNS
+    SUCCEED/FAIL
+ DESCRIPTION
+    This routine retrieves the compression type and the compression
+    information of the element, identified by 'aid'.  The routine is 
+    used by GRgetcompinfo and SDgetcompinfo at this time.
+
+ GLOBAL VARIABLES
+ COMMENTS, BUGS, ASSUMPTIONS
+ EXAMPLES
+ REVISION LOG
+    July 2001: Added to fix bug #307 - BMR
+    Dec. 2004: Changed name to HCPgetcompress, to be consistent with other
+               practice.  REM
+    Apr. 2005:	HCPgetcompinfo was added to fix bugzilla #130 and may replace 
+		HCPgetcompress in the future because HCPgetcompress did not 
+		behave correctly.  The revision logs above are carried over 
+		from HCPgetcompress for the records.
+--------------------------------------------------------------------------*/
+intn
+HCPgetcompinfo(int32 file_id,
+              uint16 data_tag, uint16 data_ref,
+              comp_coder_t* comp_type,  /* OUT: compression type */
+              comp_info* c_info)        /* OUT: retrieved compression info */
+{
+    CONSTR(FUNC, "HCPgetcompinfo");	/* for HGOTO_ERROR */
+    int32   aid=0, status;
+    accrec_t*    access_rec=NULL;	/* access element record */
+    compinfo_t*  info=NULL;		/* compressed element information */
+    model_info  m_info;			/* modeling information - dummy */
+    intn       ret_value=SUCCEED;
+
+    /* clear error stack */
+    HEclear();
+
+    /* start read access on the access record of the data element, which
+       is being inquired for its compression information */
+    aid = Hstartread(file_id, data_tag, data_ref);
+
+    /* get the access_rec pointer */
+    access_rec = HAatom_object(aid);
+    if (access_rec == NULL) HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* if the element is compressed, get the compression info as requested */
+    if (access_rec->special == SPECIAL_COMP)
+    {
+        info = (compinfo_t *) access_rec->special_info;
+        if (info == NULL) HGOTO_ERROR(DFE_COMPINFO, FAIL);
+
+        status = HCIread_header(access_rec, info, c_info, &m_info);
+        if (status == FAIL) HGOTO_ERROR(DFE_COMPINFO, FAIL);
+
+        /* get the compression type */
+        *comp_type = info->cinfo.coder_type;
+
+    }  /* end if element is compressed */
+
+    /* if the element is chunked, call HMCgetcompress to get the 
+	compression info as appropriate */
+    else if (access_rec->special == SPECIAL_CHUNKED)
+    {
+	status = HMCgetcompress(access_rec, comp_type, c_info);
+        if (status == FAIL) HGOTO_ERROR(DFE_COMPINFO, FAIL);
+    }
+
+    /* return COMP_CODE_NONE for a non-compressed element */
+    /* Note: SPECIAL_COMPRAS may need special handling */
+    else if (access_rec->special == SPECIAL_LINKED ||
+             access_rec->special == SPECIAL_EXT ||
+             access_rec->special == SPECIAL_VLINKED ||
+             access_rec->special == SPECIAL_BUFFERED ||
+             access_rec->special == SPECIAL_COMPRAS ||
+             access_rec->special == 0)
+    {
+        *comp_type = COMP_CODE_NONE;
+    }
+
+    /* flag the error when access_rec->special is not something valid */
+    else 
+    {
+	*comp_type = COMP_CODE_INVALID; 
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+    }
+    /* end access to the aid appropriately */
+    if (Hendaccess(aid)== FAIL)
+        HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
+
+done:
+  if(ret_value == FAIL)
+    { /* Error condition cleanup */
+       /* end access to the aid if it's been accessed */
+        if (aid != 0)
+            if (Hendaccess(aid)== FAIL)
+                HERROR(DFE_CANTENDACCESS);
+    } /* end if */
+
+  /* Normal function cleanup */
+  return ret_value;
+} /* HCPgetcompinfo */
+
 /*--------------------------------------------------------------------------
  NAME
     HCIstaccess -- Start accessing a compressed data element.
@@ -944,9 +1220,6 @@ HCPstread(accrec_t * access_rec)
     compinfo_t *info;           /* information on the special element */
     int32       ret_value;      /* AID to return */
 
-#ifdef QAK
-printf("%s: check 1.0\n",FUNC);
-#endif /* QAK */
     if ((ret_value = HCIstaccess(access_rec, DFACC_READ)) == FAIL)
         HGOTO_ERROR(DFE_DENIED, FAIL);
     info = (compinfo_t *) access_rec->special_info;
@@ -986,9 +1259,6 @@ HCPstwrite(accrec_t * access_rec)
     compinfo_t *info;               /* information on the special element */
     int32       ret_value;          /* AID to return */
 
-#ifdef QAK
-printf("%s: check 1.0\n",FUNC);
-#endif /* QAK */
     if ((ret_value = HCIstaccess(access_rec, DFACC_WRITE)) == FAIL)
         HGOTO_ERROR(DFE_DENIED, FAIL);
     info = (compinfo_t *) access_rec->special_info;
@@ -1038,18 +1308,12 @@ HCPseek(accrec_t * access_rec, int32 offset, intn origin)
     if (offset < 0)
         HGOTO_ERROR(DFE_RANGE, FAIL);
 
-#ifdef QAK
-printf("%s: check 1.0\n",FUNC);
-#endif /* QAK */
     info = (compinfo_t *) access_rec->special_info;
     if ((ret_value = (*(info->minfo.model_funcs.seek)) (access_rec, offset, origin)) == FAIL)
         HGOTO_ERROR(DFE_MODEL, FAIL);
 
     /* set the offset */
     access_rec->posn = offset;
-#ifdef QAK
-printf("%s: check 1.0: access_rec->posn=%d, info->length=%d\n",FUNC,(int)access_rec->posn,(int)info->length);
-#endif /* QAK */
 
 done:
     if(ret_value == FAIL)   
@@ -1092,18 +1356,12 @@ HCPread(accrec_t * access_rec, int32 length, void * data)
 
     info = (compinfo_t *) access_rec->special_info;
 
-#ifdef QAK
-printf("%s: length=%d, data=%p\n",FUNC,(int)length,data);
-#endif /* QAK */
     /* adjust length if it falls off the end of the element */
     if (length == 0)
         length = info->length - access_rec->posn;
     else if (length < 0 || access_rec->posn + length > info->length)
         HGOTO_ERROR(DFE_RANGE, FAIL);
 
-#ifdef QAK
-printf("%s: check 1.0: access_rec->posn=%d, info->length=%d\n",FUNC,(int)access_rec->posn,(int)info->length);
-#endif /* QAK */
     if ((*(info->minfo.model_funcs.read))(access_rec, length, data) == FAIL)
         HGOTO_ERROR(DFE_MODEL, FAIL);
 
@@ -1147,26 +1405,22 @@ HCPwrite(accrec_t * access_rec, int32 length, const void * data)
     compinfo_t *info;           /* information on the special element */
     uint8       local_ptbuf[4];
     uint8       *p = local_ptbuf;  /* temp buffer ptr */
-    filerec_t   *file_rec =     /* file record */
-                           HAatom_object(access_rec->file_id);  
+    filerec_t  *file_rec;           /* file record */
     int32       ret_value;
 
+    /* convert file id to file record */
+    file_rec = HAatom_object(access_rec->file_id);
+
     /* validate length */
     if (length < 0)
         HRETURN_ERROR(DFE_RANGE, FAIL);
 
-#ifdef QAK
-printf("%s: length=%d\n",FUNC,(int)length);
-#endif /* QAK */
     info = (compinfo_t *) access_rec->special_info;
     if ((*(info->minfo.model_funcs.write)) (access_rec, length, data) == FAIL)
         HGOTO_ERROR(DFE_MODEL, FAIL);
 
     /* update access record, and information about special element */
     access_rec->posn += length;
-#ifdef QAK
-printf("%s: check 1.0: access_rec->posn=%d, info->length=%d\n",FUNC,(int)access_rec->posn,(int)info->length);
-#endif /* QAK */
     if (access_rec->posn > info->length)
       {
           int32       data_off;		/* offset of the data we are checking */
@@ -1184,9 +1438,6 @@ printf("%s: check 1.0: access_rec->posn=%d, info->length=%d\n",FUNC,(int)access_
           if (HP_write(file_rec, local_ptbuf, 4) == FAIL)     
               HGOTO_ERROR(DFE_WRITEERROR, FAIL);
       }     /* end if */
-#ifdef QAK
-printf("%s: check 2.0: access_rec->posn=%d, info->length=%d\n",FUNC,(int)access_rec->posn,(int)info->length);
-#endif /* QAK */
 
     ret_value=length;  /* return length of bytes written */
 
@@ -1281,9 +1532,12 @@ intn
 HCPendaccess(accrec_t * access_rec)
 {
     CONSTR(FUNC, "HCPendaccess");   /* for HERROR */
-    filerec_t  *file_rec = HAatom_object(access_rec->file_id);    /* file record */
+    filerec_t  *file_rec;           /* file record */
     intn      ret_value = SUCCEED;
 
+    /* convert file id to file record */
+    file_rec = HAatom_object(access_rec->file_id);
+
     /* validate file record */
     if (BADFREC(file_rec))
         HGOTO_ERROR(DFE_INTERNAL, FAIL);
@@ -1385,3 +1639,359 @@ HCPinfo(accrec_t * access_rec, sp_info_block_t * info_block)
 
     return SUCCEED;
 }   /* HCPinfo */
+
+/* ------------------------------- HCPgetinfo ----------------------------- */
+/*
+NAME
+   HCget_config_info -- return info about configuration of a compression method
+
+USAGE
+     intn HCget_config_info( comp_coder_t coder_type,  
+	uint32* compression_config_info)
+        comp_coder_t coder_type;  IN: the compression type queried  
+	compression_config_info;  OUT: flags to indiat compression status
+               
+                0 -- not enabled
+		COMP_DECODER_ENABLED - decoding enabled
+                COMP_ENCODER_ENABLED - encoding enabled
+
+RETURNS
+   SUCCEED / FAIL
+DESCRIPTION
+   Return information about the given compresion method. 
+
+   Currently, reports if encoding and/or decoding are available. SZIP
+   is the only method that varies in the current versions.
+
+
+---------------------------------------------------------------------------*/
+intn
+HCget_config_info( comp_coder_t coder_type,  /* IN: compression type */
+		uint32* compression_config_info)
+{
+    CONSTR(FUNC, "HCget_config_info");
+
+    *compression_config_info = 0;
+    switch (coder_type)
+      {     
+          case COMP_CODE_NONE:      /* "none" (i.e. no) encoding */
+		*compression_config_info = 0;
+          case COMP_CODE_RLE:   /* Run-length encoding */
+          case COMP_CODE_NBIT:      /* N-bit encoding */
+          case COMP_CODE_SKPHUFF:   /* Skipping Huffman encoding */
+		*compression_config_info = COMP_DECODER_ENABLED|COMP_ENCODER_ENABLED;
+              break;
+
+          case COMP_CODE_JPEG:  /* jpeg may be optional */
+		*compression_config_info = COMP_DECODER_ENABLED|COMP_ENCODER_ENABLED;
+              break;
+          case COMP_CODE_DEFLATE:   /* gzip 'deflate' encoding, maybe optional */
+		*compression_config_info = COMP_DECODER_ENABLED|COMP_ENCODER_ENABLED;
+              break;
+
+           case COMP_CODE_SZIP:
+#ifdef H4_HAVE_LIBSZ
+	      if (SZ_encoder_enabled()) {
+		*compression_config_info = COMP_DECODER_ENABLED|COMP_ENCODER_ENABLED;
+		} else {
+		*compression_config_info = COMP_DECODER_ENABLED;
+		}
+#else
+		*compression_config_info = 0;
+#endif /* H4_HAVE_LIBSZ */
+              break;
+          default:
+		*compression_config_info = 0;
+              HRETURN_ERROR(DFE_BADCODER, FAIL)
+	}
+    return SUCCEED;
+}
+
+/*--------------------------------------------------------------------------
+ NAME
+    HCPgetcomptype -- Retrieves compression type of an element
+ USAGE
+    intn HCPgetcomptype(aid, coder_type)
+    int32 aid;                  IN: access record ID
+    comp_coder_t* coder_type;   OUT: the type of compression
+ RETURNS
+    SUCCEED/FAIL
+ DESCRIPTION
+    This routine retrieves the compression type of the element, identified 
+    by 'aid'.  It is very similar to HCPgetcompinfo except that it only
+    retrieves the compression type and not the compression information.  The 
+    routine is used by GRgetcomptype and SDgetcomptype.
+
+ GLOBAL VARIABLES
+ COMMENTS, BUGS, ASSUMPTIONS
+ EXAMPLES
+ REVISION LOG
+    Dec. 2007: Added so that applications can get the compression method only.
+		The immediate intention is to avoid the need for external 
+		libraries to be present when only compression type is desired
+		and not compression information. -BMR
+--------------------------------------------------------------------------*/
+intn
+HCPgetcomptype(int32 file_id,
+              uint16 data_tag, uint16 data_ref, /* IN: tag/ref of element */
+              comp_coder_t* comp_type)  /* OUT: compression type */
+{
+    CONSTR(FUNC, "HCPgetcomptype");	/* for HGOTO_ERROR */
+    uint16      ctag, cref;	/* tag/ref for the special info header object */
+    int32       data_id;	/* temporary AID for header info */
+    int32	temp_aid;	/* temporary AID for header info */
+    int32	data_len;	/* offset of the data we are checking */
+    uint8      *p;		/* pointers to the temporary buffer */
+    uint8      *local_ptbuf;	/* temporary buffer */
+    uint16	sp_tag;		/* special tag */
+    uint16	c_type;		/* compression type */
+    filerec_t  *file_rec;	/* file record */
+    intn        ret_value=SUCCEED;
+
+    /* clear error stack */
+    HEclear();
+
+    /* convert file id to file rec and check for validity */
+    file_rec = HAatom_object(file_id);
+    if (BADFREC(file_rec))
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* get access element from dataset's tag/ref */
+    if ((data_id=HTPselect(file_rec, data_tag, data_ref))!=FAIL)
+    {
+	/* get the info for the dataset */
+	if(HTPinquire(data_id,&ctag,&cref,NULL,&data_len)==FAIL)
+	    HGOTO_ERROR(DFE_INTERNAL, FAIL);
+
+	/* if element is not special, return COMP_CODE_NONE */
+	if (!SPECIALTAG(ctag))	
+	{
+	    *comp_type = COMP_CODE_NONE;
+	    HGOTO_DONE(SUCCEED);
+	}
+
+	/* element is special, proceed with reading special info header */
+	if((local_ptbuf=(uint8 *)HDmalloc(data_len))==NULL)
+	    HGOTO_ERROR(DFE_NOSPACE, FAIL);
+
+	/* Get the special info header */
+	if ((temp_aid=Hstartaccess(file_id,MKSPECIALTAG(ctag),cref,DFACC_READ)) == FAIL)
+	    HGOTO_ERROR(DFE_BADAID, FAIL);
+	if (Hread(temp_aid,2,local_ptbuf) == FAIL)
+	    HGOTO_ERROR(DFE_READERROR, FAIL);
+
+	/* Get special tag */
+	p = local_ptbuf;
+	INT16DECODE(p, sp_tag);
+
+	/* If it is a compressed element, move forward until compression
+	   coder and get it */
+	switch (sp_tag)
+	{
+	  case SPECIAL_COMP:
+	      if (Hread(temp_aid,0,local_ptbuf) == FAIL)
+		  HGOTO_ERROR(DFE_READERROR, FAIL);
+
+	      /* Skip comp version, length, ref#, and model type */
+	      p = local_ptbuf + 2 + 4 + 2 + 2;
+	      UINT16DECODE(p, c_type);     /* get encoding type */
+	      *comp_type=(comp_coder_t)c_type;
+	      break;
+
+	  /* If element is chunked, hand over to the chunk interface to check 
+	     if it is compressed and get the type */
+	  case SPECIAL_CHUNKED:
+	      if (HMCgetcomptype(temp_aid, comp_type)==FAIL)
+		  HGOTO_ERROR(DFE_INTERNAL, FAIL);
+	      break;
+
+	  /* return COMP_CODE_NONE for a non-compressed element */
+	  /* Developer's Note: SPECIAL_COMPRAS may need special handling */
+	  case SPECIAL_LINKED:
+	  case SPECIAL_EXT:
+	  case SPECIAL_VLINKED:
+	  case SPECIAL_BUFFERED:
+	  case SPECIAL_COMPRAS:
+	  case 0:
+	      *comp_type = COMP_CODE_NONE;
+	      break;
+
+	  /* flag the error when special tag is not something valid */
+	  default:
+	      *comp_type = COMP_CODE_INVALID;
+	      HGOTO_ERROR(DFE_ARGS, FAIL);
+	}
+
+	/* release allocated memory */
+	if (local_ptbuf != NULL)
+	    HDfree(local_ptbuf);
+
+	if(Hendaccess(temp_aid)==FAIL)
+	    HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
+
+	/* end access to the aid appropriately */
+	if (HTPendaccess(data_id)== FAIL)
+	    HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
+    }
+
+done:
+  if(ret_value == FAIL)
+    { /* Error condition cleanup */
+       /* end access to the aid's if they've been accessed */
+        if (temp_aid != 0)
+            if (Hendaccess(temp_aid)== FAIL)
+                HERROR(DFE_CANTENDACCESS);
+        if (data_id != 0)
+            if (Hendaccess(data_id)== FAIL)
+                HERROR(DFE_CANTENDACCESS);
+	if (local_ptbuf != NULL)
+	    HDfree(local_ptbuf);
+    } /* end if */
+
+  /* Normal function cleanup */
+  return ret_value;
+} /* HCPgetcomptype */
+
+/*--------------------------------------------------------------------------
+ NAME
+    HCPgetdatasize -- Retrieves the sizes of original and compressed data.
+ USAGE
+    int32 HCPgetdatasize(file_id, data_tag, data_ref, comp_size, orig_size)	
+		int32 file_id;		IN: file id
+		uint16 data_tag;	IN: tag of the element
+		uint16 data_ref;	IN: ref of element
+		int32* comp_size;	OUT: size of compressed data
+		int32* orig_size;	OUT: size of non-compressed data
+ RETURNS
+    SUCCEED/FAIL
+ DESCRIPTION
+    This routine gets access to the element pointed to by the dataset's 
+    tag/ref pair, then proceeds as followed:
+    - If the element is not special, HCPgetdatasize will use Hlength to get 
+      the length of the data then return.
+    - If the element is compressed, HCPgetdatasize will read the element's
+      special header and decode it for the uncompressed data length and the 
+      compressed data ref#, then use Hlength to get the length of the 
+      compressed data.
+    - If the element is chunked, HCPgetdatasize will let the chunking layer
+      retrieve the sizes (HMCgetdatasize.)
+ GLOBAL VARIABLES
+ COMMENTS, BUGS, ASSUMPTIONS
+ EXAMPLES
+ REVISION LOG
+--------------------------------------------------------------------------*/
+intn
+HCPgetdatasize(int32 file_id,
+              uint16 data_tag, uint16 data_ref, /* IN: tag/ref of element */
+              int32* comp_size,	/* OUT  - size of compressed data */
+              int32* orig_size)	/* OUT  - size of non-compressed data */
+{
+    CONSTR(FUNC, "HCPgetdatasize");	/* for HGOTO_ERROR */
+    int32	data_len;	/* offset of the data we are checking */
+    uint8      *local_ptbuf=NULL, *p;
+    uint16	sp_tag;		/* special tag */
+    uint16 comp_ref = 0;
+    uint16	drec_tag, drec_ref;	/* description record tag/ref */
+    int32	drec_aid;	/* description record access id */
+    atom_t      data_id = FAIL;	/* dd ID of existing regular element */
+    int32 len = 0;
+    filerec_t  *file_rec;	/* file record */
+    intn        ret_value=SUCCEED;
+
+    /* clear error stack */
+    HEclear();
+
+    /* convert file id to file rec and check for validity */
+    file_rec = HAatom_object(file_id);
+    if (BADFREC(file_rec))
+	HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* get access element from dataset's tag/ref */
+    if ((data_id=HTPselect(file_rec, data_tag, data_ref))!=FAIL)
+    {
+	/* if the element is not special, that means dataset's tag/ref 
+	   specifies the actual data that was written to the dataset, so
+	   we don't need to check further */
+	if (HTPis_special(data_id)==FALSE)
+        {
+	    if ((len = Hlength(file_id, data_tag, data_ref)) == FAIL)
+		HGOTO_ERROR(DFE_BADLEN, FAIL);
+	    *orig_size = *comp_size = len;
+        }
+
+	/* if the element is special, get the special info header and decode
+	   for the uncompressed data length and the compressed data ref#, which
+	   will be used with DFTAG_COMPRESSED to get the compressed data len */
+	else
+	{
+	    /* get the info for the dataset (description record) */
+	    if (HTPinquire(data_id,&drec_tag,&drec_ref,NULL,&data_len) == FAIL)
+		HGOTO_ERROR(DFE_INTERNAL, FAIL);
+	    if ((local_ptbuf = (uint8 *)HDmalloc(data_len)) == NULL)
+		HGOTO_ERROR(DFE_NOSPACE, FAIL);
+
+	    /* get the special info header */
+	    drec_aid = Hstartaccess(file_id,MKSPECIALTAG(drec_tag),drec_ref,DFACC_READ);
+	    if (drec_aid == FAIL)
+		HGOTO_ERROR(DFE_BADAID, FAIL);
+	    if (Hread(drec_aid,0,local_ptbuf) == FAIL)
+		HGOTO_ERROR(DFE_READERROR, FAIL);
+	    if(Hendaccess(drec_aid)==FAIL)
+		HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
+
+	    /* get special tag */
+	    p = local_ptbuf;
+	    INT16DECODE(p, sp_tag);
+
+	    /* verify that it is a compressed element, then get the data len */
+	    if (sp_tag == SPECIAL_COMP)
+	    {
+		/* skip 2byte header_version */
+		p = p + 2;
+		INT32DECODE(p, len);	/* get _uncompressed_ data length */
+		*orig_size = len;	/* set original data size */
+
+		/* if no data written, set compressed data size too */
+		if (len == 0)
+		{
+		    *comp_size = len;
+		}
+		/* Data has been written, get compressed data size */
+		else
+		{
+		    /* get ref# of compressed data */
+		    UINT16DECODE(p, comp_ref);
+		    if ((len = Hlength(file_id, DFTAG_COMPRESSED, comp_ref)) == FAIL)
+			HGOTO_ERROR(DFE_BADLEN, FAIL);
+		    *comp_size = len;	/* set compressed data size */
+		} /* data written */
+	    } /* element is compressed */
+
+	    /* if it is a chunked element, hand the task over to the chunking
+		layer. */
+	    else if (sp_tag == SPECIAL_CHUNKED)
+	    {
+	     if (HMCgetdatasize(file_id, p, comp_size, orig_size)==FAIL)
+		  HGOTO_ERROR(DFE_INTERNAL, FAIL);
+	    }
+	} /* else, data_id is special */
+
+	/* end access to the aid */
+	if (HTPendaccess(data_id) == FAIL)
+	    HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
+    }  /* end if data_id != FAIL */
+
+    else /* HTPselect failed */
+        HGOTO_ERROR(DFE_CANTACCESS, FAIL);
+ 
+done:
+    if(ret_value == FAIL)   
+    { /* Error condition cleanup */
+    } /* end if */
+
+    /* Normal function cleanup */
+    if (local_ptbuf != NULL) 
+	HDfree(local_ptbuf);
+
+    return ret_value;
+} /* HCPgetdatasize */
