@@ -1,16 +1,17 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: hdfi.h,v 1.139 1999/04/16 18:22:21 ptlu Exp $ */
+/* $Id: hdfi.h 5007 2007-12-19 20:16:09Z ymuqun $ */
 
 #ifndef HDFI_H
 #define HDFI_H
@@ -47,7 +48,8 @@
 /*      8 - Cray IEEE                                                       */
 /*          (i.e. Big-Endian, all 64-bit architecture w/IEEE Floats)        */
 /*--------------------------------------------------------------------------*/
-#define     DFMT_SUN            0x1111
+#define     DFMT_SUN            0x1111 
+#define     DFMT_SUN_INTEL      0x4441
 #define     DFMT_ALLIANT        0x1111
 #define     DFMT_IRIX           0x1111
 #define     DFMT_APOLLO         0x1111
@@ -61,6 +63,8 @@
 #define     DFMT_VAX            0x2221
 #define     DFMT_MIPSEL         0x4441
 #define     DFMT_PC             0x4441
+#define     DFMT_APPLE          0x1111
+#define     DFMT_APPLE_INTEL    0x4441
 #define     DFMT_MAC            0x1111
 #define     DFMT_SUN386         0x4441
 #define     DFMT_NEXT           0x1111
@@ -69,6 +73,9 @@
 #define     DFMT_VP             0x6611
 #define     DFMT_I860           0x4441
 #define     DFMT_CRAYMPP        0x1171
+#define     DFMT_IA64           0x4441
+#define     DFMT_LINUX64        0x4441
+#define     DFMT_POWERPC64      0x1111
 
 /* I/O library constants */
 #define UNIXUNBUFIO 1
@@ -79,10 +86,6 @@
 #define PAGEBUFIO   6    /* page buffering - fmpool */
 #define WINNTIO     7    /* 32-bit Windows File I/O (deprecated, WinNT now uses UNIXBUFIO) */ 
 
-/* IBM RS6000 AIX hack */
-#if defined(IBM6000) || defined(_AIX)
-#define _POSIX_SOURCE
-#endif 
 
 /* Standard header files needed all the time */
 #include <stdio.h>
@@ -90,33 +93,22 @@
 #include <limits.h>
 #include <string.h>
 
-/* PABLO support files */
-#ifdef HAVE_PABLO
-#define IOTRACE
-#include "HDFIOTrace.h"
-#endif  /* HAVE_PABLO */
-
 /**
  * Provide the macros to adapt the HDF public functions to
  * dll entry points.
  * In addition it provides error lines if the configuration is incorrect.
  **/
 
-#ifdef WIN32
+#ifdef _WIN32
 /**
- * Under WIN32 we have single threaded static libraries, or
+ * Under _WIN32 we have single threaded static libraries, or
  * mutli-threaded DLLs using the multithreaded runtime DLLs.
  **/
 #	if defined(_MT) &&	defined(_DLL) &&!defined(_HDFDLL_)
-/*		If the user really ment to use _HDFDLL_, but he forgot, just define it. */
+/*		If the user really meant to use _HDFDLL_, but he forgot, just define it. */
 #		define _HDFDLL_
 #	endif
 
-#	if defined(_MT) && !defined(_HDFDLL_)
-#		error To use the HDF libraries from a multithreaded project, you must use the HDF DLLs
-#		error Use the Mutlithreaded DLL runtime libraries (prefered), or define the macro "_HDFDLL_"
-#	endif
-
 #	if !defined(_MT) && defined(_HDFDLL_)
 #		error To use the HDF libraries from a single-threaded project, you must use static HDF libraries
 #		error Undefine the macro "_HDFDLL_"
@@ -136,13 +128,22 @@
 #		else
 #			define HDFLIBAPI __declspec(dllexport) extern
 #		endif 
+
+#		if defined(_HDFLIB_C_STUB_EXPORTS) || defined(_MFHDFLIB_C_STUB_EXPORTS) || defined(_DLLLIBTEST_FCSTUB_EXPORTS)
+#			define HDFFCLIBAPI __declspec(dllexport) extern
+#		else
+#			define HDFFCLIBAPI __declspec(dllimport) extern
+#		endif 
+
 #	else
 #		define HDFPUBLIC
 #		define HDFLIBAPI extern
+#		define HDFFCLIBAPI extern
 #	endif
-#else	/* !defined( WIN32 ) */
+#else	/* !defined( _WIN32 ) */
 #	define HDFPUBLIC
 #	define HDFLIBAPI extern
+#   define HDFFCLIBAPI extern
 #endif
 
 
@@ -182,7 +183,11 @@ Please check your Makefile.
 #include <sys/time.h>
 #include <sys/file.h>               /* for unbuffered i/o stuff */
 #include <sys/stat.h>
-#define DF_MT             DFMT_SUN
+#if (defined __sun) && (defined __amd64 || defined __i386) /* SunOS on Intel; 32 and 64-bit modes */
+#define DF_MT   DFMT_SUN_INTEL 
+#else
+#define DF_MT   DFMT_SUN
+#endif /* __sun */
 typedef void              VOID;
 typedef void              *VOIDP;
 typedef char              *_fcd;
@@ -192,14 +197,23 @@ typedef char              int8;
 typedef unsigned char     uint8;
 typedef short int         int16;
 typedef unsigned short int uint16;
+#ifdef _LP64 /* 64-bit environment */
+typedef int               int32;
+typedef unsigned int      uint32;
+#else /* 32-bit environment */
 typedef long int          int32;
 typedef unsigned long int uint32;
+#endif
 typedef int               intn;
 typedef unsigned int      uintn;
 typedef int               intf;     /* size of INTEGERs in Fortran compiler */
 typedef float             float32;
 typedef double            float64;
+#ifdef _LP64 /* 64-bit environment */
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#else /* 32-bit environment */
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+#endif
 #define FNAME_POST_UNDERSCORE
 #define _fcdtocp(desc) (desc)
 #ifdef  HAVE_FMPOOL
@@ -303,20 +317,26 @@ Please check your Makefile.
 typedef void              VOID;
 typedef void              *VOIDP;
 typedef char              *_fcd;
+#ifndef _ALL_SOURCE       
+typedef char              int8;
+typedef short int         int16; 
+typedef int               int32;
+#endif  
 typedef char              char8;
 typedef unsigned char     uchar8;
-typedef char              int8;
 typedef unsigned char     uint8;
-typedef short int         int16;
 typedef unsigned short int uint16;
-typedef long int          int32;
-typedef unsigned long int uint32;
+typedef unsigned int      uint32;
 typedef int               intn;
 typedef unsigned int      uintn;
 typedef float             float32;
 typedef double            float64;
 typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+#ifdef AIX5L64
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#else /*AIX5L64 */
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+#endif /*AIX5L64 */
 #define _fcdtocp(desc) (desc)
 #ifdef  HAVE_FMPOOL
 #define FILELIB PAGEBUFIO  /* enable page buffering */
@@ -368,14 +388,23 @@ typedef char              int8;
 typedef unsigned char     uint8;
 typedef short int         int16;
 typedef unsigned short int uint16;
+#ifdef _LP64 /* 64-bit environment */
+typedef int               int32;
+typedef unsigned int      uint32;
+#else /* 32-bit environment */
 typedef long int          int32;
 typedef unsigned long int uint32;
+#endif
 typedef int               intn;
 typedef unsigned int      uintn;
 typedef float             float32;
 typedef double            float64;
 typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+#ifdef _LP64 /* 64-bit environment */
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#else /* 32-bit environment */
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+#endif
 #define _fcdtocp(desc) (desc)
 #ifdef  HAVE_FMPOOL
 #define FILELIB PAGEBUFIO  /* enable page buffering */
@@ -413,7 +442,14 @@ Please check your Makefile.
 #endif
 #define GOT_MACHINE 1
 
-#   define BSD
+/*
+ * BSD was originally defined with no value.  But some newer SGI system
+ * header files (e.g., resolv.h) assume it has a value and evaluate it
+ * in expressions, thus causing compiling errors.  This has been reported
+ * to SGI as bug #781568.  SGI could not provide a list of the semantics
+ * of BSD values and suggested a work around of setting BSD to 1.
+ */
+#   define BSD 1
 #ifndef __GNUC__
 #include <memory.h>
 #endif /* __GNUC__ */
@@ -444,9 +480,11 @@ typedef long               hdf_pint_t;   /* an integer the same size as a pointe
 #else
 #define FILELIB UNIXBUFIO
 #endif
+/*
 #ifdef IRIX64
 #define BIG_LONGS
 #endif
+*/
 
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
@@ -586,6 +624,19 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* CRAYMPP */
 
+/* CRAY XT3
+ * Note from RedStorm helpdesk,
+ * When I compile a C code with the '-v' option, it indicates that the compile
+ * is done with the macros __QK_USER__ and __LIBCATAMOUNT__ defined.  In
+ * addition, there are other macros like __x86_64__ defined as well, to
+ * indicate processor type.  __QK_USER__ might be a good check for Catamount,
+ * and __x86_64__ might be good for Opteron node.  You might try something
+ * like the following in a header file:
+ */
+#if ((defined(__QK_USER__)) && (defined(__x86_64__)))
+#define __CRAY_XT3__
+#endif
+
 #if defined(VMS) || defined(vms)
 
 #ifdef GOT_MACHINE
@@ -696,6 +747,67 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 #endif /* CONVEX */
 
 
+#if defined (__APPLE__)
+
+#ifndef __APPLE__
+#define __APPLE__
+#endif
+
+#ifdef GOT_MACHINE
+If you get an error on this line more than one machine type has been defined.
+Please check your Makefile.
+#endif
+#define GOT_MACHINE 1
+
+#ifndef __GNUC__
+#define DUMBCC 	/* because it is.  for later use in macros */
+#endif /* __GNUC__ */
+
+#include <sys/types.h>
+#include <sys/file.h>               /* for unbuffered i/o stuff */
+#include <sys/stat.h>
+#ifdef __i386
+#ifndef INTEL86
+#define INTEL86   /* we need this Intel define or bad things happen later */
+#endif /* INTEL86 */
+#define DF_MT   DFMT_APPLE_INTEL
+#else
+#define DF_MT   DFMT_APPLE
+#endif /* __i386 */
+
+typedef void            VOID;
+typedef void            *VOIDP;
+typedef char            *_fcd;
+typedef char            char8;
+typedef unsigned char   uchar8;
+typedef char            int8;
+typedef unsigned char   uint8;
+typedef short           int16;
+typedef unsigned short  uint16;
+typedef int             int32;
+typedef unsigned int    uint32;
+typedef int             intn;
+typedef unsigned int    uintn;
+typedef float           float32;
+typedef double          float64;
+typedef int             intf;     /* size of INTEGERs in Fortran compiler */
+typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+#define _fcdtocp(desc) (desc)
+#ifdef  HAVE_FMPOOL
+#define FILELIB PAGEBUFIO  /* enable page buffering */
+#else
+#define FILELIB UNIXBUFIO
+#endif
+
+/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
+
+/* Determine the memory manager we are going to use. Valid values are: */
+/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
+/*  what each does */
+#define JMEMSYS         MEM_ANSI
+
+#endif /* __APPLE__ */
+
 #if defined(MIPSEL) || ((defined(mips) || defined(__mips)) && (defined(ultrix) || defined(__ultrix)))
 
 #ifndef MIPSEL
@@ -770,7 +882,7 @@ Please check your Makefile.
 #else  /* MPW, possibly others */
 #include <Files.h>              /* for unbuffered I/O stuff */
 #endif /* SYMANTEC_C*/
-#ifndef ABSOFT
+#ifndef ABSOFT 
 #define DF_CAPFNAMES            /* fortran names are in all caps */
 #endif /* ABSOFT */
 #define DF_DYNAMIC              /* use dynamic allocation */
@@ -808,9 +920,9 @@ void exit(int status);
 #endif /*MAC*/
 
 /* Metrowerks Mac compiler defines some PC stuff so need to exclude this on the Mac */
-#if !(defined(macintosh) || defined(MAC))
+#if !(defined(macintosh) || defined(MAC) || defined (__APPLE__))
 
-#if defined _M_ALPHA || defined _M_IX86 || defined INTEL86 || defined M_I86 || defined M_I386 || defined DOS386 || defined __i386 || defined UNIX386 || defined i386
+#if defined _M_ALPHA || defined _M_X64 || defined _M_IA64 || defined _M_IX86 || defined INTEL86 || defined M_I86 || defined M_I386 || defined DOS386 || defined __i386 || defined UNIX386 || defined i386
 #ifndef INTEL86
 #define INTEL86
 #endif /* INTEL86 */
@@ -823,9 +935,9 @@ void exit(int status);
 #define DOS386
 #endif /* M_I386 && !DOS386 */
 
-#if defined _WINDOWS || defined WIN32
+#if defined _WINDOWS || defined _WIN32
 #define WIN386
-#endif  /* _WINDOWS | WIN32 */
+#endif  /* _WINDOWS | _WIN32 */
 
 #if defined WIN386 || defined DOS386 || defined UNIX386
 #define INTEL386
@@ -837,7 +949,7 @@ Please check your Makefile.
 #endif
 #define GOT_MACHINE 1
 
-#if defined _WINDOWS || defined WIN32
+#if defined _WINDOWS || defined _WIN32
 #pragma comment( lib, "oldnames" )
 #endif
 
@@ -858,27 +970,6 @@ Please check your Makefile.
 #include <stddef.h>         /* for the 'fortran' pragma */
 #endif
 
-#if defined(_MSC_VER) && !defined(_MFHDFLIB_) && !defined(_HDFLIB_)	/* Auto-link when possible */
-#	define HDF_LIB_VER	"413"
-#	if !defined(_DEBUG)
-#		if !defined(_HDFDLL_)
-#			define HDF_LIB_NAME	"HD" HDF_LIB_VER ".lib"
-#			pragma message( "Automatic linking with the static single-threaded HDF library - " HDF_LIB_NAME )
-#		else
-#			define HDF_LIB_NAME	"HD" HDF_LIB_VER "m.lib"
-#			pragma message( "Automatic linking with the multithreaded HDF DLL - " HDF_LIB_NAME )
-#		endif
-#	else
-#		if !defined(_HDFDLL_)
-#			define HDF_LIB_NAME	"HD" HDF_LIB_VER "d.lib"
-#			pragma message( "Automatic linking with the debug static single-threaded HDF library - " HDF_LIB_NAME  )
-#		else
-#			define HDF_LIB_NAME	"HD" HDF_LIB_VER "md.lib"
-#			pragma message( "Automatic linking with the debug multithreaded HDF DLL - " HDF_LIB_NAME  )
-#		endif
-#	endif
-#	pragma comment(lib, HDF_LIB_NAME )
-#endif /* defined(_MSC_VER) && !defined(_MFHDFLIB_) && !defined(_HDFLIB_) */
 
 #if defined WIN386
 #ifndef GMEM_MOVEABLE       /* check if windows header is already included */
@@ -908,14 +999,23 @@ typedef unsigned int      uintn;
 typedef float             float32;
 typedef double            float64;
 typedef long              intf;     /* size of INTEGERs in Fortran compiler */
-typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+#ifdef _WIN64
+typedef long long         hdf_pint_t;   /* 8-byte pointer */
+#else
+typedef int               hdf_pint_t;   /* 4-byte pointer */
+#endif /* _WIN64 */
 
 #if defined _M_ALPHA
 #define FNAME_PRE_UNDERSCORE
 #endif
 
 #if defined UNIX386
+#ifdef H4_ABSOFT
+#define FNAME(x) x
+#define DF_CAPFNAMES
+#else
 #define FNAME_POST_UNDERSCORE
+#endif
 #elif defined INTEL386
 #define DF_CAPFNAMES
 #endif
@@ -1192,6 +1292,170 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* I860 */
 
+
+/* Power PC 5 64 */
+#if defined __powerpc64__
+
+#ifdef GOT_MACHINE
+If you get an error on this line more than one machine type has been defined.
+Please check your Makefile.
+#endif
+#define GOT_MACHINE
+
+#include <sys/file.h>               /* for unbuffered i/o stuff */
+#include <sys/stat.h>
+#define DF_MT             DFMT_POWERPC64
+typedef void              VOID;
+typedef void              *VOIDP;
+typedef char              *_fcd;
+typedef char              char8;
+typedef unsigned char     uchar8;
+typedef char              int8;
+typedef unsigned char     uint8;
+typedef short int         int16;
+typedef unsigned short int uint16;
+typedef int               int32;
+typedef unsigned int      uint32;
+typedef int               intn;
+typedef unsigned int      uintn;
+typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+typedef float             float32;
+typedef double            float64;
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#if defined __GNUC__
+#define FNAME_POST_UNDERSCORE
+#endif
+#define _fcdtocp(desc) (desc)
+#ifdef  HAVE_FMPOOL
+#define FILELIB PAGEBUFIO  /* enable page buffering */
+#else
+#define FILELIB UNIXBUFIO
+#endif
+
+/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
+
+/* Determine the memory manager we are going to use. Valid values are: */
+/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
+/*  what each does */
+#define JMEMSYS         MEM_ANSI
+
+#ifdef __GNUC__
+#define HAVE_STDC
+#define INCLUDES_ARE_ANSI
+#endif
+
+#endif /*power PC 5 64 */
+/* Linux 64 */
+#if defined __x86_64__  && !(defined  SUN) /* i.e. not SunOS on Intel */
+
+#ifdef GOT_MACHINE
+If you get an error on this line more than one machine type has been defined.
+Please check your Makefile.
+#endif
+#define GOT_MACHINE
+
+#include <sys/file.h>               /* for unbuffered i/o stuff */
+#include <sys/stat.h>
+#define DF_MT             DFMT_LINUX64
+typedef void              VOID;
+typedef void              *VOIDP;
+typedef char              *_fcd;
+typedef char              char8;
+typedef unsigned char     uchar8;
+typedef char              int8;
+typedef unsigned char     uint8;
+typedef short int         int16;
+typedef unsigned short int uint16;
+typedef int               int32;
+typedef unsigned int      uint32;
+typedef int               intn;
+typedef unsigned int      uintn;
+typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+typedef float             float32;
+typedef double            float64;
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#define FNAME_POST_UNDERSCORE
+#define _fcdtocp(desc) (desc)
+#ifdef  HAVE_FMPOOL
+#define FILELIB PAGEBUFIO  /* enable page buffering */
+#else
+#define FILELIB UNIXBUFIO
+#endif
+
+/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
+
+/* Determine the memory manager we are going to use. Valid values are: */
+/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
+/*  what each does */
+#define JMEMSYS         MEM_ANSI
+
+#ifdef __GNUC__
+#define HAVE_STDC
+#define INCLUDES_ARE_ANSI
+#endif
+
+#endif /*Linux 64 */
+
+/*#ifndef GOT_MACHINE
+No machine type has been defined.  Your Makefile needs to have someing like
+-DSUN or -DUNICOS in order for the HDF internal structures to be defined
+correctly.
+#endif
+*/
+
+/*-----------------------------------------------------*/
+
+/* IA64 running Linux */
+#if defined __ia64 && !(defined(hpux) || defined(__hpux))
+
+#ifdef GOT_MACHINE
+If you get an error on this line more than one machine type has been defined.
+Please check your Makefile.
+#endif
+#define GOT_MACHINE
+
+#include <sys/file.h>               /* for unbuffered i/o stuff */
+#include <sys/stat.h>
+#define DF_MT             DFMT_IA64
+typedef void              VOID;
+typedef void              *VOIDP;
+typedef char              *_fcd;
+typedef char              char8;
+typedef unsigned char     uchar8;
+typedef char              int8;
+typedef unsigned char     uint8;
+typedef short int         int16;
+typedef unsigned short int uint16;
+typedef int               int32;
+typedef unsigned int      uint32;
+typedef int               intn;
+typedef unsigned int      uintn;
+typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+typedef float             float32;
+typedef double            float64;
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#define FNAME_POST_UNDERSCORE
+#define _fcdtocp(desc) (desc)
+#ifdef  HAVE_FMPOOL
+#define FILELIB PAGEBUFIO  /* enable page buffering */
+#else
+#define FILELIB UNIXBUFIO
+#endif
+
+/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
+
+/* Determine the memory manager we are going to use. Valid values are: */
+/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
+/*  what each does */
+#define JMEMSYS         MEM_ANSI
+
+#ifdef __GNUC__
+#define HAVE_STDC
+#define INCLUDES_ARE_ANSI
+#endif
+
+#endif /* IA64 */
+
 #ifndef GOT_MACHINE
 No machine type has been defined.  Your Makefile needs to have someing like
 -DSUN or -DUNICOS in order for the HDF internal structures to be defined
@@ -1341,7 +1605,7 @@ correctly.
 /**************************************************************************
 *  Allocation functions defined differently 
 **************************************************************************/
-#if !defined(MALLOC_CHECK) && !defined(_HDFDLL_)
+#if !defined(MALLOC_CHECK)
 #  define HDmalloc(s)      (malloc((size_t)s))
 #  define HDcalloc(a,b)    (calloc((size_t)a,(size_t)b))
 #  define HDfree(p)        (free((void*)p))
@@ -1364,7 +1628,7 @@ correctly.
 #  define HDstrrchr(s,c)        (strrchr((s),(c)))
 #  define HDstrtol(s,e,b)       (strtol((s),(e),(b)))
 /* non-standard function, not defined on the following machines - */
-#if !(defined VMS || defined macintosh || defined MAC || defined SYMANTEC_C || defined MIPSEL || defined NEXT || defined CONVEX || defined IBM6000 || defined ANSISUN || defined IRIX || defined _HDFDLL_ )
+#if !(defined VMS || defined macintosh || defined MAC || defined SYMANTEC_C || defined MIPSEL || defined NEXT || defined CONVEX || defined IBM6000 || defined ANSISUN || defined IRIX )
 #  define HDstrdup(s)      ((char *)strdup((const char *)(s)))
 #endif /* !(VMS | etc..) */
 
