@@ -1,23 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.81 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: hextelt.c,v 1.81 1998/09/02 21:09:22 acheng Exp $ */
-#ifdef HAVE_PABLO
-#define HDF_mask H_mask
-#endif
+/* $Id: hextelt.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*LINTLIBRARY */
 /* ------------------------------ hextelt.c -------------------------------
@@ -212,9 +210,6 @@ HXcreate(int32 file_id, uint16 tag, uint16 ref, const char *extern_file_name, in
     void *       buf = NULL;      /* temporary buffer */
     int32       ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_HXcreate);
-#endif /* HAVE_PABLO */
     /* clear error stack and validate args */
     HEclear();
     file_rec = HAatom_object(file_id);
@@ -364,9 +359,6 @@ done:
   if (buf != NULL)
       HDfree(buf);
 
-#ifdef HAVE_PABLO
-        HDF_TRACE_OFF( ID_HXcreate, file_id, extern_file_name, HDF_File_ID );
-#endif /* HAVE_PABLO */
   return ret_value; 
 } /* HXcreate */
 
@@ -737,11 +729,13 @@ HXPwrite(accrec_t * access_rec, int32 length, const void * data)
     CONSTR(FUNC, "HXPwrite");   /* for HERROR */
     extinfo_t  *info =          /* information on the special element */
                     (extinfo_t *) (access_rec->special_info);
-    uint8      *p =local_ptbuf;/* temp buffer ptr */
-    filerec_t  *file_rec =     /* file record */
-                          HAatom_object(access_rec->file_id);
+    uint8      *p =local_ptbuf; /* temp buffer ptr */
+    filerec_t  *file_rec;       /* file record */
     int32      ret_value = SUCCEED;
 
+    /* convert file id to file record */
+    file_rec = HAatom_object(access_rec->file_id);
+
     /* validate length */
     if (length < 0)
         HGOTO_ERROR(DFE_RANGE, FAIL);
@@ -905,10 +899,12 @@ intn
 HXPendaccess(accrec_t * access_rec)
 {
     CONSTR(FUNC, "HXPendaccess");   /* for HERROR */
-    filerec_t  *file_rec =      /* file record */
-        HAatom_object(access_rec->file_id);
+    filerec_t  *file_rec;           /* file record */
     intn     ret_value = SUCCEED;
 
+    /* convert file id to file record */
+    file_rec = HAatom_object(access_rec->file_id);
+
     /* close the file pointed to by this access rec */
     HXPcloseAID(access_rec);
 
@@ -1159,9 +1155,6 @@ HXsetcreatedir(const char *dir)
   char	*pt;
   intn       ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_HXsetcreatedir);
-#endif /* HAVE_PABLO */
 
   if (dir)
     {
@@ -1183,9 +1176,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        HDF_TRACE_OFF( ID_HXsetcreatedir, NoDSid, dir, HDF_Directory_ID );
-#endif /* HAVE_PABLO */
   return ret_value; 
 }	/* HXsetcreatedir */
 
@@ -1216,9 +1206,6 @@ HXsetdir(const char *dir)
   char	*pt;
   intn   ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_HXsetdir);
-#endif /* HAVE_PABLO */
   if (dir)
     {
       if (!(pt = HDstrdup(dir)))
@@ -1239,9 +1226,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        HDF_TRACE_OFF( ID_HXsetdir, NoDSid, dir, HDF_Directory_ID );
-#endif /* HAVE_PABLO */
   return ret_value; 
 }	/* HXsetdir */
 
