@@ -1,16 +1,17 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: hfile.h,v 1.112 1999/04/12 14:48:57 bljones Exp $ */
+/* $Id: hfile.h 5167 2009-01-26 01:55:18Z epourmal $ */
 
 /*+ hfile.h
    *** Header for hfile.c, routines for low level data element I/O
@@ -47,9 +48,9 @@
 /* Library version numbers */
 
 #define LIBVER_MAJOR    4
-#define LIBVER_MINOR    1 
-#define LIBVER_RELEASE  3 
-#define LIBVER_STRING   "NCSA HDF Version 4.1 Release 3, May 1999"
+#define LIBVER_MINOR    2 
+#define LIBVER_RELEASE  4 
+#define LIBVER_STRING   "HDF Version 4.2 Release 4, January 25, 2009"
 #define LIBVSTR_LEN    80   /* length of version string  */
 #define LIBVER_LEN  92      /* 4+4+4+80 = 92 */
 /* end of version tags */
@@ -87,7 +88,7 @@ typedef FILE *hdf_file_t;
                                 SUCCEED : FAIL)
 #   define HI_WRITE(f, b, n)   (((size_t)(n) == (size_t)fwrite((b), 1, (size_t)(n), (f))) ? \
                                 SUCCEED : FAIL)
-#   define HI_CLOSE(f)   (fclose(f))
+#   define HI_CLOSE(f)   (((f = ((fclose(f)==0) ? NULL : f))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(f)   (fflush(f)==0 ? SUCCEED : FAIL)
 #   define HI_SEEK(f,o)  (fseek((f), (long)(o), SEEK_SET)==0 ? SUCCEED : FAIL)
 #   define HI_SEEK_CUR(f,o)  (fseek((f), (long)(o), SEEK_CUR)==0 ? SUCCEED : FAIL)
@@ -102,7 +103,7 @@ typedef int hdf_file_t;
 #   define HI_OPEN(p, a)       (((a) & DFACC_WRITE) ? \
                                     open((p), O_RDWR) : open((p), O_RDONLY))
 #   define HI_CREATE(p)         (open((p), O_RDWR | O_CREAT | O_TRUNC, 0666))
-#   define HI_CLOSE(f)          (close(f))
+#   define HI_CLOSE(f)          (((f = ((close(f)==0) ? NULL : f))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(f)          (SUCCEED)
 #   define HI_READ(f, b, n)     (((n)==read((f), (char *)(b), (n))) ? SUCCEED : FAIL)
 #   define HI_WRITE(f, b, n)    (((n)==write((f), (char *)(b), (n))) ? SUCCEED : FAIL)
@@ -117,7 +118,7 @@ typedef int hdf_file_t;
 typedef short hdf_file_t;
 #   define HI_OPEN(x,y)         mopen(x,y)
 #   define HI_CREATE(name)      mopen(name, DFACC_CREATE)
-#   define HI_CLOSE(x)          mclose(x)
+#   define HI_CLOSE(x)          (((x = ((mclose(x)==0) ? NULL : x))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(a)          (SUCCEED)
 #   define HI_READ(a,b,c)       mread(a, (char *) b, (int32) c)
 #   define HI_WRITE(a,b,c)      mwrite(a, (char *) b, (int32) c)
@@ -141,7 +142,7 @@ typedef FILE *hdf_file_t;
                                 SUCCEED : FAIL)
 #   define HI_WRITE(f, b, n)   (((int32)(n) == HDfwritebig((b), (n), (f))) ? \
                                 SUCCEED : FAIL)
-#   define HI_CLOSE(f)          (fclose(f))
+#   define HI_CLOSE(f)          (((f = ((fclose(f)==0) ? NULL : f))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(f)          (fflush(f)==0 ? SUCCEED : FAIL)
 #   define HI_SEEK(f,o)  (fseek((f), (long)(o), SEEK_SET)==0 ? SUCCEED : FAIL)
 #   define HI_SEEKEND(f) (fseek((f), (long)0, SEEK_END)==0 ? SUCCEED : FAIL)
@@ -161,7 +162,7 @@ typedef HFILE hdf_file_t;
                                 SUCCEED : FAIL)
 #   define HI_WRITE(f, b, n)   (((int32)(n) == HDfwritebig((b), (n), (f))) ? \
                                 SUCCEED : FAIL)
-#   define HI_CLOSE(f)          (_lclose(f))
+#   define HI_CLOSE(f)          (((f = ((_lclose(f)==0) ? NULL : f))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(f)          (0)
 #   define HI_SEEK(f, o)        (_llseek((f), (long)(o), SEEK_SET))
 #   define HI_SEEKEND(f)        (_llseek((f), (long)0, SEEK_END))
@@ -179,7 +180,7 @@ typedef HFILE hdf_file_t;
                                 SUCCEED : FAIL)
 #   define HI_WRITE(f, b, n)   (((int32)(n) == _hwrite((f), (b), (n))) ? \
                                 SUCCEED : FAIL)
-#   define HI_CLOSE(f) (_lclose(f)==0 ? SUCCEED : FAIL)
+#   define HI_CLOSE(f)         (((f = ((_lclose(f)==0) ? NULL : f))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(f) (0)
 #   define HI_SEEK(f, o)       (_llseek((f), (long)(o), 0))
 #   define HI_SEEKEND(f) (_llseek((f), (long)0, 2))
@@ -194,7 +195,7 @@ typedef HFILE hdf_file_t;
 typedef MPFILE *hdf_file_t;
 #   define HI_OPEN(p, a)        (MPopen((p), (a)))
 #   define HI_CREATE(p)         (MPopen((p), DFACC_CREATE))
-#   define HI_CLOSE(f)          (MPclose(f))
+#   define HI_CLOSE(f)          (((f = ((MPclose(f)==0) ? NULL : f))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(f)          (MPflush(f))
 #   define HI_READ(f, b, n)     (MPread((f), (char *)(b), (n)))
 #   define HI_WRITE(f, b, n)    (MPwrite((f), (char *)(b), (n)))
@@ -337,10 +338,10 @@ typedef struct tag_info_str
 /* For determining what the last file operation was */
 typedef enum
   {
-      OP_UNKNOWN = 0,   /* Don't know what the last operation was (after fopen frex) */
-      OP_SEEK,          /* Last operation was a seek */
-      OP_WRITE,         /* Last operation was a write */
-      OP_READ           /* Last operation was a read */
+      H4_OP_UNKNOWN = 0,   /* Don't know what the last operation was (after fopen frex) */
+      H4_OP_SEEK,          /* Last operation was a seek */
+      H4_OP_WRITE,         /* Last operation was a write */
+      H4_OP_READ           /* Last operation was a read */
   }
 fileop_t;
 
@@ -399,7 +400,8 @@ typedef struct accrec_t
       intn        appendable;   /* whether appends to the data are allowed */
       intn        special;      /* special element ? */
       intn        new_elem;     /* is a new element (i.e. no length set yet) */
-      
+      int32       block_size;   /* size of the blocks for linked-block element*/
+      int32       num_blocks;   /* number blocks in the linked-block element */
       uint32      access;       /* access codes */
       uintn       access_type;  /* I/O access type: serial/parallel/... */
       int32       file_id;      /* id of attached file */
@@ -555,6 +557,12 @@ extern      "C"
     HDFLIBAPI intn HPfreediskblock
                 (filerec_t * file_rec, int32 block_offset, int32 block_size);
 
+    HDFLIBAPI intn HPisfile_in_use
+                (const char *path);
+
+    HDFLIBAPI int32 HDcheck_empty
+                (int32 file_id, uint16 tag, uint16 ref, intn *emptySDS);
+
     HDFLIBAPI int32 HDget_special_info
                 (int32 access_id, sp_info_block_t * info_block);
 
@@ -682,6 +690,9 @@ extern      "C"
     HDFLIBAPI int32 HCPinfo
                 (accrec_t * access_rec, sp_info_block_t * info_block);
 
+    HDFLIBAPI int32 get_comp_len
+	        (accrec_t* access_rec);
+
 /*
    ** from hchunks.c - should be the same as found in 'hchunks.h'
  */
