@@ -1,24 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.52 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: mfan.c,v 1.52 1999/06/16 21:11:08 dwells Exp $ */
-
-#ifdef HAVE_PABLO
-#define PABLO_mask ID_mfan_c
-#endif
+/* $Id: mfan.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*-----------------------------------------------------------------------------
  * File:     mfan.c
@@ -1356,10 +1353,6 @@ ANstart(int32 file_id /* IN: file to start annotation access on*/)
     filerec_t  *file_rec = NULL;		/* file record pointer */
     int32       ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANstart);
-#endif /* HAVE_PABLO */
-
     /* Clear error stack */
     HEclear();
 
@@ -1380,10 +1373,6 @@ ANstart(int32 file_id /* IN: file to start annotation access on*/)
       } /* end if */
 
     /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANstart);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANstart() */
 
@@ -1415,10 +1404,6 @@ ANfileinfo(int32  an_id,        /* IN:  annotation interface id */
     filerec_t  *file_rec  = NULL;  /* file record pointer */
     intn        ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANfileinfo);
-#endif /* HAVE_PABLO */
-
     /* Clear error stack */
     HEclear();
 
@@ -1470,10 +1455,6 @@ ANfileinfo(int32  an_id,        /* IN:  annotation interface id */
       } /* end if */
 
     /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANfileinfo);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANfileinfo() */
 
@@ -1497,10 +1478,6 @@ ANend(int32 an_id /* IN: Annotation ID of file to close */)
     ANnode    *ann_node  = NULL;
     int32      ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANend);
-#endif /* HAVE_PABLO */
-  
     /* Clear error stack */
     HEclear();
 
@@ -1613,10 +1590,6 @@ ANend(int32 an_id /* IN: Annotation ID of file to close */)
       } /* end if */
 
     /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANend);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANend() */
 
@@ -1647,16 +1620,8 @@ ANcreate(int32    an_id,    /* IN: annotation interface ID */
 #endif /* LATER */
     int32    ret_value;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANcreate);
-#endif /* HAVE_PABLO */
-
     ret_value = (ANIcreate(an_id, elem_tag, elem_ref, type));
 
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANcreate);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANcreate() */
 
@@ -1687,10 +1652,6 @@ ANcreatef(int32    an_id,/* IN: annotation interface ID */
     uint16 ann_ref;
     int32  ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANcreatef);
-#endif /* HAVE_PABLO */
-
     /* deal with type */
     switch((ann_type)type)
       {
@@ -1717,10 +1678,6 @@ ANcreatef(int32    an_id,/* IN: annotation interface ID */
       } /* end if */
 
     /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANcreatef);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANcreateann() */
 
@@ -1752,10 +1709,6 @@ ANselect(int32    an_id, /* IN: annotation interface ID */
     ANentry   *ann_entry = NULL;
     int32      ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANselect);
-#endif /* HAVE_PABLO */
-
     /* Clear error stack */
     HEclear();
 
@@ -1793,10 +1746,6 @@ ANselect(int32    an_id, /* IN: annotation interface ID */
       } /* end if */
 
     /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANselect);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANselect() */
 
@@ -1829,10 +1778,6 @@ ANnumann(int32    an_id,    /* IN: annotation interface id */
     CONSTR(FUNC, "ANnumann");
     intn   ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANnumann);
-#endif /* HAVE_PABLO */
-
     /* deal with invalid types */
     if(type == AN_FILE_LABEL || type == AN_FILE_DESC)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -1847,10 +1792,6 @@ ANnumann(int32    an_id,    /* IN: annotation interface id */
 
     /* Normal function cleanup */
 
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANnumann);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANnumann() */
 
@@ -1884,10 +1825,6 @@ ANannlist(int32    an_id,      /* IN: annotation interface id */
     CONSTR(FUNC, "ANannlist");
     intn  ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANannlist);
-#endif /* HAVE_PABLO */
-
     /* deal with invalid types */
     if(type == AN_FILE_LABEL || type == AN_FILE_DESC)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -1902,10 +1839,6 @@ ANannlist(int32    an_id,      /* IN: annotation interface id */
 
     /* Normal function cleanup */
 
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANannlist);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANannlist() */
 
@@ -1931,15 +1864,7 @@ ANannlen(int32 ann_id /* IN: annotation id */)
 #endif /* LATER */
     int32  ret_value;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANannlen);
-#endif /* HAVE_PABLO */
-
     ret_value =  ANIannlen(ann_id);
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANannlen);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANannlen() */
 
@@ -1968,15 +1893,7 @@ ANwriteann(int32 ann_id,     /* IN: annotation id */
 #endif /* LATER */
     int32  ret_value;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANwriteann);
-#endif /* HAVE_PABLO */
-
     ret_value = ANIwriteann(ann_id, ann, annlen);
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANwriteann);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANwriteann() */
 
@@ -2005,15 +1922,7 @@ ANreadann(int32 ann_id,  /* IN: annotation id (handle) */
 #endif /* LATER */
     int32   ret_value;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANreadann);
-#endif /* HAVE_PABLO */
-
     ret_value = ANIreadann(ann_id, ann, maxlen);
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANreadann);
-#endif /* HAVE_PABLO */
-
     return ret_value;
 } /* ANreadann() */
 
@@ -2038,18 +1947,9 @@ ANendaccess(int32 ann_id /* IN: annotation id */)
     CONSTR(FUNC, "ANendaccess");    /* for HERROR */
 #endif /* LATER */
     intn  ret_value = SUCCEED;
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_ANendaccess);
-#endif /* HAVE_PABLO */
-
     /* shut compiler up */
     ann_id=ann_id;
 
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_ANendaccess);
-#endif /* HAVE_PABLO */
-
-
     return ret_value;
 } /* ANendaccess() */
 
