@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.15 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: mfgrf.c,v 1.15 2000/08/29 13:55:36 koziol Exp $ */
+/* $Id: mfgrf.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*-----------------------------------------------------------------------------
  * File:    mfsdf.c
@@ -46,7 +47,8 @@ static char RcsId[] = "@(#)$Revision: 1.15 $";
  *  mgrclut:    Call GRreadlut to read a character palette from the file
  *  mgsxfil:    Call GRsetexternalfile to move an image into an external file
  *  mgsactp:    Call GRsetaccesstype to set the access type for an image
- *  mgscomp:    Call GRsetcompress to compress an image in the file [Later]
+ *  mgscomp:    Call GRsetcompress to compress an image in the file 
+ *  mggcomp:    Call GRgetcompress to get image compression information 
  *  mgisattr:    Call GRsetattr to write an attribute for an object
  *  mgiscatt:   Call GRsetattr to write a char attribute for an obj.
  *  mgatinf:    Call GRattrinfo get information about an attribute
@@ -60,6 +62,7 @@ static char RcsId[] = "@(#)$Revision: 1.15 $";
  *---------------------------------------------------------------------------*/
 
 #include "hdf.h"
+#include "hproto_fortran.h"
 
 /* Local pre-processor macros */
 #define XDIM    0
@@ -1122,7 +1125,7 @@ nmgifndat(intf * riid, _fcd name, intf *nlen)
  *                      COMP_CODE_RLE  = 1
  *                      COMP_CODE_SKPHUFF = 3
  *                      COMP_CODE_DEFLATE = 4
- *                      COMP_CODE_JPEG    = 6
+ *                      COMP_CODE_JPEG    = 7 
  *          comp_prm:   compression parameters array
  *          comp_prm[0]=skphuff_skp_size: size of individual elements for 
  *                            Adaptive Huffman compression algorithm
@@ -1145,7 +1148,7 @@ nmgifndat(intf * riid, _fcd name, intf *nlen)
 {
     int32 riid;               /*  GR id               */
     comp_info c_info;         /* compression info     */
-    int32 c_type;              /* compression type definition */
+    comp_coder_t c_type;              /* compression type definition */
 
     int CASE;
     intf ret;
@@ -1189,6 +1192,84 @@ nmgifndat(intf * riid, _fcd name, intf *nlen)
     ret = GRsetcompress(riid, c_type, &c_info);
     return(ret);
 
+}   
+/*-------------------------------------------------------------------------
+ * Name:    mgcgcompress
+ * Puporse: Call GRgetcompress
+ * Inputs:  id: access id to GR
+ * Outputs: comp_type:  type of compression
+ *                      COMP_CODE_NONE = 0
+ *                      COMP_CODE_RLE  = 1
+ *                      COMP_CODE_SKPHUFF = 3
+ *                      COMP_CODE_DEFLATE = 4
+ *                      COMP_CODE_JPEG    = 7 
+ *          comp_prm:   compression parameters array
+ *          comp_prm[0]=skphuff_skp_size: size of individual elements for 
+ *                            Adaptive Huffman compression algorithm
+ *          comp_prm[0]=deflate_level:    GZIP  compression parameter
+ * Returns: 0 on success, -1 on failure with error set
+ * Users:   HDF Fortran programmers          
+ *-------------------------------------------------------------------------*/
+
+    FRETVAL (intf)
+#ifdef PROTOTYPE
+       nmgcgcompress(intf *id, intf *comp_type, intf *comp_prm)
+#else
+       nmgcgcompress( id, comp_type, comp_prm)
+       intf *id;
+       intf *comp_type;
+       intf *comp_prm;
+#endif /* PROTOTYPE */
+{
+    comp_info c_info;         /* compression info     */
+    comp_coder_t c_type;              /* compression type definition */
+
+    int CASE;
+    intf ret = -1;
+    intn c_ret;
+
+
+    c_ret = GRgetcompinfo(*id, &c_type, &c_info);
+
+    if (c_ret == 0) {
+    CASE = (int)c_type;
+    switch (CASE)  {
+
+       case COMP_CODE_NONE:       /* No compression */
+         *comp_type = 0;
+         ret = 0;
+         break;
+    
+       case COMP_CODE_RLE:             /* RLE compression */
+         *comp_type = 1;
+         ret = 0;
+         break;
+ 
+       case COMP_CODE_SKPHUFF:      /* Skipping Huffman encoding */
+          *comp_type = 3;
+          comp_prm[0] = (intf)c_info.skphuff.skp_size;
+          ret = 0;
+          break;
+
+       case COMP_CODE_DEFLATE:      /* GZIP compression */  
+          *comp_type = 4;
+          comp_prm[0] = (intf)c_info.deflate.level;
+          ret = 0;
+          break;
+
+       case COMP_CODE_JPEG:      /* JPEG compression */  
+          *comp_type = 7;
+          ret = 0;
+          break;
+
+       default:
+
+          return FAIL;
+                    
+     } /*end CASE */
+    } /*end if */
+    return(ret);
+
 }   
 /*-------------------------------------------------------------------------
  * Name:    mglt2rf
@@ -1212,3 +1293,26 @@ nmgifndat(intf * riid, _fcd name, intf *nlen)
    ret = GRluttoref ( *id );
    return(ret);
 }
+/*-------------------------------------------------------------------------
+ * Name:    mgcgnluts
+ * Puporse: Call GRgetnluts
+ * Inputs:  id: image identifier
+ * Returns: number of palettes on success and -1 if fails.
+ * Users:   HDF Fortran programmers          
+ *-------------------------------------------------------------------------*/
+
+    FRETVAL (intf)
+#ifdef PROTOTYPE
+       nmgcgnluts(intf *id)
+#else
+       nmgcgnluts( id)
+       intf *id;
+#endif /* PROTOTYPE */
+{
+   intf ret = -1;
+   intn c_ret;
+
+   c_ret = GRgetnluts ( *id );
+   if(c_ret >= 0) ret = c_ret;
+   return(ret);
+}
