@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.43 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: tbbt.c,v 1.43 1998/02/02 21:44:52 smitchel Exp $ */
+/* $Id: tbbt.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /* "tbbt.c" -- Routines for using threaded, balanced, binary trees. */
 /* Extended from (added threads to) Knuth 6.2.3, Algorithm A (AVL trees) */
@@ -456,13 +457,14 @@ balance(TBBT_NODE ** root, TBBT_NODE * ptr, intn side, intn added)
                         {
                             ptr->flags |= (TBBT_FLAG)TBBT_HEAVY(Other(side));  /* Other side longer */
                             if (ptr->Parent)
-                                if (ptr->Parent->Rchild == ptr)     /* we're the right child */
+                                if (ptr->Parent->Rchild == ptr) {     /* we're the right child */
                                     if (Heavy(ptr->Parent, RIGHT) && LeftCnt(ptr->Parent) == 1)
                                         deeper = 0;
                                     else
                                         /* we're the left child */ if (Heavy(ptr->Parent, LEFT))
                                         if (ptr->Parent->Rchild && !UnBal(ptr->Parent->Rchild))
                                             deeper = 0;
+                                }
                         }
                   }
                 else
