@@ -1,23 +1,21 @@
-/*******************************************************************
- * NCSA HDF                                                        *
- * Software Development Group                                      *
- * National Center for Supercomputing Applications                 *
- * University of Illinois at Urbana-Champaign                      *
- * 605 E. Springfield, Champaign IL 61820                          *
- *                                                                 *
- * For conditions of distribution and use, see the accompanying    *
- * hdf/COPYING file.                                               *
- *                                                                 *
- *******************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.16 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: vattr.c,v 1.16 1999/06/16 21:11:12 dwells Exp $ */
-#ifdef HAVE_PABLO
-#define PABLO_mask ID_vattr_c
-#endif
+/* $Id: vattr.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /**************************************************************
 *
@@ -209,10 +207,6 @@ intn VSfindex(int32 vsid, const char *fieldname, int32 *findex)
      int32 ret_value = SUCCEED;
      intn i, found = 0;
 
-#ifdef PABLO
-     TRACE_ON(PABLO_mask,ID_VSfindex);
-#endif
-     
      HEclear();
      if (HAatom_group(vsid) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -249,10 +243,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask,ID_VSfindex);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }       /* VSfindex */
 
@@ -295,19 +285,26 @@ intn VSsetattr(int32 vsid, int32 findex, const char *attrname,
      int32 nattrs, ret_value = SUCCEED;
      int32 attr_vs_ref, fid, attr_vsid;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSsetattr);
-#endif /* HAVE_PABLO */
-
      HEclear();
+
+     /* check if id is valid vdata */
      if (HAatom_group(vsid) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
+     /* check for null attribute name */
+     if (attrname == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
      /* locate vs' index in vstab */
      if (NULL == (vs_inst = (vsinstance_t *)HAatom_object(vsid)))
         HGOTO_ERROR(DFE_NOVS, FAIL);
      if (NULL == (vs = vs_inst->vs))
         HGOTO_ERROR(DFE_NOVS, FAIL);
+
+     /* check for read access */
+     if (vs->access == 'r')
+        HGOTO_ERROR(DFE_BADATTACH, FAIL);
+
      w = &(vs->wlist);
      /* check field index */
      if ((findex >= w->n || findex < 0) && (findex != _HDF_VDATA))
@@ -378,10 +375,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSsetattr);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }  /* VSsetattr */
 /* ------------------------------------------------ 
@@ -406,10 +399,6 @@ intn VSnattrs(int32 vsid)
     VDATA *vs;
     int32 ret_value = SUCCEED;
     
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSnattrs);
-#endif /* HAVE_PABLO */
-
      HEclear();
      if (HAatom_group(vsid) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -427,10 +416,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-       TRACE_OFF(PABLO_mask, ID_VSnattrs);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }  /* VSnattrs */
 
@@ -459,10 +444,6 @@ intn VSfnattrs(int32 vsid, int32 findex)
     vs_attr_t *vs_alist;
     intn i, nattrs, t_attrs;
  
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSfnattrs);
-#endif /* HAVE_PABLO */
-
      HEclear();
      if (HAatom_group(vsid) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -491,10 +472,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_VSfnattrs);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }  /* VSfattrs */
               
@@ -525,13 +502,15 @@ intn VSfindattr(int32 vsid, int32 findex, const char *attrname)
      int32 ret_value = FAIL;
      intn i, nattrs, a_index, found;
 
-#ifdef HAVE_PABLO
-     TRACE_ON(PABLO_mask,ID_VSfindattr);
-#endif /* HAVE_PABLO */
-
      HEclear();
+     /* check if id is valid vdata */
      if (HAatom_group(vsid) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
+
+     /* check for null attribute name */
+     if (attrname == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
      /* locate vs' index in vstab */
      if (NULL == (vs_inst = (vsinstance_t *)HAatom_object(vsid)))
         HGOTO_ERROR(DFE_NOVS, FAIL);
@@ -588,10 +567,6 @@ done:
 
   /* Normal function cleanup */
 
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_VSfindattr);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSfindattr */
 
@@ -629,10 +604,6 @@ intn VSattrinfo(int32 vsid, int32 findex, intn attrindex,
      DYN_VWRITELIST *w;
      char *fldname;
 
-#ifdef HAVE_PABLO
-     TRACE_ON(PABLO_mask,ID_VSattrinfo);
-#endif /* HAVE_PABLO */
-
      HEclear();
      if (HAatom_group(vsid) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -696,10 +667,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-            TRACE_OFF(PABLO_mask, ID_VSattrinfo);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }  /* VSattrinfo */
 
@@ -731,10 +698,6 @@ intn VSgetattr(int32 vsid, int32 findex, intn attrindex,
      int32 n_recs, il;
      char fields[FIELDNAMELENMAX+1];
 
-#ifdef HAVE_PABLO
-     TRACE_ON(PABLO_mask,ID_VSgetattr);
-#endif /* HAVE_PABLO */
-
      HEclear();
      if (HAatom_group(vsid) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -797,10 +760,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-             TRACE_OFF(PABLO_mask, ID_VSgetattr);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }  /* VSgetattr */
 
@@ -824,10 +783,6 @@ intn VSisattr(int32 vsid)
      VDATA    *vs;
      int32  ret_value = FALSE;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSisattr);
-#endif /* HAVE_PABLO */
-
      HEclear();
      if (HAatom_group(vsid) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FALSE);
@@ -845,10 +800,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-            TRACE_OFF(PABLO_mask, ID_VSisattr);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }  /* VSisattr */
 
@@ -888,14 +839,16 @@ intn Vsetattr(int32 vgid, const char *attrname, int32 datatype,
     int32 attr_vs_ref,fid, vsid;
     intn i;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_Vsetattr);
-#endif /* HAVE_PABLO */
-
     HEclear();
+
+    /* check if id is valid vgroup */
     if (HAatom_group(vgid)!=VGIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
+    /* check for null attribute name */
+    if (attrname == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
     /* locate vg's index in vgtab */
     if (NULL == (v = (vginstance_t *) HAatom_object(vgid)))
         HGOTO_ERROR(DFE_VTAB, FAIL);
@@ -971,10 +924,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_Vsetattr);
-#endif /* HAVE_PABLO */
-  
   return ret_value;
 }  /* Vsetattr */
 
@@ -1003,10 +952,6 @@ int32 Vgetversion(int32 vgid)
     int16 vg_version;
     int32 ret_value = FAIL;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_Vgetversion);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if (HAatom_group(vgid)!=VGIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -1028,10 +973,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-            TRACE_OFF(PABLO_mask, ID_Vgetversion);
-#endif /* HAVE_PABLO */
-  
   return ret_value;
 }  /* Vgetversion */
 
@@ -1053,10 +994,6 @@ intn Vnattrs(int32 vgid)
     vginstance_t *v;
     int32 ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_Vnattrs);
-#endif  /* HAVE_PABLO */
-
     HEclear();
     if (HAatom_group(vgid) != VGIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -1078,10 +1015,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-            TRACE_OFF(PABLO_mask, ID_Vnattrs);
-#endif /* HAVE_PABLO */
-  
   return ret_value;
 }  /* Vnattrs */
 
@@ -1109,13 +1042,16 @@ intn Vfindattr(int32 vgid, const char *attrname)
     int32 ret_value = FAIL;
     intn i, found;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_Vfindattr);
-#endif /* HAVE_PABLO */
-
     HEclear();
+
+    /* check if id is valid vgroup */
     if (HAatom_group(vgid) != VGIDGROUP)
        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* check for null attribute name */
+    if (attrname == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
     /* locate vg's index in vgtab */
     if (NULL == (v = (vginstance_t *)HAatom_object(vgid)))
        HGOTO_ERROR(DFE_VTAB, FAIL);
@@ -1155,10 +1091,6 @@ done:
 
   /* Normal function cleanup */
 
-#ifdef HAVE_PABLO
-        TRACE_OFF(PABLO_mask, ID_Vfindattr);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vfindattr */
         
@@ -1196,10 +1128,6 @@ intn Vattrinfo(int32 vgid, intn attrindex, char *name,
     int32 fid, vsid;
     int32 ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_Vattrinfo);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if (HAatom_group(vgid) != VGIDGROUP)
        HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -1250,10 +1178,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-            TRACE_OFF(PABLO_mask, ID_Vattrinfo);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }  /* Vattrinfo */
 
@@ -1283,10 +1207,6 @@ intn Vgetattr(int32 vgid, intn attrindex, void * values)
     int32 n_recs, il;
     int32 ret_value = SUCCEED;
     
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_Vgetattr);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if (HAatom_group(vgid) != VGIDGROUP)
        HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -1333,10 +1253,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-            TRACE_OFF(PABLO_mask, ID_Vgetattr);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }  /* Vgetattr */
 
