@@ -1,24 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.55 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 /* vg.c,v 1.15.4.1 1993/10/26 19:25:07 georgev Exp */
 
-#ifdef HAVE_PABLO
-#define PABLO_mask ID_vg_c
-#endif
-
 /*
 FILE  
      vg.c
@@ -44,6 +41,10 @@ EXPORTED ROUTINES
                        the vgroup with the specified class
      VSfindclass    -- looks in the file and returns the ref of the vdata 
                        with specified class
+     VSsetblocksize -- sets the block size of the linked-block element.
+     VSsetnumblocks -- sets the number of blocks for a linked-block element.
+     VSgetblockinfo -- retrieves the block size and the number of blocks 
+		       of a linked-block element.
      Vsetzap        -- maintaind for back compatibility
 PRIVATE FUNCTIONS
      matchnocase    -- compares to strings, ignoring case
@@ -115,10 +116,6 @@ VSelts(int32 vkey /* IN: vdata key */)
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "VSelts");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_VSelts);
-#endif /* HAVE_PABLO */
-
     /* make sure vdata key is part of vdata group */
     if (HAatom_group(vkey) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -142,10 +139,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask,ID_VSelts);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSelts */
 
@@ -168,10 +161,6 @@ VSgetinterlace(int32 vkey /* IN: vdata key */)
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "VSgetinterlace");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_VSgetinterlace);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -195,10 +184,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask,ID_VSgetinterlace);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSgetinterlace */
 
@@ -222,10 +207,6 @@ VSsetinterlace(int32 vkey,     /* IN: vdata key */
     intn         ret_value = SUCCEED;
     CONSTR(FUNC, "VSsetinterlace");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSsetinterlace);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey)!=VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -264,10 +245,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask,ID_VSsetinterlace);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSsetinterlace */
 
@@ -293,9 +270,10 @@ VSgetfields(int32 vkey,   /* IN: vdata key */
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "VSgetfields");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSgetfields);
-#endif /* HAVE_PABLO */
+    /* check if a NULL field list is passed in, then return with
+       error (found while fixing bug #554) - BMR 4/30/01 */
+    if (fields == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* check key is valid vdata */
     if (HAatom_group(vkey) != VSIDGROUP)
@@ -330,10 +308,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSgetfields);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSgetfields */
 
@@ -364,10 +338,6 @@ VSfexist(int32 vkey,  /* IN: vdata key */
     intn          ret_value = SUCCEED;
     CONSTR(FUNC, "VSfexist");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSfexist);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -422,10 +392,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSfexist);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* VSfexist */
 
@@ -454,10 +420,6 @@ VSsizeof(int32 vkey,   /* IN vdata key */
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "VSsizeof");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSsizeof);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey)!=VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -507,10 +469,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSsizeof);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSsizeof */
 
@@ -554,14 +512,14 @@ VSsetname(int32 vkey,        /* IN: Vdata key */
     int32       ret_value = SUCCEED;
     CONSTR(FUNC, "VSsetname");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSsetname);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
+    /* check for null vdata name */
+    if (vsname == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
     /* get vdata instance */
     if (NULL == (w = (vsinstance_t *) HAatom_object(vkey)))
         HGOTO_ERROR(DFE_NOVS, FAIL);
@@ -595,10 +553,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSsetname);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSsetname */
 
@@ -626,14 +580,14 @@ VSsetclass(int32 vkey,         /* IN: vdata key */
     int32       ret_value = SUCCEED;
     CONSTR(FUNC, "VSsetclass");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSsetclass);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
+    /* check for null vdata class */
+    if (vsclass == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
     /* get vdata instance */
     if (NULL == (w = (vsinstance_t *) HAatom_object(vkey)))
         HGOTO_ERROR(DFE_NOVS, FAIL);
@@ -667,10 +621,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSsetclass);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSsetclass */
 
@@ -694,10 +644,6 @@ VSgetname(int32 vkey,   /* IN: vdata key */
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "VSgetname");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSgetname);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -725,10 +671,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSgetname);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSgetname */
 
@@ -752,14 +694,14 @@ VSgetclass(int32 vkey,    /* IN: vdata key */
     int32     ret_value = SUCCEED;
     CONSTR(FUNC, "VSgetclass");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSgetclass);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
+    /* check user allocated space */
+    if (vsclass == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
     /* get vdata instance */
     if (NULL == (w = (vsinstance_t *) HAatom_object(vkey)))
         HGOTO_ERROR(DFE_NOVS, FAIL);
@@ -779,10 +721,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSgetclass);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSgetclass */
 
@@ -810,10 +748,6 @@ VSinquire(int32 vkey,       /* IN: vdata key */
   intn status;
   CONSTR(FUNC, "VSinquire");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSinquire);
-#endif /* HAVE_PABLO */
-
     /* check key is valid vdata */
     if (HAatom_group(vkey) != VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -853,10 +787,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSinquire);
-#endif /* HAVE_PABLO */
-
     return ret_value;   /* ok */
 
 }   /* VSinquire */
@@ -888,10 +818,6 @@ VSlone(HFILEID f,     /* IN: file id */
     int32   ret_value = SUCCEED;
     CONSTR(FUNC, "VSlone");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSlone);
-#endif /* HAVE_PABLO */
-
     /* -- allocate local space for vdata refs, init to zeros -- */
     if (NULL == (lonevdata = (uint8 *) HDcalloc(MAX_REF , sizeof(uint8))))
         HGOTO_ERROR(DFE_NOSPACE, FAIL);
@@ -940,10 +866,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSlone);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSlone */
 
@@ -974,10 +896,6 @@ Vlone(HFILEID f,      /* IN: file id */
     int32       ret_value = SUCCEED;
     CONSTR(FUNC, "Vlone");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_Vlone);
-#endif /* HAVE_PABLO */
-
     /* -- allocate space for vgroup refs, init to zeroes -- */
     if (NULL == (lonevg = (uint8 *) HDcalloc(MAX_REF , sizeof(uint8))))
         HGOTO_ERROR(DFE_NOSPACE, FAIL);
@@ -1027,10 +945,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF( PABLO_mask, ID_Vlone );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vlone */
 
@@ -1055,13 +969,11 @@ Vfind(HFILEID f,          /* IN: file id */
     vginstance_t *v = NULL;
     VGROUP       *vg = NULL;
     int32       ret_value = 0;
-#ifdef LATER
     CONSTR(FUNC, "Vfind");
-#endif
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_Vfind);
-#endif /* HAVE_PABLO */
+    /* check for null vgroup name */
+    if (vgname == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* process through Vgroups in file */
     while (FAIL != (vgid = Vgetid(f, vgid)))
@@ -1086,10 +998,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF( PABLO_mask, ID_Vfind );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* Vfind */
 
@@ -1114,13 +1022,11 @@ VSfind(HFILEID f,          /* IN: file id */
     vsinstance_t *v = NULL;
     VDATA        *vs = NULL;
     int32 ret_value = 0;
-#ifdef LATER
     CONSTR(FUNC, "VSfind");
-#endif
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSfind);
-#endif /* HAVE_PABLO */
+    /* check for null vdata name */
+    if (vsname == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* process through Vdatas in file */
     while (FAIL != (vsid = VSgetid(f, vsid)))
@@ -1145,10 +1051,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSfind);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSfind */
 
@@ -1173,13 +1075,11 @@ Vfindclass(HFILEID f,           /* IN: file id */
     vginstance_t *v = NULL;
     VGROUP       *vg = NULL;
     int32       ret_value = 0;
-#ifdef LATER
     CONSTR(FUNC, "Vfindclass");
-#endif
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_Vfindclass);
-#endif /* HAVE_PABLO */
+    /* check for null vgroup class */
+    if (vgclass == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* process through Vgroups in file */
     while (FAIL != (vgid = Vgetid(f, vgid)))
@@ -1204,10 +1104,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF( PABLO_mask, ID_Vfindclass);
-#endif /* HAVE_PABLO */
-
   return ret_value;    
 }	/* Vfindclass */
 
@@ -1232,13 +1128,11 @@ VSfindclass(HFILEID f,           /* IN: file id */
     vsinstance_t *v = NULL;
     VDATA        *vs = NULL;
     int32        ret_value = 0;
-#ifdef LATER
-    CONSTR(FUNC, "VSfind");
-#endif
+    CONSTR(FUNC, "VSfindclass");
 
-#ifdef HAVE_PABLO
-  TRACE_ON(PABLO_mask,ID_VSfindclass);
-#endif /* HAVE_PABLO */
+    /* check for null vdata class */
+    if (vsclass == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* process through Vdatas in file */
     while (FAIL != (vsid = VSgetid(f, vsid)))
@@ -1263,13 +1157,197 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(PABLO_mask, ID_VSfindclass);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSfindclass */
 
+/* ----------------------------------------------------------------- 
+NAME
+   VSsetblocksize -- sets the block size of the linked-block element.
+
+USAGE
+   intn VSsetblocksize(vkey, block_size)
+   int32 vkey;		IN: vdata key
+   int32 block_size	IN: length to be used for each linked-block
+   
+DESCRIPTION
+   Sets the size of the blocks, that are after the first block, of a 
+   linked-block element used for storing a vdata.  This routine is 
+   to be called before the first write to the vdata to change the block 
+   size from the default value HDF_APPENDABLE_BLOCK_LEN (4096).  Once the
+   linked-block element is created, the block size cannot be changed.
+
+RETURNS
+   Returns SUCCEED/FAIL
+
+MODIFICATION
+   BMR - added in June 2001 to fix bug# 267
+
+---------------------------------------------------------------------*/
+intn
+VSsetblocksize(	int32 vkey, /* IN: vdata key */
+		int32 block_size) /* length to be used for each linked-block */
+{
+    vsinstance_t *w = NULL;
+    VDATA        *vs = NULL;
+    intn        ret_value = SUCCEED;
+    CONSTR(FUNC, "VSsetblocksize");
+
+    /* clear error stack */
+    HEclear();
+
+    /* check if the given vdata id is part of vdata group */
+    if (HAatom_group(vkey) != VSIDGROUP)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* get vdata instance */
+    if (NULL == (w = (vsinstance_t *) HAatom_object(vkey)))
+        HGOTO_ERROR(DFE_NOVS, FAIL);
+
+    /* get vdata itself and check it */
+    vs = w->vs;
+    if ((vs == NULL) || (vs->otag != VSDESCTAG))
+      HGOTO_ERROR(DFE_ARGS,FAIL);
+
+    /* internal routine handles the actual setting */
+    if (HLsetblockinfo(vs->aid, block_size, -1) == FAIL)
+        HGOTO_ERROR(DFE_INTERNAL, FAIL);
+
+done:
+  if(ret_value == FAIL)
+    { /* Error condition cleanup */
+
+    } /* end if */
+
+  /* Normal function cleanup */
+  return ret_value;
+}       /* VSsetblocksize */
+
+/* ----------------------------------------------------------------- 
+NAME
+   VSsetnumblocks -- sets the number of blocks for a linked-block element.
+
+USAGE
+   intn VSsetnumblocks(vkey, num_blocks)
+   int32 vkey;		IN: vdata key
+   int32 num_blocks	IN: number of blocks to be used for the linked-block
+			    element
+   
+DESCRIPTION
+   Sets the number of blocks of a linked-block element used for storing
+   a vdata.  This routine is to be called before the first write to the
+   vdata to change the number of blocks from the default value
+   HDF_APPENDABLE_BLOCK_NUM (16).  Once the linked-block element is
+   created, the number of blocks cannot be changed.
+
+RETURNS
+   Returns SUCCEED/FAIL
+
+MODIFICATION
+   BMR - added in June 2001 to fix bug# 267
+
+---------------------------------------------------------------------*/
+intn
+VSsetnumblocks( int32 vkey, /* IN: vdata key */
+		int32 num_blocks) /* number of blocks the element can have */
+{
+    vsinstance_t *w = NULL;
+    VDATA        *vs = NULL;
+    intn        ret_value = SUCCEED;
+    CONSTR(FUNC, "VSsetnumblocks");
+
+    /* clear error stack */
+    HEclear();
+
+    /* check if the given vdata id is part of vdata group */
+    if (HAatom_group(vkey) != VSIDGROUP)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* get vdata instance */
+    if (NULL == (w = (vsinstance_t *) HAatom_object(vkey)))
+        HGOTO_ERROR(DFE_NOVS, FAIL);
+
+    /* get vdata itself and check it */
+    vs = w->vs;
+    if ((vs == NULL) || (vs->otag != VSDESCTAG))
+      HGOTO_ERROR(DFE_ARGS,FAIL);
+
+    /* internal routine handles the actual setting */
+    if (HLsetblockinfo(vs->aid, -1, num_blocks) == FAIL)
+        HGOTO_ERROR(DFE_INTERNAL, FAIL);
+
+done:
+  if(ret_value == FAIL)
+    { /* Error condition cleanup */
+
+    } /* end if */
+
+  /* Normal function cleanup */
+  return ret_value;
+}       /* VSsetnumblocks */
+
+/* ----------------------------------------------------------------- 
+NAME
+   VSgetblockinfo -- retrieves the block size and the number of blocks 
+		     of a linked-block element.
+
+USAGE
+   intn VSgetblockinfo(vkey, block_size, num_blocks)
+   int32 vkey		IN: vdata key
+   int32* block_size	OUT: the linked-block size
+   int32* num_blocks	OUT: the number of blocks the element has
+   
+DESCRIPTION
+   Retrieves the block size and the number of blocks of a linked-block
+   element used for storing a vdata.  A NULL can be passed in for
+   unwanted value.
+
+RETURNS
+   Returns SUCCEED/FAIL
+
+MODIFICATION
+   BMR - added in June 2001 to fix bug# 267
+
+---------------------------------------------------------------------*/
+intn
+VSgetblockinfo(int32 vkey, /* IN: vdata id */
+               int32* block_size, /* OUT: length used for each linked-block */
+               int32* num_blocks) /* OUT: number of blocks the element has */
+{
+    vsinstance_t *w = NULL;
+    VDATA        *vs = NULL;
+    intn        ret_value = SUCCEED;
+    CONSTR(FUNC, "VSgetblockinfo");
+
+    /* clear error stack */
+    HEclear();
+
+    /* check if vdata is part of vdata group */
+    if (HAatom_group(vkey) != VSIDGROUP)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* get vdata instance */
+    if (NULL == (w = (vsinstance_t *) HAatom_object(vkey)))
+        HGOTO_ERROR(DFE_NOVS, FAIL);
+
+    /* get vdata itself and check it */
+    vs = w->vs;
+    if ((vs == NULL) || (vs->otag != VSDESCTAG))
+      HGOTO_ERROR(DFE_ARGS,FAIL);
+
+    /* internal routine handles the actual retrieval */
+    if (HLgetblockinfo(vs->aid, block_size, num_blocks) == FAIL)
+        HGOTO_ERROR(DFE_INTERNAL, FAIL);
+
+done:
+  if(ret_value == FAIL)
+    { /* Error condition cleanup */
+
+    } /* end if */
+
+  /* Normal function cleanup */
+  return ret_value;
+}       /* VSgetblockinfo */
+
 /* ------------------------------- Vsetzap -------------------------------- */
 /*
  * Vsetzap: Useless now. Maintained for back compatibility.
