@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.42 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: vgf.c,v 1.42 2000/02/29 21:35:30 koziol Exp $ */
+/* $Id: vgf.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*-----------------------------------------------------------------------------
   FUNCTION NAMEING CONVENTION:(For the most part true)
@@ -46,6 +47,7 @@ static char RcsId[] = "@(#)$Revision: 1.42 $";
 
 #define VSET_INTERFACE
 #include "hdf.h"
+#include "hproto_fortran.h"
 
 /*
    **  remove trailing blanks from a string. input argument is a  string
@@ -1453,3 +1455,86 @@ nvdtrc(intf * vkey, intf * tag, intf * ref)
        HDfree(class_name);
        return(ret);
 } 
+/*------------------------------------------------------------------------
+ *       Name:      vscsetblsz
+ *       Purpose:   calls VSsetblocksize
+ *       Inputs:    id    -  vdata identifier
+ *                  block_size - size of the block
+ *       Returns:   0 if succeeds, -1 if fails
+ *       Users:     HDF Fortran programmers
+ ---------------------------------------------------------------------*/
+     FRETVAL (intf)
+#ifdef PROTOTYPE
+       nvscsetblsz( intf *id , intf *block_size)
+#else
+       nvscsetblsz (id, block_size)
+               intf   *id;
+               intf   *block_size;
+#endif /* PROTOTYPE */
+
+{
+       intf  ret = -1;
+       intn c_ret;	
+
+       c_ret = VSsetblocksize( *id, *block_size);
+       if(c_ret == 0) ret = 0;
+       return(ret);
+} 
+/*------------------------------------------------------------------------
+ *       Name:      vscsetnmbl
+ *       Purpose:   calls VSsetnumblocks
+ *       Inputs:    id    -  vdata identifier
+ *                  num_blocks - number of blocks
+ *       Returns:   0 if succeeds, -1 if fails
+ *       Users:     HDF Fortran programmers
+ ---------------------------------------------------------------------*/
+     FRETVAL (intf)
+#ifdef PROTOTYPE
+       nvscsetnmbl( intf *id , intf *num_blocks)
+#else
+       nvscsetnmbl (id, num_blocks)
+               intf   *id;
+               intf   *num_blocks;
+#endif /* PROTOTYPE */
+
+{
+       intf  ret;
+       intn  c_ret;
+
+       c_ret = VSsetnumblocks( *id, *num_blocks);
+       if(c_ret == 0) ret = 0;
+       return(ret);
+} 
+/*------------------------------------------------------------------------
+ *       Name:      vscgblinfo
+ *       Purpose:   calls VSgetblockinfo
+ *       Inputs:    id    -  vdata identifier
+ *                  block_size - size of the block
+ *                  num_blocks - number of blocks
+ *       Returns:   0 if succeeds, -1 if fails
+ *       Users:     HDF Fortran programmers
+ ---------------------------------------------------------------------*/
+     FRETVAL (intf)
+#ifdef PROTOTYPE
+       nvscgblinfo( intf *id , intf *block_size, intf *num_blocks)
+#else
+       nvscgblinfo (id, block_size, num_blocks)
+               intf   *id;
+               intf   *block_size; 
+               intf   *num_blocks;
+#endif /* PROTOTYPE */
+
+{
+       intf  ret = -1;
+        intn c_ret;
+	int32 c_block_size;
+        int32 c_num_blocks;
+
+       c_ret = VSgetblockinfo( *id, &c_block_size, &c_num_blocks);
+       if (c_ret == 0) {
+       		*block_size = c_block_size;
+       	        *num_blocks = c_num_blocks;
+       	      	ret = 0;
+       }
+       return(ret);
+} 
