@@ -1,24 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.95 $";
-#endif
-
-/* $Id: vgp.c,v 1.95 1998/09/02 21:09:40 acheng Exp $ */
-#ifdef HAVE_PABLO
-#define HDF_mask V_mask
+static char RcsId[] = "@(#)$Revision: 5147 $";
 #endif
 
+/* $Id: vgp.c 5147 2009-01-17 06:00:43Z bmribler $ */
 /*****************************************************************************
 
  file - vgp.c
@@ -88,6 +85,7 @@ EXPORTED ROUTINES
  Vgetid       -- Given a vgroup's id, returns the next vgroup's id in the file.
  Vgetnext     -- Given the id of an entry from a vgroup vg, looks in vg 
                   for the next entry after it, and returns its id.
+ Vgetnamelen  -- Retrieves the length of the vgroup's name.
  Vgetname     -- Returns the vgroup's name.
  Vgetclass    -- Returns the vgroup's class name .
  Vinquire     -- General inquiry routine for VGROUP. 
@@ -154,7 +152,7 @@ static vginstance_t *vginstance_free_list = NULL;
     VIget_vgroup_node -- allocate a new VGROUP record
 
  DESCRIPTION
-    Return an pointer to a new VGROUP to use for a new VGID.
+    Return a pointer to a new VGROUP to use for a new VGID.
 
  RETURNS
     returns VGROUP record pointer or NULL if failed.
@@ -437,6 +435,10 @@ Load_vfile(HFILEID f /* IN: file handle */)
     if (aid != FAIL)
         Hendaccess(aid);
 
+    /* clear error stack - this is to remove the faux errors about DD not
+       found from when Hstartread is called on a new file */
+    HEclear();
+
     /* load all the vs's  tag/refs from file */
     vf->vstabn = 0;
     vf->vstree = tbbtdmake(vcompare, sizeof(int32), TBBT_FAST_INT32_COMPARE);
@@ -483,6 +485,10 @@ Load_vfile(HFILEID f /* IN: file handle */)
     if (aid != FAIL)
         Hendaccess(aid);
 
+    /* clear error stack - this is to remove the faux errors about DD not
+       found from when Hstartread is called on a new file */
+    HEclear();
+
     /* file may be incompatible with vset version 2.x. Need to check it */
     if (((int32) 0 == vf->vgtabn) && ((int32) 0 == vf->vstabn))
       {
@@ -634,6 +640,9 @@ vdestroynode(VOIDP n /* IN: node to free */)
                 HDfree((VOIDP) vg->tag);
                 HDfree((VOIDP) vg->ref);
 
+                if (vg->vgname != NULL)
+                    HDfree((VOIDP) vg->vgname);
+
                 if (vg->alist != NULL)
                     HDfree((VOIDP) vg->alist);
 
@@ -705,10 +714,6 @@ Vinitialize(HFILEID f /* IN: file handle */)
     intn   ret_value = SUCCEED;
     CONSTR(FUNC, "Vinitialize");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_Vinitialize);
-#endif /* HAVE_PABLO */
-  
     /* clear error stack */
     HEclear();
 
@@ -730,10 +735,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vinitialize, NoDSid, NULL, HDF_NULL_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 } /* Vinitialize() */
 
@@ -755,10 +756,6 @@ Vfinish(HFILEID f /* IN: file handle */)
   intn    ret_value = SUCCEED;
   CONSTR(FUNC, "Vfinish");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vfinish);
-#endif /* HAVE_PABLO */
-
   /* clear error stack */
   HEclear();
 
@@ -773,10 +770,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vfinish, NoDSid, NULL, HDF_NULL_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 } /* Vfinish() */
 
@@ -869,8 +862,8 @@ vexistvg(HFILEID f,   /* IN: file handle */
    *
    *    Fields of VGROUP  that gets stored in HDF as a DFTAG_VG data object:
    *            int16           nvelt (no of entries )
-   *            char            vgname[MAXVGNAMELEN]
-   *            char     vgclass[MAXVGNAMELEN]
+   *            char*           vgname
+   *            char            vgclass[MAXVGNAMELEN]
    *            int16           tag[1..nvelt]
    *            int16           ref[1..nvelt]
    *    (fields for version 4) 
@@ -886,7 +879,7 @@ NAME
    vpackvg
 
 DESCRIPTION
-   extracts fields from  a VGROUP struct vg and pack the fields
+   Extracts fields from a VGROUP struct vg and packs the fields
    into array buf in preparation for storage in the HDF file.
 
 RETRUNS   
@@ -902,14 +895,11 @@ vpackvg(VGROUP * vg, /* IN: */
     CONSTR(FUNC, "vpackvg");
 #endif
     uintn  i;
-    int16 slen;
+    int16 slen = 0;
+    uint16 temp_len = 0;
     uint8 *bb = NULL;
     int32 ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_vpackvg);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -927,18 +917,22 @@ vpackvg(VGROUP * vg, /* IN: */
         UINT16ENCODE(bb, vg->ref[i]);
 
     /* save the vgnamelen and vgname - omit the null */
-    slen = HDstrlen(vg->vgname);
-    UINT16ENCODE(bb, slen);
+    if (vg->vgname != NULL)
+        slen = HDstrlen(vg->vgname);
+    temp_len = slen > 0 ? slen : 0;
+    UINT16ENCODE(bb, temp_len);
 
-    HDstrcpy((char *) bb, vg->vgname);
-    bb += slen;
+    if (vg->vgname != NULL)
+        HDstrcpy((char *) bb, vg->vgname);
+    bb += temp_len;
 
     /* save the vgclasslen and vgclass- omit the null */
     slen = HDstrlen(vg->vgclass);
-    UINT16ENCODE(bb, slen);
+    temp_len = slen > 0 ? slen : 0;
+    UINT16ENCODE(bb, temp_len);
 
     HDstrcpy((char *) bb, vg->vgclass);
-    bb += slen;
+    bb += temp_len;
 
     /* save the expansion tag/ref pair */
     UINT16ENCODE(bb, vg->extag);    /* the vg's expansion tag */
@@ -975,6 +969,7 @@ vpackvg(VGROUP * vg, /* IN: */
     /* but since files have been created with */
     /* it there (and the size calc. wrong) it */
     /* has to be left alone -QAK */
+
 #ifdef LATER
 done:
     if (ret_value == FAIL)
@@ -984,10 +979,6 @@ done:
 #endif /* LATER */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        HDF_TRACE_OFF(ID_vpackvg, NoDSid, NULL, HDF_NULL_ID );
-#endif /* HAVE_PABLO */
- 
   return ret_value;
 }   /* vpackvg */
 
@@ -1017,10 +1008,6 @@ vunpackvg(VGROUP * vg, /* IN/OUT: */
     int32 ret_value = SUCCEED;
     CONSTR(FUNC, "vunpackvg");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_vunpackvg);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1061,6 +1048,7 @@ vunpackvg(VGROUP * vg, /* IN/OUT: */
           /* retrieve vgname (and its len)  */
           UINT16DECODE(bb, uint16var);
 
+	  vg->vgname = (char *)HDmalloc(uint16var+1);
           HIstrncpy(vg->vgname, (char *) bb, (int32) uint16var + 1);
           bb += (size_t)uint16var;
 
@@ -1099,10 +1087,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        HDF_TRACE_OFF(ID_vunpackvg, NoDSid, NULL, HDF_NULL_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 
 }   /* vunpackvg */
@@ -1213,10 +1197,6 @@ Vattach(HFILEID f,             /* IN: file handle */
     atom_t      ret_value = FAIL;
     CONSTR(FUNC, "Vattach");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_Vattach);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1317,10 +1297,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vattach, NoDSid, NULL, HDF_NULL_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vattach */
 
@@ -1353,10 +1329,6 @@ Vdetach(int32 vkey /* IN: vgroup key */)
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "Vdetach");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_Vdetach);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1378,9 +1350,13 @@ Vdetach(int32 vkey /* IN: vgroup key */)
     /* no reason to check for access... (I hope) -QAK */
     if (vg->marked == 1)
       {
-          size_t need;
+          size_t need, vgnamelen=0;
+	  if (vg->vgname != NULL)
+	      vgnamelen = strlen(vg->vgname);
 
-          need = sizeof(VGROUP)+ (size_t)vg->nvelt*4 + (size_t)vg->nattrs*sizeof(vg_attr_t) + 1;
+          need = sizeof(VGROUP)
+		+ vgnamelen	/* vgname dynamic, vpackvg omits null */
+		+ (size_t)vg->nvelt*4 + (size_t)vg->nattrs*sizeof(vg_attr_t) + 1;
           if(need > Vgbufsize)
             {
                 Vgbufsize = need;
@@ -1435,10 +1411,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vdetach,vkey,NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vdetach */
 
@@ -1471,10 +1443,6 @@ Vinsert(int32 vkey,      /* IN: vgroup key */
     int32       ret_value = SUCCEED;
     CONSTR(FUNC, "Vinsert");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_Vinsert);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1555,10 +1523,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vinsert,vkey,NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vinsert */
 
@@ -1662,10 +1626,6 @@ Vinqtagref(int32 vkey, /* IN: vgroup key */
     intn       ret_value = FALSE;
     CONSTR(FUNC, "Vinqtagref");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_Vinqtagref);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1698,10 +1658,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vinqtagref,vkey,NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vinqtagref */
 
@@ -1740,10 +1696,6 @@ Vdeletetagref(int32 vkey, /* IN: vgroup key */
     If the case of duplicate tag/ref pairs the user can call Vinqtagref() 
     to see if there are more occurences and then delete them. */
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_Vdeletetagref);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1821,10 +1773,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-  HDF_TRACE_OFF(ID_Vdeletetagref, vkey,NULL, HDF_Vdata_ID);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vdeletetagref */
 
@@ -1848,10 +1796,6 @@ Vntagrefs(int32 vkey /* IN: vgroup key */)
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "Vntagrefs");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_Vntagrefs);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1877,10 +1821,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vntagrefs,vkey,NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vntagrefs */
 
@@ -1968,10 +1908,6 @@ Vgettagrefs(int32 vkey,       /* IN: vgroup key */
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "Vgettagrefs");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vgettagrefs);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -2006,10 +1942,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vgettagrefs,vkey,NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vgettagrefs */
 
@@ -2040,10 +1972,6 @@ Vgettagref(int32 vkey,   /* IN: vgroup key */
     intn       ret_value = SUCCEED;
     CONSTR(FUNC, "Vgettagref");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vgettagref);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -2073,10 +2001,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vgettagref,vkey,NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vgettagref */
 
@@ -2206,10 +2130,6 @@ Vaddtagref(int32 vkey, /* IN: vgroup key */
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "Vaddtagref");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vaddtagref);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -2244,10 +2164,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vaddtagref,vkey,NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vaddtagref */
 
@@ -2357,7 +2273,6 @@ NAME
 
 DESCRIPTION
    gives a name to the VGROUP vg.
-    truncates to max length of VGNAMELENMAX
 
 RETURNS
     RETURN VALUES: SUCCEED for success, FAIL for failure (big suprise, eh?)
@@ -2365,17 +2280,14 @@ RETURNS
 *******************************************************************************/
 int32
 Vsetname(int32 vkey,         /* IN: vgroup key */
-         const char *vgname  /* IN: name to set for vgrou */) 
+         const char *vgname  /* IN: name to set for vgroup */) 
 {
     vginstance_t *v = NULL;
     VGROUP       *vg = NULL;
+    uint16 name_len;
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "Vsetname");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_Vsetname);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -2392,8 +2304,10 @@ Vsetname(int32 vkey,         /* IN: vgroup key */
     if (vg == NULL || vg->access!='w')
         HGOTO_ERROR(DFE_BADPTR, FAIL);
 
-    /* copy the name over, upto VGNAMELENMAX in length */
-    HIstrncpy(vg->vgname, vgname, VGNAMELENMAX);
+    /* copy the name over */
+    name_len = HDstrlen(vgname);
+    vg->vgname = (char *)HDmalloc(name_len+1);
+    HIstrncpy(vg->vgname, vgname, name_len+1);
 
     vg->marked = TRUE;
 
@@ -2404,10 +2318,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vsetname, NoDSid, NULL, HDF_NULL_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* Vsetname */
 
@@ -2432,9 +2342,6 @@ Vsetclass(int32 vkey,          /* IN: vgroup key */
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "Vsetclass");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vsetclass);
-#endif /* HAVE_PABLO */
     /* clear error stack */
     HEclear();
 
@@ -2467,9 +2374,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vsetclass, vkey, vgclass , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
 
   return ret_value;
 }   /* Vsetclass */
@@ -2617,9 +2521,6 @@ Vgetid(HFILEID f,  /* IN: file handle */
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "Vgetid");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vgetid);
-#endif /* HAVE_PABLO */
 
     /* clear error stack */
     HEclear();
@@ -2671,9 +2572,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vgetid, vgid, NULL , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
 
   return ret_value;
 }   /* Vgetid */
@@ -2773,6 +2671,60 @@ done:
   return ret_value;
 }   /* Vgetnext  */
 
+/*******************************************************************************
+NAME
+   Vgetnamelen
+
+DESCRIPTION
+   Retrieves the length of the vgroup's name.
+
+RETURNS
+   Returns SUCCEED/FAIL
+   BMR - 2006/09/10
+   
+*******************************************************************************/
+int32
+Vgetnamelen(int32 vkey,   /* IN: vgroup key */
+	    uint16 *name_len /* OUT: length of vgroup's name */)
+{
+    vginstance_t *v = NULL;
+    VGROUP       *vg = NULL;
+    size_t       temp_len;
+    int32        ret_value = SUCCEED;
+    CONSTR(FUNC, "Vgetnamelen");
+
+
+    /* clear error stack */
+    HEclear();
+
+    /* check if vgroup is valid and the vgname */
+    if (HAatom_group(vkey)!=VGIDGROUP)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
+    /* get instance of vgroup */
+    if (NULL == (v = (vginstance_t *) HAatom_object(vkey)))
+        HGOTO_ERROR(DFE_NOVS, FAIL);
+
+    /* get vgroup itself and check */
+    vg = v->vg;
+    if (vg == NULL)
+        HGOTO_ERROR(DFE_BADPTR, FAIL);
+
+    /* obtain the name length */
+    temp_len = HDstrlen(vg->vgname);
+    *name_len = temp_len > 0 ? (uint16)temp_len : 0;
+
+done:
+  if(ret_value == FAIL)   
+    { /* Error condition cleanup */
+
+    } /* end if */
+
+  /* Normal function cleanup */
+
+  return ret_value;
+}   /* Vgetnamelen */
+
 /*******************************************************************************
 NAME
    Vgetname
@@ -2795,9 +2747,6 @@ Vgetname(int32 vkey,   /* IN: vgroup key */
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "Vgetname");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vgetname);
-#endif /* HAVE_PABLO */
 
     /* clear error stack */
     HEclear();
@@ -2825,9 +2774,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vgetname, vkey, vgname , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
 
   return ret_value;
 }   /* Vgetname */
@@ -2854,9 +2800,6 @@ Vgetclass(int32 vkey,    /* IN: vgroup key */
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "Vgetclass");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vgetclass);
-#endif /* HAVE_PABLO */
 
     /* clear error stack */
     HEclear();
@@ -2884,9 +2827,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vgetclass, vkey, vgclass , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
 
   return ret_value;
 }   /* Vgetclass */
@@ -2916,9 +2856,6 @@ Vinquire(int32 vkey,        /* IN: vgroup key */
     intn    ret_value = SUCCEED;
     CONSTR(FUNC, "Vinquire");
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_Vinquire);
-#endif /* HAVE_PABLO */
 
     /* clear error stack */
     HEclear();
@@ -2955,9 +2892,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_TRACE_OFF(ID_Vinquire, vkey, vgname , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
 
   return ret_value;
 }   /* Vinquire */
