@@ -1,23 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.52 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: vrw.c,v 1.52 1999/06/16 21:11:19 dwells Exp $ */
-#ifdef HAVE_PABLO
-#define PABLO_mask ID_vrw_c
-#endif
+/* $Id: vrw.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /***********************************************************************
 *
@@ -111,10 +109,6 @@ VSseek(int32 vkey,   /* IN: vdata key */
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "VSseek");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_VSseek);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -151,10 +145,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF( PABLO_mask, ID_VSseek );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* VSseek */
 
@@ -201,10 +191,6 @@ VSread(int32 vkey,       /* IN: vdata key */
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "VSread");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_VSread);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -479,10 +465,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF( PABLO_mask,ID_VSread);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSread */
 
@@ -533,10 +515,6 @@ VSwrite(int32 vkey,         /* IN: vdata key */
     int32       ret_value = SUCCEED;
     CONSTR(FUNC, "VSwrite");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(PABLO_mask,ID_VSwrite);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -819,10 +797,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        TRACE_OFF( PABLO_mask, ID_VSwrite );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* VSwrite */
 
