@@ -1,24 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.65 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: vsfld.c,v 1.65 1998/09/02 21:09:46 acheng Exp $ */
-
-#ifdef HAVE_PABLO
-#define HDF_mask VS_mask
-#endif
+/* $Id: vsfld.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*****************************************************************************
 * vsetf.c
@@ -95,9 +92,10 @@ VSsetfields(int32 vkey, const char *fields)
     intn       ret_value = FAIL;
     CONSTR(FUNC, "VSsetfields");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_VSsetfields);
-#endif /* HAVE_PABLO */
+    /* check if a NULL field list is passed in, then return with
+       error (bug #554) - BMR 4/30/01 */
+    if (fields == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     if (HAatom_group(vkey)!=VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -121,115 +119,118 @@ VSsetfields(int32 vkey, const char *fields)
      * write to an empty vdata : set the write list but do not set the
      *   read list cuz there is nothing there to read yet...
      */
-    if ((vs->access == 'w') && (vs->nvertices == 0))
+    if (vs->access == 'w')
        {
-          wlist=&(vs->wlist);
-          if (wlist->n == 0) /* fields not set yet, Sept. 96. */
-            /* do not re-set fields if they were already set. */
-          {
-              wlist->ivsize = 0;
-              wlist->n = 0;
+        if (vs->nvertices == 0)
+           {
+              wlist=&(vs->wlist);
+              if (wlist->n == 0) /* fields not set yet, Sept. 96. */
+                /* do not re-set fields if they were already set. */
+              {
+                  wlist->ivsize = 0;
+                  wlist->n = 0;
 
-          /* allocate space for the internal WRITELIST structures */
-              /* Allocate buffer to hold all the int16/uint16 arrays */
-              if((wlist->bptr=HDmalloc(sizeof(uint16)*(size_t)(ac*5)))==NULL)
-                  HGOTO_ERROR(DFE_NOSPACE,FAIL);
+              /* allocate space for the internal WRITELIST structures */
+                  /* Allocate buffer to hold all the int16/uint16 arrays */
+                  if((wlist->bptr=HDmalloc(sizeof(uint16)*(size_t)(ac*5)))==NULL)
+                      HGOTO_ERROR(DFE_NOSPACE,FAIL);
 
-              /* Use buffer to support the other arrays */
-              wlist->type=(int16 *)wlist->bptr;
-              wlist->off=(uint16 *)wlist->type+ac;
-              wlist->isize=wlist->off+ac;
-              wlist->order=wlist->isize+ac;
-              wlist->esize=wlist->order+ac;
-              if((wlist->name=HDmalloc(sizeof(char *)*(size_t)ac))==NULL)
-                {
-                  HDfree(wlist->bptr);
-                  HGOTO_ERROR(DFE_NOSPACE,FAIL);
-                } /* end if */
+                  /* Use buffer to support the other arrays */
+                  wlist->type=(int16 *)wlist->bptr;
+                  wlist->off=(uint16 *)wlist->type+ac;
+                  wlist->isize=wlist->off+ac;
+                  wlist->order=wlist->isize+ac;
+                  wlist->esize=wlist->order+ac;
+                  if((wlist->name=HDmalloc(sizeof(char *)*(size_t)ac))==NULL)
+                    {
+                      HDfree(wlist->bptr);
+                      HGOTO_ERROR(DFE_NOSPACE,FAIL);
+                    } /* end if */
 
-              for (i = 0; i < ac; i++)
-                {
-                    found = FALSE;
-                /* --- first look in the user's symbol table --- */
-                    for (j = 0; j < vs->nusym; j++)
-                        if (!HDstrcmp(av[i], vs->usym[j].name))
-                          {
-                              found = TRUE;
-                            
-                              if((wlist->name[wlist->n]=HDstrdup(vs->usym[j].name))==NULL)
-                               {
-                                  HDfree(wlist->name);
-                                  HDfree(wlist->bptr);
-                                  HGOTO_ERROR(DFE_NOSPACE,FAIL);
-                                } /* end if */
-                              order = vs->usym[j].order;
-                              wlist->type[wlist->n] = vs->usym[j].type;
-                              wlist->order[wlist->n] = order;
+                  for (i = 0; i < ac; i++)
+                    {
+                        found = FALSE;
+                    /* --- first look in the user's symbol table --- */
+                        for (j = 0; j < vs->nusym; j++)
+                            if (!HDstrcmp(av[i], vs->usym[j].name))
+                              {
+                                  found = TRUE;
+                                
+                                  if((wlist->name[wlist->n]=HDstrdup(vs->usym[j].name))==NULL)
+                                   {
+                                      HDfree(wlist->name);
+                                      HDfree(wlist->bptr);
+                                      HGOTO_ERROR(DFE_NOSPACE,FAIL);
+                                    } /* end if */
+                                  order = vs->usym[j].order;
+                                  wlist->type[wlist->n] = vs->usym[j].type;
+                                  wlist->order[wlist->n] = order;
 
-                              value = order * DFKNTsize(vs->usym[j].type | DFNT_NATIVE);
-                              if (value == FAIL)
-                                  HGOTO_ERROR(DFE_BADFIELDS, FAIL);
-                              wlist->esize[wlist->n] = (uint16) value;
-
-                              value = order * vs->usym[j].isize;
-                              if (value > MAX_FIELD_SIZE)
-                                  HGOTO_ERROR(DFE_BADFIELDS, FAIL);
-                              wlist->isize[wlist->n] = (uint16) value;
-
-                              value = (int32) wlist->ivsize + (int32) (wlist->isize[wlist->n]);
-                              if (value > MAX_FIELD_SIZE)
-                                  HGOTO_ERROR(DFE_BADFIELDS, FAIL);
-                              wlist->ivsize = (uint16) value;
-
-                              wlist->n++;
-                              break;
-                          }
-
-                /* --- now look in the reserved symbol table --- */
-                    if (!found)
-                      {
-                          for (j = 0; j < (intn)NRESERVED; j++)
-                              if (!HDstrcmp(av[i], rstab[j].name))
-                                {
-                                    found = TRUE;
-
-                                    if((wlist->name[wlist->n]=HDstrdup(rstab[j].name))==NULL)
-                                      {
-                                        HDfree(wlist->name);
-                                        HDfree(wlist->bptr);
-                                        HGOTO_ERROR(DFE_NOSPACE,FAIL);
-                                      } /* end if */
-                                    order = rstab[j].order;
-                                    wlist->type[wlist->n] = rstab[j].type;
-                                    wlist->order[wlist->n] = order;
-                                    value = order * DFKNTsize(rstab[j].type | DFNT_NATIVE);
-                                    if (value == FAIL)
+                                  value = order * DFKNTsize(vs->usym[j].type | DFNT_NATIVE);
+                                  if (value == FAIL)
                                       HGOTO_ERROR(DFE_BADFIELDS, FAIL);
-                                    wlist->esize[wlist->n] = (uint16) value;
-                                    wlist->isize[wlist->n] = (uint16) (order * rstab[j].isize);
-                                    wlist->ivsize += (uint16) (wlist->isize[wlist->n]);
-                                    wlist->n++;
-                                    break;
-                                }
-                      }
-                    if (!found)     /* field is not a defined field - error  */
-                        HGOTO_ERROR(DFE_BADFIELDS, FAIL);
-                }
+                                  wlist->esize[wlist->n] = (uint16) value;
 
-          /* *********************************************************** */
-          /* compute and save the fields' offsets */
-               for (uj = 0, i = 0; i < wlist->n; i++)
-                {
-                    wlist->off[i] = (uint16) uj;
-                    uj += wlist->isize[i];
-                }
+                                  value = order * vs->usym[j].isize;
+                                  if (value > MAX_FIELD_SIZE)
+                                      HGOTO_ERROR(DFE_BADFIELDS, FAIL);
+                                  wlist->isize[wlist->n] = (uint16) value;
 
-              vs->marked = TRUE; /* mark vdata as being modified */
-              vs->new_h_sz = TRUE; /* mark vdata header size being changed */
+                                  value = (int32) wlist->ivsize + (int32) (wlist->isize[wlist->n]);
+                                  if (value > MAX_FIELD_SIZE)
+                                      HGOTO_ERROR(DFE_BADFIELDS, FAIL);
+                                  wlist->ivsize = (uint16) value;
 
-              HGOTO_DONE(SUCCEED); /* OK */
-          } /* if wlist->n == 0 */
-      }     /* writing to empty vdata */
+                                  wlist->n++;
+                                  break;
+                              }
+
+                    /* --- now look in the reserved symbol table --- */
+                        if (!found)
+                          {
+                              for (j = 0; j < (intn)NRESERVED; j++)
+                                  if (!HDstrcmp(av[i], rstab[j].name))
+                                    {
+                                        found = TRUE;
+
+                                        if((wlist->name[wlist->n]=HDstrdup(rstab[j].name))==NULL)
+                                          {
+                                            HDfree(wlist->name);
+                                            HDfree(wlist->bptr);
+                                            HGOTO_ERROR(DFE_NOSPACE,FAIL);
+                                          } /* end if */
+                                        order = rstab[j].order;
+                                        wlist->type[wlist->n] = rstab[j].type;
+                                        wlist->order[wlist->n] = order;
+                                        value = order * DFKNTsize(rstab[j].type | DFNT_NATIVE);
+                                        if (value == FAIL)
+                                          HGOTO_ERROR(DFE_BADFIELDS, FAIL);
+                                        wlist->esize[wlist->n] = (uint16) value;
+                                        wlist->isize[wlist->n] = (uint16) (order * rstab[j].isize);
+                                        wlist->ivsize += (uint16) (wlist->isize[wlist->n]);
+                                        wlist->n++;
+                                        break;
+                                    }
+                          }
+                        if (!found)     /* field is not a defined field - error  */
+                            HGOTO_ERROR(DFE_BADFIELDS, FAIL);
+                    }
+
+              /* *********************************************************** */
+              /* compute and save the fields' offsets */
+                   for (uj = 0, i = 0; i < wlist->n; i++)
+                    {
+                        wlist->off[i] = (uint16) uj;
+                        uj += wlist->isize[i];
+                    }
+
+                  vs->marked = TRUE; /* mark vdata as being modified */
+                  vs->new_h_sz = TRUE; /* mark vdata header size being changed */
+
+                  HGOTO_DONE(SUCCEED); /* OK */
+              } /* if wlist->n == 0 */
+          } /* writing to empty vdata */
+      } /* writing to vdata */
 
     /*
      *   No matter the access mode, if there are elements in the VData
@@ -271,10 +272,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        HDF_MASK_TRACE_OFF(VS_mask, ID_VSsetfields, vkey, NULL , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSsetfields */
 
@@ -297,10 +294,6 @@ VSfdefine(int32 vkey, const char *field, int32 localtype, int32 order)
     intn       ret_value = SUCCEED;
     CONSTR(FUNC, "VSfdefine");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_VSfdefine);
-#endif /* HAVE_PABLO */
-
     if (HAatom_group(vkey)!=VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
@@ -323,7 +316,7 @@ VSfdefine(int32 vkey, const char *field, int32 localtype, int32 order)
     /*
      ** check for any duplicates
      */
-#ifdef QAK
+#ifdef OLD_WAY
 /* It's OK to over-ride pre-defined symbols with the user's own -QAK */
     /* --- first look in the reserved symbol table --- */
     for (j = 0; j < NRESERVED; j++)
@@ -332,7 +325,7 @@ VSfdefine(int32 vkey, const char *field, int32 localtype, int32 order)
               if (localtype != rstab[j].type && order != rstab[j].order)
                   break;
           }
-#endif /* QAK */
+#endif /* OLD_WAY */
 
     /* --- then look in the user's symbol table --- */
     for (replacesym = 0, j = 0; j < vs->nusym; j++)
@@ -386,10 +379,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        HDF_MASK_TRACE_OFF(VS_mask, ID_VSfdefine, vkey, NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* VSfdefine */
 
@@ -406,10 +395,6 @@ VFnfields(int32 vkey)
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "VFnfields");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_VFnfields);
-#endif /* HAVE_PABLO */
-
     if (HAatom_group(vkey)!=VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS,FAIL);
 
@@ -430,10 +415,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-        HDF_MASK_TRACE_OFF(VF_mask, ID_VFnfields, vkey, NULL , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* VFnfields */
 
@@ -453,10 +434,6 @@ VFfieldname(int32 vkey, int32 index)
     char       *ret_value = NULL; /* FAIL */
     CONSTR(FUNC, "VFfieldname");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_VFfieldname);
-#endif /* HAVE_PABLO */
-
     if (HAatom_group(vkey)!=VSIDGROUP)
       HGOTO_ERROR(DFE_ARGS,NULL);
 
@@ -480,10 +457,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-  HDF_MASK_TRACE_OFF(VF_mask, ID_VFfieldname, vkey, ret_value , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VFfieldname */
 
@@ -501,10 +474,6 @@ VFfieldtype(int32 vkey, int32 index)
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "VFfeildtype");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_VFfieldtype);
-#endif /* HAVE_PABLO */
-
     if (HAatom_group(vkey)!=VSIDGROUP)
       HGOTO_ERROR(DFE_ARGS,FAIL);
 
@@ -528,10 +497,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-      HDF_MASK_TRACE_OFF(VF_mask, ID_VFfieldtype, vkey, NULL , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VFfieldtype */
 
@@ -550,10 +515,6 @@ VFfieldisize(int32 vkey, int32 index)
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "VFfieldisize");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_VFfieldisize);
-#endif /* HAVE_PABLO */
-
     if (HAatom_group(vkey)!=VSIDGROUP)
       HGOTO_ERROR(DFE_ARGS,FAIL);
 
@@ -577,10 +538,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-     HDF_MASK_TRACE_OFF(VF_mask, ID_VFfieldisize, vkey, NULL , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VFfieldisize */
 
@@ -599,10 +556,6 @@ VFfieldesize(int32 vkey, int32 index)
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "VFfieldesize");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_VFfieldesize);
-#endif /* HAVE_PABLO */
-
     if (HAatom_group(vkey)!=VSIDGROUP)
       HGOTO_ERROR(DFE_ARGS,FAIL);
 
@@ -626,10 +579,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-  HDF_MASK_TRACE_OFF(VF_mask, ID_VFfieldesize, vkey, NULL , HDF_Vdata_ID );
-
-#endif /* HAVE_PABLO */
 
   return ret_value;
 }   /* VFfieldesize */
@@ -648,10 +597,6 @@ VFfieldorder(int32 vkey, int32 index)
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "VFfieldorder");
 
-#ifdef HAVE_PABLO
-    HDF_TRACE_ON(ID_VFfieldorder);
-#endif /* HAVE_PABLO */
-
     if (HAatom_group(vkey)!=VSIDGROUP)
       HGOTO_ERROR(DFE_ARGS,FAIL);
 
@@ -675,10 +620,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    HDF_MASK_TRACE_OFF(VF_mask, ID_VFfieldorder, vkey, NULL , HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* VFfieldorder */
 
@@ -822,10 +763,6 @@ intn VSfpack(int32 vsid, intn packtype, const char *fields_in_buf,
        int32 *offs; /* offset of buf fields in buf */
     }  blist;
 
-#ifdef HAVE_PABLO
-  HDF_TRACE_ON(ID_VSfpack);
-#endif /* HAVE_PABLO */
-
     if (HAatom_group(vsid)!=VSIDGROUP)
         HGOTO_ERROR(DFE_ARGS, FAIL);
     /* locate vs' index in vgtab */
@@ -980,10 +917,6 @@ done:
     if (fbufps != NULL)
        HDfree(fbufps);
 
-#ifdef HAVE_PABLO
-    HDF_MASK_TRACE_OFF(VS_mask, ID_VSfpack, vsid, NULL, HDF_Vdata_ID );
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }       /* VSfpack */
 /*--------------------------------------------------------- */
