@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.18 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: chunks.c,v 1.18 1997/11/05 19:39:19 koziol Exp $ */
+/* $Id: chunks.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*
  * This file tests the Special Chunking Element(HMCxxx) layer of the HDF library.
@@ -135,9 +136,6 @@ static uint8  outbuf_2[16] = {0,0,2,3,0,0,6,7,8,9,0,0,12,13,0,0};
 static    uint8      cptr3[4] = {10,11,14,15};
 static    uint8      cptr2[4] = {8,9,12,13};
 static    uint8      cptr1[4] = {2,3,6,7};
-#ifdef QAK
-static    uint8      cptr0[4] = {0,1,4,5};
-#endif /* QAK */
 
 /* for writing/verifying some chunks used in Test 6*/
 static uint8  chunk1[4] = { 0, 1, 2, 3};
@@ -237,7 +235,7 @@ test_chunks(void)
     /* Create file first */
     MESSAGE(5, printf("Creating a file %s\n", TESTFILE_NAME); );
     fid = Hopen(TESTFILE_NAME, DFACC_CREATE, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
 
     /*
@@ -275,7 +273,7 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill,  chunk array */
     aid1 = HMCcreate(fid, 1020, 2, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
 #if 0
     /* write 16 bytes out */
@@ -290,12 +288,12 @@ test_chunks(void)
     MESSAGE(5, printf("Wrote first 16 bytes to 2-D, uint8 chunked element to file\n"); );
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
 
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 #endif
 
@@ -311,28 +309,28 @@ test_chunks(void)
     MESSAGE(5, printf("Wrote first 12 bytes to 2-D, uint8 chunked element to file\n"); );
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
 
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 2-D chunked element again for writing\n"); );
 
     /* Open file for writing last 2 chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start write access   tag,  ref */
     aid1 = Hstartwrite(fid, 1020, 2, 16);
-    CHECK(aid1, FAIL, "Hstartwrite");
+    CHECK_VOID(aid1, FAIL, "Hstartwrite");
 
     /* Try writing to last chunk in the element */
     dims[0] = 1;
     dims[1] = 1;
     ret = HMCwriteChunk(aid1, dims, cptr3);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     MESSAGE(5, printf("Wrote to 4th chunk(4of4 chunks) in file\n"););
 
@@ -340,31 +338,31 @@ test_chunks(void)
     dims[0] = 1;
     dims[1] = 0;
     ret = HMCwriteChunk(aid1, dims, cptr2);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     MESSAGE(5, printf("Wrote to 3 chunk (3of4 chunks) in file\n"););
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 2-D, uint8 chunked element again for reading \n"); );
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 2);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -385,7 +383,7 @@ test_chunks(void)
 
     /* get special info about element */
     ret = HDget_special_info(aid1, &info_block);
-    CHECK(aid1, FAIL, "HDget_special_info");
+    CHECK_VOID(aid1, FAIL, "HDget_special_info");
 
     /* check special info */
     if (info_block.ndims != chunk[0].num_dims /* 2-D */)
@@ -442,11 +440,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     /* 
        2. Now create a new chunked 2-D element with same parameters
@@ -456,7 +454,7 @@ test_chunks(void)
 
     /* Open file for writing again */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     MESSAGE(5, printf("Test 2. Create another new element as a 2-D, uint8 chunked element\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
@@ -468,13 +466,13 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 3, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* Try writing to 2 chunk in the element */
     dims[0] = 1;
     dims[1] = 0;
     ret = HMCwriteChunk(aid1, dims, cptr2);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     MESSAGE(5, printf("Wrote to 3 chunk (3of4) in file\n"); );
 
@@ -482,33 +480,33 @@ test_chunks(void)
     dims[0] = 0;
     dims[1] = 1;
     ret = HMCwriteChunk(aid1, dims, cptr1);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     MESSAGE(5, printf("Wrote to 2nd chunk (2of4 chunks) in file\n"); );
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"); );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     /* Now reopen and read back 16 bytes */
     MESSAGE(5, printf("Open 2-D, uint8 chunked element again for reading \n"); );
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 3);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -552,11 +550,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"); );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 
     /* 
@@ -585,7 +583,7 @@ test_chunks(void)
 
     /* Open file for writing odd size chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     MESSAGE(5, printf("Test 3. Create another new element as a 2-D, uint8 chunked element\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
@@ -597,7 +595,7 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 5, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* write 16 bytes out */
     ret = Hwrite(aid1, 16, outbuf);
@@ -612,27 +610,27 @@ test_chunks(void)
     MESSAGE(5, printf("Wrote to 4of4 chunks (16 bytes) in file\n"););
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"); );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 2-D, uint8 chunked element again for reading\n"); );
 
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 5);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -676,11 +674,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"); );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 
     /* 
@@ -713,7 +711,7 @@ test_chunks(void)
 
     /* Open file for writing last odd size chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
     MESSAGE(5, printf("Test 4. Create another new element as a 3-D, uint8 chunked element(192 bytes)\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
                       0,(int)chunk[0].pdims[0].dim_length, 
@@ -727,7 +725,7 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 6, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* write only 112 bytes out */
     ret = Hwrite(aid1, 112, outbuf);
@@ -742,27 +740,27 @@ test_chunks(void)
     MESSAGE(5, printf("Wrote 112of192 bytes to 3-D, uint8 chunked element \n"); );
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the files\n");
             );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 3-D, uint8 chunked element again for reading\n"); );
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 6);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -784,7 +782,7 @@ test_chunks(void)
 
     /* get special info about element */
     ret = HDget_special_info(aid1, &info_block);
-    CHECK(aid1, FAIL, "HDget_special_info");
+    CHECK_VOID(aid1, FAIL, "HDget_special_info");
 
     /* check special info */
     if (info_block.ndims != chunk[0].num_dims /* 2-D */)
@@ -843,11 +841,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 
     /* 
@@ -884,7 +882,7 @@ test_chunks(void)
 
     /* Open file for writing last odd size chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     MESSAGE(5, printf("Test 5. Create another new element as a 3-D, uint8 chunked element(192bytes)\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
@@ -899,7 +897,7 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 7, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* Set max chunks to cache to 3x4 = 12 chunks */
     MESSAGE(5, printf("Set max # of chunks to cache for chunked element to 12 \n"); );
@@ -920,26 +918,26 @@ test_chunks(void)
 
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 3-D, uint8 chunked element again for reading\n"); );
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 7);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -1007,11 +1005,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"); );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 
     /* 
@@ -1056,7 +1054,7 @@ test_chunks(void)
 
     /* Open file for writing last odd size chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
     MESSAGE(5, printf("Test 6. Create another new element as a 3-D, uint8 chunked element(192 bytes)\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
                       0,(int)chunk[0].pdims[0].dim_length, 
@@ -1070,11 +1068,11 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 12, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid2 = HMCcreate(fid, 1020, 18, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* write 24 bytes out */
     ret = Hwrite(aid2, 24, u8_data);
@@ -1093,68 +1091,68 @@ test_chunks(void)
     dims[1] = 0;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk1);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 1;
     dims[1] = 0;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk4);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 0;
     dims[1] = 1;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk2);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 1;
     dims[1] = 1;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk5);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 0;
     dims[1] = 2;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk3);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 1;
     dims[1] = 2;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk6);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     /* end access */
     ret = Hendaccess(aid2);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the files\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 3-D, uint8 chunked element again for reading\n"); );
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 12);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* start read access   tag,  ref */
     aid2 = Hstartread(fid, 1020, 18);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -1176,7 +1174,7 @@ test_chunks(void)
 
     /* get special info about element */
     ret = HDget_special_info(aid1, &info_block);
-    CHECK(aid1, FAIL, "HDget_special_info");
+    CHECK_VOID(aid1, FAIL, "HDget_special_info");
 
     /* check special info */
     if (info_block.ndims != chunk[0].num_dims /* 2-D */)
@@ -1246,7 +1244,7 @@ test_chunks(void)
     dims[1] = 0;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -1268,7 +1266,7 @@ test_chunks(void)
     dims[1] = 1;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -1290,7 +1288,7 @@ test_chunks(void)
     dims[1] = 2;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -1312,7 +1310,7 @@ test_chunks(void)
     dims[1] = 0;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -1334,7 +1332,7 @@ test_chunks(void)
     dims[1] = 1;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -1356,7 +1354,7 @@ test_chunks(void)
     dims[1] = 2;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -1376,15 +1374,15 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     /* end access and close file */
     ret = Hendaccess(aid2);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 
     /* The following tests will work if Number type conversion
@@ -1431,7 +1429,7 @@ test_chunks(void)
 
     /* Open file for writing last odd size chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
     MESSAGE(5, printf("Test 7. Create another new element as a 3-D, uint16 chunked element(48 bytes)\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
                       0,(int)chunk[0].pdims[0].dim_length, 
@@ -1445,7 +1443,7 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 14, 1, fill_val_len, &fill_val_u16, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* write 48 bytes out */
     ret = Hwrite(aid1, 48, u16_data);
@@ -1461,21 +1459,21 @@ test_chunks(void)
 
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the files\n");
             );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 3-D, uint16 chunked element again for reading\n"); );
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 14);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* read back in buffer  */
     ret = Hread(aid1, 48, inbuf_u16);
@@ -1510,11 +1508,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 
     /* 
@@ -1556,7 +1554,7 @@ test_chunks(void)
 
     /* Open file for writing last odd size chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     MESSAGE(5, printf("Test 8. Create another new element as a 3-D, float32 chunked element(96 bytes)\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
@@ -1571,7 +1569,7 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 15, 1, fill_val_len, &fill_val_f32, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     if (aid1 == FAIL)
       {
@@ -1594,21 +1592,21 @@ test_chunks(void)
 
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the files\n");
             );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 3-D, float32 chunked element again for reading\n"); );
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 15);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* read back in buffer  */
     ret = Hread(aid1, 96, inbuf_f32);
@@ -1644,11 +1642,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 #endif /*  !(defined(UNICOS) || defined(_UNICOS) || defined(_CRAYMPP)) */
 
@@ -1697,7 +1695,7 @@ test_chunks(void)
 
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     MESSAGE(5, printf("Test 9. Create another new element as a 4-D, uint8 chunked element\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
@@ -1715,7 +1713,7 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 9, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* write 5000 bytes out */
     ret = Hwrite(aid1, 5000, outbuf);
@@ -1730,27 +1728,27 @@ test_chunks(void)
     MESSAGE(5, printf("Wrote 5000of10000 bytes to 4-D chunked element \n"); );
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     MESSAGE(5, printf("Open 4-D chunked element again for reading\n"); );
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 9);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -1825,11 +1823,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 #ifdef BIG_TEST
 
@@ -1860,12 +1858,12 @@ test_chunks(void)
 #if 0
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 #endif
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 10, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     for (j = 0; j < 12000; j++)
       {
@@ -1882,27 +1880,27 @@ test_chunks(void)
 
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the files\n");
             );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 10);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -1986,12 +1984,12 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the files\n");
             );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 #endif /* BIG_TEST */
 
@@ -2036,7 +2034,7 @@ test_chunks(void)
 
     /* Open file for writing odd size chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     MESSAGE(5, printf("Test 11. Create another new element as a 2-D, uint8 chunked, RLE Compressed element\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
@@ -2048,7 +2046,7 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 20, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* write 16 bytes out */
     ret = Hwrite(aid1, 16, outbuf);
@@ -2063,27 +2061,27 @@ test_chunks(void)
     MESSAGE(5, printf("Wrote to 4of4 chunks (16 bytes) in file\n"););
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"); );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 2-D, uint8 chunked, RLE Compressed element again for reading\n"); );
 
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 20);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -2127,11 +2125,11 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"); );
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     /* 
        12. Now create 3-D chunked, Compressed element with no partial chunks.
@@ -2179,7 +2177,7 @@ test_chunks(void)
 
     /* Open file for writing last odd size chunks now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
     MESSAGE(5, printf("Test 12. Create another new element as a 3-D, uint8 chunked, GZIP Compressed element(192 bytes)\n"););
     MESSAGE(5, printf(" dim_length[%d]=%d, chunk_length[%d]=%d \n",
                       0,(int)chunk[0].pdims[0].dim_length, 
@@ -2193,11 +2191,11 @@ test_chunks(void)
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid1 = HMCcreate(fid, 1020, 21, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* Create element     tag, ref,  nlevels, fill_len, fill, chunk array */
     aid2 = HMCcreate(fid, 1020, 22, 1, fill_val_len, &fill_val_u8, (HCHUNK_DEF *)chunk);
-    CHECK(aid1, FAIL, "HMCcreate");
+    CHECK_VOID(aid1, FAIL, "HMCcreate");
 
     /* write 24 bytes out */
     ret = Hwrite(aid2, 24, u8_data);
@@ -2216,68 +2214,68 @@ test_chunks(void)
     dims[1] = 0;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk1);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 1;
     dims[1] = 0;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk4);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 0;
     dims[1] = 1;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk2);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 1;
     dims[1] = 1;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk5);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 0;
     dims[1] = 2;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk3);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     dims[0] = 1;
     dims[1] = 2;
     dims[2] = 0;
     ret = HMCwriteChunk(aid1, dims, chunk6);
-    CHECK(ret, FAIL, "HMCwriteChunk");
+    CHECK_VOID(ret, FAIL, "HMCwriteChunk");
 
     /* end access */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     /* end access */
     ret = Hendaccess(aid2);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the files\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
     MESSAGE(5, printf("Open 3-D, uint8 chunked, GZIP Compressed element again for reading\n"); );
     /* Open file for reading now */
     fid = Hopen(TESTFILE_NAME, DFACC_RDWR, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     /* start read access   tag,  ref */
     aid1 = Hstartread(fid, 1020, 21);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* start read access   tag,  ref */
     aid2 = Hstartread(fid, 1020, 22);
-    CHECK(aid1, FAIL, "Hstartread");
+    CHECK_VOID(aid1, FAIL, "Hstartread");
 
     /* inquire about element */
     ret = Hinquire(aid1, &fileid, &tag, &ref, &length, &offset, &posn,
                    &acc_mode, &special);
 
-    CHECK(ret, FAIL, "Hinquire");
+    CHECK_VOID(ret, FAIL, "Hinquire");
     if (!special)
       {
           fprintf(stderr, "ERROR: Hinquire does not think element is special line %d\n",
@@ -2299,7 +2297,7 @@ test_chunks(void)
 
     /* get special info about element */
     ret = HDget_special_info(aid1, &info_block);
-    CHECK(aid1, FAIL, "HDget_special_info");
+    CHECK_VOID(aid1, FAIL, "HDget_special_info");
 
     /* check special info */
     if (info_block.ndims != chunk[0].num_dims /* 2-D */)
@@ -2369,7 +2367,7 @@ test_chunks(void)
     dims[1] = 0;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -2391,7 +2389,7 @@ test_chunks(void)
     dims[1] = 1;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -2413,7 +2411,7 @@ test_chunks(void)
     dims[1] = 2;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -2435,7 +2433,7 @@ test_chunks(void)
     dims[1] = 0;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -2457,7 +2455,7 @@ test_chunks(void)
     dims[1] = 1;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -2479,7 +2477,7 @@ test_chunks(void)
     dims[1] = 2;
     dims[2] = 0;
     ret = HMCreadChunk(aid2, dims, inbuf);
-    CHECK(ret, FAIL, "HMCreadChunk");
+    CHECK_VOID(ret, FAIL, "HMCreadChunk");
     if (ret != 4)
       {
           fprintf(stderr, "ERROR: HMCreadChunk returned the wrong length: %d\n", (int) ret);
@@ -2499,15 +2497,15 @@ test_chunks(void)
 
     /* end access and close file */
     ret = Hendaccess(aid1);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     /* end access and close file */
     ret = Hendaccess(aid2);
-    CHECK(ret, FAIL, "Hendaccess");
+    CHECK_VOID(ret, FAIL, "Hendaccess");
 
     MESSAGE(5, printf("Closing the file\n"););
     ret = Hclose(fid);
-    CHECK(ret, FAIL, "Hclose");
+    CHECK_VOID(ret, FAIL, "Hclose");
 
 
   done:
