@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.17 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: litend.c,v 1.17 1996/11/11 20:39:55 koziol Exp $ */
+/* $Id: litend.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 #include "tproto.h"
 
@@ -83,11 +84,21 @@ test_little_read(void)
     float64 *data_f64;
     int ret;
 
+    char        filename[512] = "";
+    char       *srcdir = getenv("srcdir");
+
     MESSAGE(5,printf("Testing Little-Endian Read Routines\n"););
 
     MESSAGE(10,printf("Testing Little-Endian INT8 Reading Routines\n"););
 
-    ret=DFSDgetdims(FILENAME,&rank,dimsizes,2);
+    /* Generate the correct name for the test file, by prepending the source path */
+    if (srcdir && ((strlen(srcdir) + strlen(FILENAME) + 1) < sizeof(filename))) {
+        strcpy(filename, srcdir);
+        strcat(filename, "/");
+    }
+    strcat(filename, FILENAME);
+
+    ret=DFSDgetdims(filename,&rank,dimsizes,2);
     RESULT("DFSDgetdims");
     if(dimsizes[0]!=CDIM_Y || dimsizes[1]!=CDIM_X) {
         fprintf(stderr, "Dimensions for INT8 data were incorrect\n");
@@ -102,7 +113,7 @@ test_little_read(void)
           } /* end if */
         else {
             data_i8=(int8 *)HDmalloc((size_t)(dimsizes[0]*dimsizes[1])*sizeof(int8));
-            ret=DFSDgetdata(FILENAME,rank,dimsizes,(VOIDP)data_i8);
+            ret=DFSDgetdata(filename,rank,dimsizes,(VOIDP)data_i8);
             RESULT("DFSDgetdata");
 
             if(HDmemcmp(cdata_i8,data_i8,CDIM_X*CDIM_Y*sizeof(int8))) {
@@ -115,7 +126,7 @@ test_little_read(void)
 
     MESSAGE(10,printf("Testing Little-Endian UINT8 Reading Routines\n"););
 
-    ret=DFSDgetdims(FILENAME,&rank,dimsizes,2);
+    ret=DFSDgetdims(filename,&rank,dimsizes,2);
     RESULT("DFSDgetdims");
     if(dimsizes[0]!=CDIM_Y || dimsizes[1]!=CDIM_X) {
         fprintf(stderr, "Dimensions for UINT8 data were incorrect\n");
@@ -130,7 +141,7 @@ test_little_read(void)
           } /* end if */
         else {
             data_u8=(uint8 *)HDmalloc((size_t)(dimsizes[0]*dimsizes[1])*sizeof(uint8));
-            ret=DFSDgetdata(FILENAME,rank,dimsizes,(VOIDP)data_u8);
+            ret=DFSDgetdata(filename,rank,dimsizes,(VOIDP)data_u8);
             RESULT("DFSDgetdata");
 
             if(HDmemcmp(cdata_u8,data_u8,CDIM_X*CDIM_Y*sizeof(uint8))) {
@@ -143,7 +154,7 @@ test_little_read(void)
 
     MESSAGE(10,printf("Testing Little-Endian INT16 Reading Routines\n"););
 
-    ret=DFSDgetdims(FILENAME,&rank,dimsizes,2);
+    ret=DFSDgetdims(filename,&rank,dimsizes,2);
     RESULT("DFSDgetdims");
     if(dimsizes[0]!=CDIM_Y || dimsizes[1]!=CDIM_X) {
         fprintf(stderr, "Dimensions for INT16 data were incorrect\n");
@@ -158,7 +169,7 @@ test_little_read(void)
           } /* end if */
         else {
             data_i16=(int16 *)HDmalloc((size_t)(dimsizes[0]*dimsizes[1])*sizeof(int16));
-            ret=DFSDgetdata(FILENAME,rank,dimsizes,(VOIDP)data_i16);
+            ret=DFSDgetdata(filename,rank,dimsizes,(VOIDP)data_i16);
             RESULT("DFSDgetdata");
 
             if(HDmemcmp(cdata_i16,data_i16,CDIM_X*CDIM_Y*sizeof(int16))) {
@@ -171,7 +182,7 @@ test_little_read(void)
 
     MESSAGE(10,printf("Testing Little-Endian UINT16 Reading Routines\n"););
 
-    ret=DFSDgetdims(FILENAME,&rank,dimsizes,2);
+    ret=DFSDgetdims(filename,&rank,dimsizes,2);
     RESULT("DFSDgetdims");
     if(dimsizes[0]!=CDIM_Y || dimsizes[1]!=CDIM_X) {
         fprintf(stderr, "Dimensions for UINT16 data were incorrect\n");
@@ -186,7 +197,7 @@ test_little_read(void)
           } /* end if */
         else {
             data_u16=(uint16 *)HDmalloc((size_t)(dimsizes[0]*dimsizes[1])*sizeof(uint16));
-            ret=DFSDgetdata(FILENAME,rank,dimsizes,(VOIDP)data_u16);
+            ret=DFSDgetdata(filename,rank,dimsizes,(VOIDP)data_u16);
             RESULT("DFSDgetdata");
 
             if(HDmemcmp(cdata_u16,data_u16,CDIM_X*CDIM_Y*sizeof(uint16))) {
@@ -199,7 +210,7 @@ test_little_read(void)
 
     MESSAGE(10,printf("Testing Little-Endian INT32 Reading Routines\n"););
 
-    ret=DFSDgetdims(FILENAME,&rank,dimsizes,2);
+    ret=DFSDgetdims(filename,&rank,dimsizes,2);
     RESULT("DFSDgetdims");
     if(dimsizes[0]!=CDIM_Y || dimsizes[1]!=CDIM_X) {
         fprintf(stderr, "Dimensions for INT32 data were incorrect\n");
@@ -214,7 +225,7 @@ test_little_read(void)
           } /* end if */
         else {
             data_i32=(int32 *)HDmalloc((size_t)(dimsizes[0]*dimsizes[1])*sizeof(int32));
-            ret=DFSDgetdata(FILENAME,rank,dimsizes,(VOIDP)data_i32);
+            ret=DFSDgetdata(filename,rank,dimsizes,(VOIDP)data_i32);
             RESULT("DFSDgetdata");
 
             if(HDmemcmp(cdata_i32,data_i32,CDIM_X*CDIM_Y*sizeof(int32))) {
@@ -227,7 +238,7 @@ test_little_read(void)
 
     MESSAGE(10,printf("Testing Little-Endian UINT32 Reading Routines\n"););
 
-    ret=DFSDgetdims(FILENAME,&rank,dimsizes,2);
+    ret=DFSDgetdims(filename,&rank,dimsizes,2);
     RESULT("DFSDgetdims");
     if(dimsizes[0]!=CDIM_Y || dimsizes[1]!=CDIM_X) {
         fprintf(stderr, "Dimensions for UINT32 data were incorrect\n");
@@ -242,7 +253,7 @@ test_little_read(void)
           } /* end if */
         else {
             data_u32=(uint32 *)HDmalloc((size_t)(dimsizes[0]*dimsizes[1])*sizeof(uint32));
-            ret=DFSDgetdata(FILENAME,rank,dimsizes,(VOIDP)data_u32);
+            ret=DFSDgetdata(filename,rank,dimsizes,(VOIDP)data_u32);
             RESULT("DFSDgetdata");
 
             if(HDmemcmp(cdata_u32,data_u32,CDIM_X*CDIM_Y*sizeof(uint32))) {
@@ -255,7 +266,7 @@ test_little_read(void)
 
     MESSAGE(10,printf("Testing Little-Endian FLOAT32 Reading Routines\n"););
 
-    ret=DFSDgetdims(FILENAME,&rank,dimsizes,2);
+    ret=DFSDgetdims(filename,&rank,dimsizes,2);
     RESULT("DFSDgetdims");
     if(dimsizes[0]!=CDIM_Y || dimsizes[1]!=CDIM_X) {
         fprintf(stderr, "Dimensions for FLOAT32 data were incorrect\n");
@@ -270,7 +281,7 @@ test_little_read(void)
           } /* end if */
         else {
             data_f32=(float32 *)HDmalloc((size_t)(dimsizes[0]*dimsizes[1])*sizeof(float32));
-            ret=DFSDgetdata(FILENAME,rank,dimsizes,(VOIDP)data_f32);
+            ret=DFSDgetdata(filename,rank,dimsizes,(VOIDP)data_f32);
             RESULT("DFSDgetdata");
 
             if(HDmemcmp(cdata_f32,data_f32,CDIM_X*CDIM_Y*sizeof(float32))) {
@@ -283,7 +294,7 @@ test_little_read(void)
 
     MESSAGE(10,printf("Testing Little-Endian FLOAT64 Reading Routines\n"););
 
-    ret=DFSDgetdims(FILENAME,&rank,dimsizes,2);
+    ret=DFSDgetdims(filename,&rank,dimsizes,2);
     RESULT("DFSDgetdims");
     if(dimsizes[0]!=CDIM_Y || dimsizes[1]!=CDIM_X) {
         fprintf(stderr, "Dimensions for FLOAT64 data were incorrect\n");
@@ -298,7 +309,7 @@ test_little_read(void)
           } /* end if */
         else {
             data_f64=(float64 *)HDmalloc((size_t)(dimsizes[0]*dimsizes[1])*sizeof(float64));
-            ret=DFSDgetdata(FILENAME,rank,dimsizes,(VOIDP)data_f64);
+            ret=DFSDgetdata(filename,rank,dimsizes,(VOIDP)data_f64);
             RESULT("DFSDgetdata");
 
 #if defined CONVEXNATIVE
