@@ -1,16 +1,17 @@
-C****************************************************************************
-C* NCSA HDF                                                                 *
-C* Software Development Group                                               *
-C* National Center for Supercomputing Applications                          *
-C* University of Illinois at Urbana-Champaign                               *
-C* 605 E. Springfield, Champaign IL 61820                                   *
-C*                                                                          *
-C* For conditions of distribution and use, see the accompanying             *
-C* hdf/COPYING file.                                                        *
-C*                                                                          *
-C****************************************************************************
+C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+C* Copyright by The HDF Group.                                               *
+C* Copyright by the Board of Trustees of the University of Illinois.         *
+C* All rights reserved.                                                      *
+C*                                                                           *
+C* This file is part of HDF.  The full HDF copyright notice, including       *
+C* terms governing use, modification, and redistribution, is contained in    *
+C* the files COPYING and Copyright.html.  COPYING can be found at the root   *
+C* of the source code distribution tree; Copyright.html can be found at      *
+C* http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+C* access to either file, you may request a copy from help@hdfgroup.org.     *
+C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 C
-C $Id: mgrf.f,v 1.27 2000/10/02 19:46:30 epourmal Exp $
+C $Id: mgrf.f 4932 2007-09-07 17:17:23Z bmribler $
 C
        subroutine mgrf (num_err)
 C
@@ -42,6 +43,8 @@ c      integer mgsattr
 	integer mgatinf, mggattr, mgfndat
       integer mgscatt, mgsnatt, mggcatt, mggnatt
       integer mgwcimg, mgrcimg
+      integer mggnluts
+      
       integer MFGR_INTERLACE_PIXEL, MFGR_INTERLACE_LINE,
      *      MFGR_INTERLACE_COMPONENT
 
@@ -100,6 +103,7 @@ c      integer mgsattr
       character attr_c(6), attr2_c(6)
       character cbuf(2,3,4), icbuf(2,3,4)
       integer i, j, k, ret, number_failed
+      integer n_pal
 
       DATA attr_c/'A','T','T','R','_','C'/
       DATA cbuf/'A','B','C','D','E','F','G','H','I','J','K','L',
@@ -134,7 +138,7 @@ C Initialize the image arrays
       do 157 i=1,2
           do 156 j=1,3
              do 155 k=1,4
-                 icbuf(k, j, i) = ' '
+                 icbuf(i,j,k) = ' '
 155          continue
 156       continue
 157   continue
@@ -241,7 +245,11 @@ C Select an image
       call VRFY(index,'mgn2ndx',number_failed)
       ri_id = mgselct(gr_id,index)
       call VRFY(ri_id,'mgselct',number_failed)
-
+      n_pal = mggnluts(ri_id)
+      call VRFY(ri_id,'mggnluts',number_failed)
+      if(n_pal .ne. 1) then
+         print *, 'Wrong number of palettes returned for IMAGE1'
+      endif
 C Get info about the image
       call MESSAGE(5,'Getting image information')
       ret = mggiinf(ri_id,IMAGE2,n_comp,nt,il,dims,n_attrs)
@@ -318,6 +326,11 @@ C Select a character image
       call VRFY(index,'mgn2ndx',number_failed)
       ri_id = mgselct(gr_id,index)
       call VRFY(ri_id,'mgselct',number_failed)
+      n_pal = mggnluts(ri_id)
+      call VRFY(ri_id,'mggnluts',number_failed)
+      if(n_pal .ne. 0) then
+         print *,'Wrong number of palettes returned for IMAGEC'
+      endif
 
 C Get info about the image
       call MESSAGE(5,'Getting image information')
@@ -808,7 +821,7 @@ C
 C
 C---GR compression function 
 C
-      integer mgscompress
+      integer mgscompress, mggcompress
 C
       integer hopen, hclose
       integer DFACC_CREATE, 
@@ -828,8 +841,8 @@ C
 C
 C---Compression types and parameters arrays 
 C
-      integer comp_type(N_COMP_TYPES)
-      integer comp_prm(N_COMP_ARG)
+      integer comp_type(N_COMP_TYPES), comp_type_out
+      integer comp_prm(N_COMP_ARG), comp_prm_out(N_COMP_ARG)
 C
 C---Compression parameters
 C
@@ -847,8 +860,8 @@ C
      .          COMP_CODE_RLE     = 1,
      .          COMP_CODE_SKPHUFF = 3,
      .          COMP_CODE_DEFLATE = 4,
-     .          COMP_CODE_JPEG = 6)
-      parameter (DEFLATE_LEVEL = 1,
+     .          COMP_CODE_JPEG = 7)
+      parameter (DEFLATE_LEVEL = 6,
      .           SKPHUFF_SKP_SIZE = 2)
       parameter (JPEG_QUALITY = 100,
      .           JPEG_COMPATIBILITY = 1)
@@ -1036,7 +1049,7 @@ C
          print *, 'mgstart failed for', i_comp, '-th data set'
          err_grcompress = err_grcompress +1
       endif 
-      do 2000 i_comp=1, N_COMP_TYPES - 1
+      do 2000 i_comp=1, N_COMP_TYPES 
       index = mgn2ndx(gr_id, name(i_comp))
       if(index .eq. -1 ) then
          print *, 'mgn2ndx failed for',  name(i_comp), ' data set'
@@ -1049,6 +1062,53 @@ C
          goto 1999
       endif 
 C
+C  Find out type of compression used and compression parameters.
+C
+       status = mggcompress(ri_id(i_comp), comp_type_out, comp_prm_out)
+	    if (status .eq. -1) then
+            print *, 'mggcompress failed for', i, ' -th dataset'
+                err_grcompress = err_grcompress + 1
+            endif
+            if (name(i_comp) .eq. 'Nocomp_data') then
+                if (comp_type_out .ne. COMP_CODE_NONE) then
+            print *, 'wrong compression type for Nocomp_data dataset'
+                err_grcompress = err_grcompress + 1
+                endif
+            endif
+            if (name(i_comp) .eq. 'Rlcomp_data') then
+                if (comp_type_out .ne. COMP_CODE_RLE) then
+            print *, 'wrong compression type for Rlcomp_data dataset'
+                err_grcompress = err_grcompress + 1
+                endif
+            endif
+            if (name(i_comp) .eq. 'Hucomp_data') then
+                if (comp_type_out .ne. COMP_CODE_SKPHUFF) then
+            print *, 'wrong compression type for Hucomp_data dataset'
+                err_grcompress = err_grcompress + 1
+                endif
+                if (comp_prm_out(1). ne. skphuff_skp_size) then
+         print *, 'wrong compression parameter for Hucomp_data dataset'
+                err_grcompress = err_grcompress + 1
+                endif
+
+            endif
+            if (name(i_comp) .eq. 'Gzcomp_data') then
+                if (comp_type_out .ne. COMP_CODE_DEFLATE) then
+          print *, 'wrong compression type for Gzcomp_data dataset'
+                endif
+                if (comp_prm_out(1). ne. deflate_level) then
+          print *, 'wrong compression parameter for Gzcomp_data dataset'
+                err_grcompress = err_grcompress + 1
+                endif
+            endif
+            if (name(i_comp) .eq. 'Jpcomp_data') then
+                if (comp_type_out .ne. COMP_CODE_JPEG) then
+            print *, 'wrong compression type for Jpcomp_data dataset'
+                err_grcompress = err_grcompress + 1
+                endif
+            goto 1111
+            endif
+C
 C     Read the stored data to the image array.
 C
       start(1) = 0
@@ -1077,7 +1137,7 @@ C
 50    continue
 60    continue
 
-  
+1111  continue  
 C
 C     Terminate access to the array.
 C
@@ -1129,7 +1189,8 @@ C
 C---GR interface functions
 C
       integer mgstart, mgcreat, mgsnatt,
-     .        mgrdimg, mgn2ndx, mgselct, mgendac, mgend, mgfinfo
+     .        mgrdimg, mgn2ndx, mgselct, mgendac, mgend, mgfinfo,
+     .        mggcompress
 C
 C---GR chunking functions 
 C
@@ -1156,7 +1217,9 @@ C
 C---Compression types and parameters arrays 
 C
       integer comp_type(N_COMP_TYPES), comp_type_out(N_COMP_TYPES)
+      integer comp_typegr
       integer comp_prm(N_COMP_ARG)
+      integer comp_prm_out(N_COMP_ARG)
 C
 C---Compression parameters
 C
@@ -1171,8 +1234,8 @@ C
      .          COMP_CODE_RLE     = 1,
      .          COMP_CODE_SKPHUFF = 3,
      .          COMP_CODE_DEFLATE = 4)
-      parameter (DEFLATE_LEVEL = 1,
-     .           SKPHUFF_SKP_SIZE = 2)
+      parameter (DEFLATE_LEVEL = 6,
+     .           SKPHUFF_SKP_SIZE = 3)
 C
 C---Data
 C 
@@ -1228,38 +1291,29 @@ C  Data initialization
 C 
       data chunk11 / 110, 111, 112, 120, 121, 122,
      .                130, 131, 132, 140, 141, 142,
-     .                150, 151, 152, 160, 161, 162/, 
-     .      chunk21 /
-     .                210, 211, 212, 220, 221, 222,
+     .                150, 151, 152, 160, 161, 162/
+      data chunk21 /  210, 211, 212, 220, 221, 222,
      .                230, 231, 232, 240, 241, 242,
-     .                250, 251, 252, 260, 261, 262
-     .              /,
-     .      chunk52 /
-     .                1010, 1011, 1012, 1020, 1021, 1022,
+     .                250, 251, 252, 260, 261, 262/
+      data chunk52 / 1010, 1011, 1012, 1020, 1021, 1022,
      .                1030, 1031, 1032, 1040, 1041, 1042,
-     .                1050, 1051, 1052, 1060, 1061, 1062
-     .              /,
-     .      data_org /
-     .                110, 111, 112, 120, 121, 122, 
-     .                210, 211, 212, 220, 221, 222, 0,
-     .                 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-     .                 0, 0, 0, 0, 0, 0, 0, 
-     .                130, 131, 132, 140,
-     .                141, 142, 230, 231, 232, 240, 241, 242, 
-     .                0, 0, 0, 0, 0, 0, 0, 0, 0,
-     .                0, 0, 0, 0, 0, 0, 0, 0, 0, 
-     .                150, 151, 152, 160, 161, 162, 250, 251,
-     .                252, 260, 261, 262, 0, 0, 0, 0, 0, 0, 0, 
-     .                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-     .                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-     .                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-     .                1010, 1011, 1012, 1020, 1021, 1022, 
-     .                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-     .                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-     .                1030, 1031, 1032, 1040, 1041,
-     .                1042, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-     .                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-     .                0, 1050, 1051, 1052, 1060, 1061, 1062 /
+     .                1050, 1051, 1052, 1060, 1061, 1062/
+      data data_org /
+     .     110, 111, 112, 120, 121, 122, 210, 211, 212, 220, 221, 222,
+     .     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+     .     0, 0, 0, 0, 0, 0, 130, 131, 132, 140, 141, 142,
+     .     230, 231, 232, 240, 241, 242, 0, 0, 0, 0, 0, 0,
+     .     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+     .     150, 151, 152, 160, 161, 162, 250, 251, 252, 260, 261, 262,
+     .     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+     .     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+     .     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+     .     0, 0, 0, 0, 0, 0, 1010, 1011, 1012, 1020, 1021, 1022, 
+     .     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+     .     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+     .     1030, 1031, 1032, 1040, 1041, 1042, 0, 0, 0, 0, 0, 0,
+     .     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+     .     0, 0, 0, 0, 0, 0, 1050, 1051, 1052, 1060, 1061, 1062/
 C
 C  Initialize compression argument array
 C
@@ -1438,6 +1492,44 @@ C
          err_grwrchunk = err_grwrchunk +1
          goto 2000 
       endif 
+      status = mggcompress(ri_id(i_comp), comp_typegr, comp_prm_out)
+      if (status .eq. -1) then
+      print *, 'mggcompress failed for', i, ' -th dataset'
+         err_grwrchunk = err_grwrchunk +1
+      endif
+      
+            if (name(i_comp) .eq. 'Nocomp_data') then
+                if (comp_typegr .ne. COMP_CODE_NONE) then
+            print *, 'wrong compression type for Nocomp_data dataset'
+                err_grwrchunk = err_grwrchunk +1
+                endif
+            endif
+            if (name(i_comp) .eq. 'Rlcomp_data') then
+                if (comp_typegr .ne. COMP_CODE_RLE) then
+            print *, 'wrong compression type for Rlcomp_data dataset'
+                err_grwrchunk = err_grwrchunk +1
+                endif
+            endif
+            if (name(i_comp) .eq. 'Hucomp_data') then
+                if (comp_typegr .ne. COMP_CODE_SKPHUFF) then
+            print *, 'wrong compression type for Hucomp_data dataset'
+                err_grwrchunk = err_grwrchunk +1
+                endif
+                if (comp_prm_out(1). ne. skphuff_skp_size) then
+         print *, 'wrong compression parameter for Hucomp_data dataset'
+                err_grwrchunk = err_grwrchunk +1
+                endif
+
+            endif
+            if (name(i_comp) .eq. 'Gzcomp_data') then
+                if (comp_typegr .ne. COMP_CODE_DEFLATE) then
+          print *, 'wrong compression type for Gzcomp_data dataset'
+                endif
+                if (comp_prm_out(1). ne. deflate_level) then
+          print *, 'wrong compression parameter for Gzcomp_data dataset'
+                err_grwrchunk = err_grwrchunk +1
+                endif
+            endif
 C
 C     Read the stored data to the image array.
 C
