@@ -1,3 +1,16 @@
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+
 /*
  * Name:
  *      fp2hdf
@@ -160,6 +173,11 @@
 #include <string.h>
 #include <ctype.h>
 
+#ifdef _WIN32
+#include <sys/stat.h>
+#include <fcntl.h>
+#endif
+
 /*
  * global macros
  */
@@ -355,17 +373,26 @@ main(int argc, char *argv[])
     int         token;
     int         state = 0;
 
+    
     const char *err1 = "Invalid number of arguments:  %d.\n";
     const char *err2 = "Error in state table.\n";
     const char *err3 = "No output file given.\n";
     const char *err4 = "Program aborted.\n";
 
+#ifdef _WIN32
+	_fmode = _O_BINARY;
+#endif
+
     /*
      * set 'stdout' and 'stderr' to line-buffering mode
      */
     (void) setvbuf(stderr, (char *) NULL, _IOLBF, 0);
     (void) setvbuf(stdout, (char *) NULL, _IOLBF, 0);
 
+#if defined __MWERKS__
+    argc = ccommand(&argv);
+#endif
+
     /*
      * validate the number of command line arguments
      */
@@ -708,7 +735,8 @@ gfloat(char *infile, FILE * strm, float32 *fp32, struct Input *in)
 
     if (in->is_text == TRUE)
       {
-          if (fscanf(strm, "%e", fp32) != 1)
+
+		if (fscanf(strm, "%e", fp32) != 1)
             {
                 (void) fprintf(stderr, err1, infile);
                 goto err;
@@ -716,6 +744,7 @@ gfloat(char *infile, FILE * strm, float32 *fp32, struct Input *in)
       }
     else if (in->is_fp32 == TRUE)
       {
+		
           if (fread((char *) fp32, sizeof(float32), 1, strm) != 1)
             {
                 (void) fprintf(stderr, err1, infile);
@@ -1096,8 +1125,12 @@ gtype(char *infile, struct Input *in, FILE **strm)
                 (void) fprintf(stderr, err2, infile);
                 goto err;
             }
-          if (!HDmemcmp("TEXT", buf, 4) || !HDmemcmp("text", buf, 4))
+          if (!HDmemcmp("TEXT", buf, 4) || !HDmemcmp("text", buf, 4)) {
+#ifdef _WIN32
+			  _fmode = _O_TEXT;
+#endif
               in->is_text = TRUE;
+		  }
           else
             {
                 rewind(*strm);
@@ -1116,6 +1149,7 @@ gtype(char *infile, struct Input *in, FILE **strm)
                       (void) fprintf(stderr, err3, infile);
                       goto err;
                   }
+		
             }
       }
 
@@ -1691,7 +1725,7 @@ palette(char *palfile)
     /*
      * extract a palette from an HDF file
      */
-    if (!Hishdf(palfile))
+    if (Hishdf(palfile))
       {
           if (DFPgetpal(palfile, pal))
             {
