@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.26 $";
+static char RcsId[] = "@(#)$Revision: 4937 $";
 #endif
 
-/* $Id: hdfpack.c,v 1.26 1997/10/25 00:56:30 koziol Exp $ */
+/* $Id: hdfpack.c 4937 2007-09-10 16:36:16Z pvn $ */
 
 /*
    ** FILE
@@ -284,8 +285,8 @@ main(int argc, char *argv[])
  */
     qsort((char *) dlist, (size_t)num_desc, sizeof(*dlist), desc_comp);
 
-    oldoff = -1;
-    oldlen = -1;
+    oldoff = -2;
+    oldlen = -2;
     for (i = 0; i < num_desc; i++)
       {
           if (((dlist[i].tag != DFTAG_NULL) && (dlist[i].tag != DFTAG_VERSION))
@@ -531,7 +532,8 @@ merge_blocks(mydd_t * dd, int32 infile, int32 outfile)
           HERROR(DFE_GENAPP);
           hdferror();
       }
-    outaid = Hstartwrite(outfile, BASETAG(dd->tag), dd->ref, dd->length);
+
+    outaid = Hstartaccess(outfile,BASETAG(dd->tag),dd->ref,DFACC_WRITE);
     if (outaid == FAIL)
       {
           HERROR(DFE_GENAPP);
@@ -547,7 +549,7 @@ merge_blocks(mydd_t * dd, int32 infile, int32 outfile)
                 hdferror();
             }
           ret = Hwrite(outaid, len, data);
-          if (len == FAIL)
+          if (ret == FAIL)
             {
                 HERROR(DFE_GENAPP);
                 hdferror();
