@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.39 $";
+static char RcsId[] = "@(#)$Revision: 4999 $";
 #endif
 
-/* $Id: he_main.c,v 1.39 1997/12/04 01:50:05 sxu Exp $ */
+/* $Id: he_main.c 4999 2007-12-03 20:31:07Z swegner $ */
 
 /******************************************************************************
  * he - HDF editor
@@ -73,7 +74,7 @@ static char RcsId[] = "@(#)$Revision: 1.39 $";
 #include "he.h"
 
 #include <stdio.h>
-#ifndef WIN32
+#ifndef _WIN32
 #include <unistd.h>
 #endif
 
@@ -215,35 +216,6 @@ getElement(int desc, char **pdata)
     return length;
 }
 
-/* The function is not called.
-
-   int od(char *format, char *file)
-   {
-   fork a child and let the child run od. Use vfork for VMS.
-
-   if (fork() == 0)
-
-   {
-   this is the child
-
-   if (execl("/bin/od", "od", format, file, 0) == -1)
-   fprintf(stderr, "Error while executing od.\n");
-
-   return control to the parent
-   exit(0);
-   }
-
-   the parent waits for the child to die
-
-   wait(0);
-
-   this is a bug because it always returns OK, will expand this as
-   soon as the status return mechanism from wait is understood
-   return HE_OK;
-
-   }
- */
-
 /* the tmp directory, currently set for unix */
 #define TDIR "/tmp/"
 
