@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char *RcsId[] = "@(#)$Revision: 1.13 $";
+static char *RcsId[] = "@(#)$Revision: 4937 $";
 #endif
 
-/* $Id: jpeg2hdf.c,v 1.13 1996/11/11 20:40:25 koziol Exp $ */
+/* $Id: jpeg2hdf.c 4937 2007-09-10 16:36:16Z pvn $ */
 #if defined __MWERKS__
 #include <console.h>
 #endif
@@ -192,27 +193,7 @@ process_tables(FILE * f)
 
           switch (c)
             {
-#ifdef QAK
-                case M_SOF0:
-                case M_SOF1:
-                case M_SOF2:
-                case M_SOF3:
-                case M_SOF5:
-                case M_SOF6:
-                case M_SOF7:
-                case M_JPG:
-                case M_SOF9:
-                case M_SOF10:
-                case M_SOF11:
-                case M_SOF13:
-                case M_SOF14:
-                case M_SOF15:
-                case M_SOI:
-#endif
                 case M_EOI:
-#ifdef OLD_WAY
-                case M_SOS:
-#endif
                     return ((JPEG_MARKER) c);
 
                 case M_SOF0:
@@ -221,28 +202,6 @@ process_tables(FILE * f)
                     get_sof(f);
                     return ((JPEG_MARKER) c);
 
-#ifdef QAK
-                case M_DHT:
-                    get_dht(cinfo);
-                    break;
-
-                case M_DAC:
-                    get_dac(cinfo);
-                    break;
-
-                case M_DQT:
-                    get_dqt(cinfo);
-                    break;
-
-                case M_DRI:
-                    get_dri(cinfo);
-                    break;
-
-                case M_APP0:
-                    get_app0(cinfo);
-                    break;
-#endif
-
                 case M_RST0:    /* these are all parameterless */
                 case M_RST1:
                 case M_RST2:
