@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char *RcsId[] = "@(#)$Revision: 1.59 $";
+static char *RcsId[] = "@(#)$Revision: 4937 $";
 #endif
 
-/* $Id: vshow.c,v 1.59 1999/04/23 22:19:11 smitchel Exp $ */
+/* $Id: vshow.c 4937 2007-09-10 16:36:16Z pvn $ */
 
 /*****************************************************************************
 *
@@ -56,6 +57,9 @@ static int32 fmtint
 static int32 fmtfloat
             (char *x);
 
+static int32 fmtulong
+            (char *x);
+
 static int32 fmtlong
             (char *x);
 
@@ -335,6 +339,15 @@ fmtfloat(char *x)
     return (1);
 }
 
+static int32
+fmtulong(char *x)
+{
+    unsigned    l = 0;
+    HDmemcpy(&l, x, sizeof(int32));
+    cn += printf("%u", l);
+    return (1);
+}
+
 static int32
 fmtlong(char *x)
 {
@@ -453,6 +466,9 @@ vsdumpfull(int32 vs)
                     break;
 
                 case DFNT_UINT32:
+                      fmtfn[i] = fmtulong;
+                      break;
+
                 case DFNT_INT32:
                     fmtfn[i] = fmtlong;
                     break;
@@ -652,6 +668,8 @@ static intn dumpattr(int32 vid, intn full, intn isvs)
                       fmtfn = fmtshort;
                       break;
                  case DFNT_UINT32:
+                      fmtfn = fmtulong;
+                      break;
                  case DFNT_INT32:
                       fmtfn = fmtlong;
                       break;
@@ -761,6 +779,8 @@ static intn dumpattr(int32 vid, intn full, intn isvs)
                   fmtfn = fmtshort;
                   break;
              case DFNT_UINT32:
+                  fmtfn = fmtulong;
+                  break;
              case DFNT_INT32:
                   fmtfn = fmtlong;
                   break;
