@@ -1,20 +1,21 @@
-/***************************************************************************e
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.37 $";
+static char RcsId[] = "@(#)$Revision: 5148 $";
 #endif
 
-/* $Id: hdp_vg.c,v 1.37 2000/09/05 14:28:13 bmribler Exp $ */
+/* $Id: hdp_vg.c 5148 2009-01-20 05:02:20Z bmribler $ */
 
 #include "hdp.h"
 #ifndef MIPSEL
@@ -240,7 +241,10 @@ Vstr_index(int32 file_id,
       /* Note: in either case, vg or vs, increment the index for the 
 	 next vgroup */
       (*index)++;
-   } /* end while getting vgroups */
+   } /* end whele getting vgroups */
+
+   /* when VSgetid returned FAIL in while above, search should stop */
+   ret_value = FAIL;
 
 done:
     if (ret_value == FAIL)
@@ -256,7 +260,7 @@ done:
    print an error message in the stderr to help debugging */
 void
 resetVG( int32 *vg_id,
-         char  *curr_file_name )
+         const char  *curr_file_name )
 {
    if( *vg_id != FAIL )
    {
@@ -325,7 +329,7 @@ display(vg_info_t *ptr,
                     && (HDstrcmp(ptr->children[i], "***")))
          {
             x = 0;
-            while (HDstrcmp(name, list[x]->name))
+            while (HDstrcmp(name, list[x]->vg_name))
             {
                x++;
             }
@@ -392,12 +396,14 @@ intn
 get_VGandInfo( int32 *vg_id,
                int32  file_id,
                int32  vg_ref,
-               char  *file_name,
+               const  char *file_name,
                int32 *n_entries,
-               char  *vgname,
+               char  **vgname,
                char  *vgclass )
 {
    intn status, ret_value = SUCCEED;
+   uint16 name_len = 0;
+   *vgname = NULL;
 
    /* detach the current vgroup if it's attached to cover the case 
       where a library routine fails and must continue to the next vgroup
@@ -409,18 +415,30 @@ get_VGandInfo( int32 *vg_id,
       ERROR_GOTO_2( "in %s: Vattach failed for vgroup ref=%d", 
 		"get_VGandInfo", (int) vg_ref );
 
-   status = Vinquire(*vg_id, n_entries, vgname);
+   /* get the length of the vgname to allocate enough space */
+   status = Vgetnamelen(*vg_id, &name_len);
+   if (FAIL == status) /* go to done and return a FAIL */
+   {
+      ERROR_GOTO_2( "in %s: Vgetnamelen failed for vg ref=%d",
+                "get_VGandInfo", (int) vg_ref );
+   }
+   *vgname = (char *) HDmalloc(sizeof(char *) * (name_len+1));
+
+   /* If allocation fails, get_VGandInfo simply terminates hdp. */
+   CHECK_ALLOC(*vgname, "*vgname", "get_VGandInfo" );
+
+   status = Vinquire(*vg_id, n_entries, *vgname);
    if (FAIL == status) /* go to done and return a FAIL */
    {
       /* stuff values to these variables so they can be printed */
       *n_entries = -1;
-      HDstrcpy( vgname, "<Unknown>" );
+      HDstrcpy( *vgname, "<Unknown>" );
 
       ERROR_GOTO_2( "in %s: Vinquire failed for vg ref=%d",
 		"get_VGandInfo", (int) vg_ref );
    }
-   else if( HDstrcmp( vgname, "" ) == 0) 
-      HDstrcpy( vgname, "<Unknown>" );
+   else if( HDstrcmp( *vgname, "" ) == 0) 
+      HDstrcpy( *vgname, "<Unknown>" );
 
    status = Vgetclass(*vg_id, vgclass);
    if( FAIL == status ) /* go to done and return a FAIL */
@@ -433,6 +451,7 @@ get_VGandInfo( int32 *vg_id,
    }
    else if( HDstrcmp( vgclass, "" ) == 0) 
       HDstrcpy( vgclass, "<Unknown>" ); 
+
 done:
    if( ret_value == FAIL )
    {
@@ -444,7 +463,7 @@ done:
 
 intn 
 print_data_annots( int32 file_id,
-                char *file_name,
+                const char *file_name,
                 int32 tag,
                 int32 ref )
 {
@@ -456,12 +475,12 @@ print_data_annots( int32 file_id,
 		"print_data_annots", file_name);
                                   
    /* print labels of vgroup if any */
-   if (FAIL == print_data_labels(file_name, an_id, tag, ref))
+   if (FAIL == print_data_labels(file_name, an_id, (uint16)tag, (uint16)ref))
       ERROR_GOTO_3( "in %s: print_data_labels failed for vg_ref(%d) in file %s\n", 
 		"print_data_annots", (int) ref, file_name);
 
    /* print descriptions of vgroup if any */
-   if (FAIL == print_data_descs(file_name, an_id, tag, ref))
+   if (FAIL == print_data_descs(file_name, an_id, (uint16)tag, (uint16)ref))
       ERROR_GOTO_3( "in %s: print_data_descs failed for vg-ref(%d) in file %s\n", 
 		"print_data_annots", (int) ref, file_name);
 
@@ -531,7 +550,7 @@ void print_fields( char *fields,
           count = 0;
    char  *ptr, *tempPtr,
           fldname[MAXNAMELEN],
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
+#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__) 
 
    /* Lets allocate space for tmpflds */
    *tempflds = (char *)HDmalloc(VSFIELDMAX * FIELDNAMELENMAX * sizeof(char *));
@@ -548,31 +567,38 @@ void print_fields( char *fields,
    else
    { /* there are fields to print */
       fprintf(fp, "%s[", field_title );
-      HDstrcpy(tempflds, fields);
-      ptr = tempflds;
+      HDstrcpy(tempflds, fields);	/* tempflds can be manipulated */
+      ptr = tempflds;			/* traverse tempflds with ptr */
+
+      /* traverse the temporary fieldname list to obtain and print each
+       * field name; use ',' to locate individual field names, and each 
+       * line should not exceed 50 characters beside the alignment */
       for (i = 0; !lastItem; i++)
       {
-         tempPtr = HDstrchr(ptr, ',');
+         tempPtr = HDstrchr(ptr, ',');  /* locate next separator */
          if (tempPtr == NULL)
-            lastItem = 1;
+            lastItem = 1;	/* set flag for end of list */
          else
-            *tempPtr = '\0';
-         HDstrcpy(fldname, ptr);
-         count += HDstrlen(fldname);
+            *tempPtr = '\0';	/* change ',' to null to obtain field name */
+         HDstrcpy(fldname, ptr);	/* obtain current field name */
+         count += HDstrlen(fldname);	/* increment current # of chars on line */
          if (count > 50)
          {
-            fprintf(fp, "%s", field_title );
-            count = 0;
+	    /* print alignment for the subsequent lines */
+            fprintf(fp, "\n\t          ");
+
+	    /* include the skipped field from previous line */
+            count = HDstrlen(fldname);  
          }
-         fprintf(fp, "%s", fldname);
+         fprintf(fp, "%s", fldname);  /* print the current field name */
          if (!lastItem)
-            fprintf(fp, ", ");
-         ptr = tempPtr + 1;
-      }  /* end of if skip */
+            fprintf(fp, ", ");	/* print a comma if it's not the last field name */
+         ptr = tempPtr + 1;	/* move ptr beyond last field name */
+      }  /* end of for loop */
       fprintf(fp, "];\n");
    }  /* there are fields to print */
    
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
+#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
    if(tempflds != NULL)
    {
       HDfree(tempflds);
@@ -665,7 +691,7 @@ get_VGindex_list(
          index = Vstr_index(file_id, dumpvg_opts->by_name.str_list[i], 1, &find_ref, &number);
          if (index == FAIL)
          {
-            printf( "Vgroup with name %s: not found\n", 
+            printf( "Vgroup with name '%s': not found\n", 
                            dumpvg_opts->by_name.str_list[i]);
             *index_error = 1; /* error */
          }
@@ -681,7 +707,7 @@ get_VGindex_list(
    if( filter & DCLASS )
       for (i = 0; i<dumpvg_opts->by_class.num_items; i++)
       {
-         int32 found = 0;
+         int32 found = FALSE;
          char sear_class[MAXNAMELEN];
 
          number = 0;
@@ -705,7 +731,7 @@ get_VGindex_list(
                (*vg_chosen)[vg_count] = index;
                num_vg_chosen++;
             }
-            found = 1;
+            found = TRUE;
             vg_count++;
          }
          if (!found)
@@ -732,7 +758,7 @@ done:
    two routines print_all_file_labels and print_file_descs defined in
    hdp_list.c to display the file annotations of the current file */
 intn
-print_file_annotations( int32 file_id, char* file_name )
+print_file_annotations( int32 file_id, const char* file_name )
 {
    int32 an_id = FAIL;
    intn  status = SUCCEED, ret_value = SUCCEED;
@@ -778,7 +804,7 @@ void
 closeVG(
     int32 *file_id,     /* will be returned as a FAIL */
     int32 **vg_chosen,  /* will be returned as a NULL */
-    char  *curr_file_name )
+    const char  *curr_file_name )
 {
    if( *file_id != FAIL )
    {
@@ -803,13 +829,13 @@ intn
 vgBuildGraph(int32        vg_id, 
            int32        file_id, 
            int32        num_entries, 
-	   char* file_name,
+	   const char* file_name,
            vg_info_t *aNode,
            intn         *skipfile)
 {
     int32  vs;
     char   vsname[MAXNAMELEN];
-    char   vgname[VGNAMELENMAX];
+    char  *vgname = NULL;
     char   vgclass[VGNAMELENMAX];
     char  *name = NULL;
     int32  vgt = FAIL;
@@ -842,7 +868,7 @@ vgBuildGraph(int32        vg_id,
 
          /* get the current vgroup and its information */
          status = get_VGandInfo( &vgt, file_id, elem_ref, file_name, 
-				 &elem_n_entries, vgname, vgclass );
+				 &elem_n_entries, &vgname, vgclass );
          if( status == FAIL )
             ERROR_NOTIFY_3( "in %s: %s failed in getting vgroup with ref#=%d",
 		"vgBuildGraph", "get_VGandInfo", (int)vg_ref );
@@ -890,7 +916,7 @@ vgBuildGraph(int32        vg_id,
 			"vgBuildGraph", (int) elem_ref );
 
                   /* set vdata's name to undefined */
-      		  HDstrcpy( vgname, "<Invalid>" );
+      		  HDstrcpy( vsname, "<Invalid>" );
                }
 
             if (FAIL == VSdetach(vs))
@@ -930,23 +956,11 @@ vgBuildGraph(int32        vg_id,
 done:
     if (ret_value == FAIL)
       { /* Failure cleanup */
-          if (aNode->children != NULL)
-            {
-                for (entry_num = 0; entry_num < num_entries; entry_num++)
-                   if (aNode->children[entry_num] != NULL)
-                       HDfree(aNode->children[entry_num]);
-                HDfree( aNode->children );
-            }
-          if (aNode->type != NULL)
-            {
-                for (entry_num = 0; entry_num < num_entries; entry_num++)
-                   if (aNode->type[entry_num] != NULL)
-                       HDfree(aNode->type[entry_num]);
-                HDfree( aNode->type );
-            }
+	  aNode = free_node_vg_info_t(aNode);
       }
     /* Normal cleanup */
-    
+    if (vgname != NULL) HDfree(vgname);
+
     return ret_value;
 }	/* vgBuildGraph */
 
@@ -972,14 +986,13 @@ vgdumpfull(int32        vg_id,
     int32  vsize;
     char   vsname[MAXNAMELEN];
     char   vsclass[VSNAMELENMAX];
-    char   vgname[VGNAMELENMAX];
+    char  *vgname = NULL;
     char   vgclass[VGNAMELENMAX];
     char  *name = NULL;
-    int32  i;
     char  *file_name = dumpvg_opts->ifile_name;
     intn   status, ret_value = SUCCEED;
 
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
+#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
 	/* macintosh cannot handle >32K locals */
    char *fields = (char *)HDmalloc(VSFIELDMAX*FIELDNAMELENMAX* sizeof(char));
    CHECK_ALLOC( fields, "*fields", "vgdumpfull" );
@@ -1017,7 +1030,7 @@ vgdumpfull(int32        vg_id,
       { /* vgroup */
 
          /* get the current vgroup and its information */
-         status = get_VGandInfo( &vgt, file_id, elem_ref, file_name, &elem_n_entries, vgname, vgclass );
+         status = get_VGandInfo( &vgt, file_id, elem_ref, file_name, &elem_n_entries, &vgname, vgclass );
          if( status == FAIL )
 	    ERROR_GOTO_3( "in %s: %s failed in getting vgroup with ref#=%d",
                 "vgdumpfull", "get_VGandInfo", (int) vg_ref );
@@ -1154,29 +1167,17 @@ vgdumpfull(int32        vg_id,
 done:
     if (ret_value == FAIL)
       { /* Failure cleanup */
-          if (aNode->children != NULL)
-            {
-                for (i = 0; i < num_entries; i++)
-                   if (aNode->children[i] != NULL)
-                       HDfree(aNode->children[i]);
-                HDfree( aNode->children );
-            }
-          if (aNode->type != NULL)
-            {
-                for (i = 0; i < num_entries; i++)
-                   if (aNode->type[i] != NULL)
-                       HDfree(aNode->type[i]);
-                HDfree( aNode->type );
-            }
+	  aNode = free_node_vg_info_t(aNode);
       }
     /* Normal cleanup */
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
+#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
    if(fields != NULL)
    {
       HDfree(fields);
       fields = NULL;
     } 
 #endif /* macintosh */ 
+    if (vgname != NULL) HDfree(vgname); /* free temp memory */
     
     return ret_value;
 }	/* vgdumpfull */
@@ -1193,18 +1194,19 @@ dvg(dump_info_t *dumpvg_opts,
     int32      *vg_chosen = NULL;
     int32       vg_count;
     int32       num_vg_chosen;
-    int32       i, j;
+    int32       j;
     int32       vg_ref = -1;
     int32       vg_tag;
     int32       n_entries;
     int32       level;
+    int32	curr_vg=0;
     int32       max_vgs=0;
     int32       num_nodes = 0;
     int         index_error = 0;
     int         dumpall = 0;
     char        file_name[MAXFNLEN];
     char        vgclass[VGNAMELENMAX];
-    char        vgname[VGNAMELENMAX];
+    char       *vgname = NULL;
     FILE       *fp = NULL;
     vg_info_t **list = NULL;
     vg_info_t *ptr = NULL;
@@ -1221,6 +1223,7 @@ dvg(dump_info_t *dumpvg_opts,
       and display them */
    while (curr_arg < argc)
    {
+      intn isHDF = TRUE;  /* FALSE, if current file is not HDF file */
       intn skipfile = FALSE;  /* skip the current file when some severe */
            /* failure occurs; otherwise, the list of nodes is not */
            /* completely prepared and will cause a crash in display */
@@ -1233,6 +1236,19 @@ dvg(dump_info_t *dumpvg_opts,
          cleanup, so closeVG ensures of that */
       closeVG( &file_id, &vg_chosen, file_name );
 
+      /* Print an informative message and skip this file if it is not
+         an HDF file */
+      isHDF = Hishdf(file_name);
+      if (isHDF == FALSE)
+      {
+         /* if there are no more files to be processed, print error
+            message, then returns with FAIL */
+         if( curr_arg == argc )
+            {ERROR_GOTO_1( "in dvg: %s is not an HDF file", file_name);}
+         else /* print message, then continue processing the next file */
+            {ERROR_CONT_1( "in dvg: %s is not an HDF file", file_name);}
+      }
+
       /* open current hdf file with error check, if fail, go to next file */
       file_id = Hopen(file_name, DFACC_READ, 0);
       if (file_id == FAIL)
@@ -1246,9 +1262,10 @@ dvg(dump_info_t *dumpvg_opts,
             ERROR_CONT_1( "in dvg: Failure in opening file %s", file_name );
       }
 
-      /* initiate VG interface; if fail, close hdf file & go to next file */
+      /* initiate VG interface; if fail, probably something fatal, returns 
+	 with FAIL */
       if (FAIL == Vstart(file_id))
-         ERROR_CONT_1( "in dvg: Vstart failed for file %s\n", file_name);
+         ERROR_GOTO_1( "in dvg: Vstart failed for file %s\n", file_name);
 
       /* compose the list of indices of vgroups to be processed in the current
       file and return the number of items in the list */
@@ -1297,21 +1314,21 @@ dvg(dump_info_t *dumpvg_opts,
 
       /* for each vgroup: go thru each vgroup in the file or until the 
          number of vgs being printed reaches the number of vgs chosen */
-      for (i = 0; (vg_ref = Vgetid(file_id, vg_ref)) != FAIL 
-                   && (dumpall || vg_count < num_vg_chosen); i++)
+      for (curr_vg = 0; (vg_ref = Vgetid(file_id, vg_ref)) != FAIL 
+                   && (dumpall || vg_count < num_vg_chosen); curr_vg++)
       {
          int32       skipvg = FALSE;
          intn isvdata; /* TRUE if a vdata being processed, FALSE if vg */
 
          /* if not to dump all vgroups but the current vgroup is not
             one of the selected ones */
-         if ((!dumpall) && (i != vg_chosen[vg_count]))
+         if ((!dumpall) && (curr_vg != vg_chosen[vg_count]))
             skipvg = TRUE;  /* skip printing this vg's info and data but
                              include it in the graphical representation */
 
          /* attaches the current vgroup and gets its tag, name, and class */ 
          status = get_VGandInfo( &vg_id, file_id, vg_ref, file_name, 
-                                 &n_entries, vgname, vgclass );
+                                 &n_entries, &vgname, vgclass );
          if( status == FAIL )
             ERROR_CONT_2( "in dvg: %s failed in getting vgroup with ref#=%d",
                         "get_VGandInfo", (int)vg_ref );
@@ -1338,8 +1355,8 @@ dvg(dump_info_t *dumpvg_opts,
             CHECK_ALLOC( list, "list", "dvg" );
          }
 
-         list[i] = (vg_info_t *) HDmalloc(sizeof(vg_info_t));
-         CHECK_ALLOC( list[i], "list[i]", "dvg" );
+         list[curr_vg] = (vg_info_t *) HDmalloc(sizeof(vg_info_t));
+         CHECK_ALLOC( list[curr_vg], "list[curr_vg]", "dvg" );
 
          /* if this vgroup is to be skipped, do not print the info here; 
             go to the data part to add the vgroup to the node list for 
@@ -1350,7 +1367,7 @@ dvg(dump_info_t *dumpvg_opts,
                ERROR_NOTIFY_3("in dvg: %s failed on vgroup with ref=%d in file %s", 
 		         "VQuerytag", (int) vg_ref, file_name);
             fprintf(fp, "\n");
-            fprintf(fp, "\nVgroup:%d\n", (int) i);
+            fprintf(fp, "\nVgroup:%d\n", (int) curr_vg);
             if( vg_tag == DFTAG_VG )
                /* when have time, change to this one, not now because
                   it takes time to fix the testfiles */
@@ -1382,7 +1399,7 @@ dvg(dump_info_t *dumpvg_opts,
 
          if( skipvg || dumpvg_opts->contents == DHEADER )
          {
-            status = vgBuildGraph(vg_id, file_id, n_entries, file_name, list[i], &skipfile );
+            status = vgBuildGraph(vg_id, file_id, n_entries, file_name, list[curr_vg], &skipfile );
             if( status == FAIL )
                ERROR_NOTIFY_3( "in dvg: %s failed for vgroup with ref#=%d in file %s", 
 			     "vgBuildGraph", (int) vg_ref, file_name );
@@ -1391,13 +1408,13 @@ dvg(dump_info_t *dumpvg_opts,
          {
             fprintf(fp, "Entries:-\n");
             status = vgdumpfull(vg_id, dumpvg_opts, file_id, n_entries,
-                                  fp, list[i], &skipfile );
+                                  fp, list[curr_vg], &skipfile );
             if( FAIL == status )
             {
                ERROR_NOTIFY_3( "in dvg: %s failed for vgroup with ref#=%d in file %s", 
 			      "vgdumpfull", (int) vg_ref, file_name);
 
-               /* do not continue so list[i] can be set */
+               /* do not continue so list[curr_vg] can be set */
             }
          } /* neither skipped nor header only */
 
@@ -1411,10 +1428,11 @@ dvg(dump_info_t *dumpvg_opts,
          resetVG( &vg_id, file_name );
   
          /* fill the graph. rep. node for this vgroup */
-         list[i]->index = i;
-         HDstrcpy(list[i]->name, vgname);
-         list[i]->displayed = FALSE;
-         list[i]->treedisplayed = FALSE;  /* BMR - 01/16/99 */
+         list[curr_vg]->index = curr_vg;
+	 list[curr_vg]->vg_name = (char *) HDmalloc(sizeof(char *) * (HDstrlen(vgname)+1));
+         HDstrcpy(list[curr_vg]->vg_name, vgname);
+         list[curr_vg]->displayed = FALSE;
+         list[curr_vg]->treedisplayed = FALSE;  /* BMR - 01/16/99 */
       }	/* for all vgroups */
 
       /* print the graphical representation part */
@@ -1439,8 +1457,9 @@ dvg(dump_info_t *dumpvg_opts,
           }		/* for */
        } /* if the file is not to be skipped */
 
-      /* free the list of vg_info_t nodes */
-      list = free_vginfo_list( list, max_vgs );
+      /* free allocated resources */
+      list = free_vginfo_list( list, curr_vg );
+      if (vgname != NULL) HDfree(vgname);
 
       /* free vg_chosen, and terminate access to and close the input file */
       closeVG( &file_id, &vg_chosen, file_name );
@@ -1456,7 +1475,8 @@ done:
       { /* Failure cleanup */
           closeVG( &file_id, &vg_chosen, file_name );
           resetVG( &vg_id, file_name );
-          list = free_vginfo_list( list, max_vgs );
+          list = free_vginfo_list(list, curr_vg);
+	  if (vgname != NULL) HDfree(vgname);
       }
     /* Normal cleanup */
 
