@@ -1,19 +1,20 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /* Modified from vshow.c by Eric Tsui, 12/25/1994. */
 
 #ifdef RCSID
-static char *RcsId[] = "@(#)$Revision: 1.22 $";
+static char *RcsId[] = "@(#)$Revision: 4933 $";
 #endif
 
 #define VSET_INTERFACE
@@ -57,7 +58,7 @@ dumpvd(int32       vd,
     int32       cn = 0;
     int32       ret_value = SUCCEED;
 
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
+#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
 	/* macintosh cannot handle >32K locals */
     char *fields = (char *)HDmalloc(VSFIELDMAX*FIELDNAMELENMAX* sizeof(char));
     char *flds = (char *)HDmalloc(VSFIELDMAX*FIELDNAMELENMAX* sizeof(char));
@@ -148,9 +149,10 @@ dumpvd(int32       vd,
 
           /* Choose a function for displaying a piece of data of a 
              particular type. */
-          switch (w->type[i])
+          switch (w->type[i] & 0xff)
             {
             case DFNT_CHAR:
+	    case DFNT_UCHAR:
                 vfmtfn[i] = fmtchar;
                 break;
 
@@ -456,7 +458,7 @@ done:
               HDfree((VOIDP)bb);
       }
     /* Normal cleanup */
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
+#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
    if(fields != NULL)
    {
       HDfree(fields);
@@ -497,7 +499,7 @@ dumpattr(int32 vid,
     intn          status;
     intn          ret_value = SUCCEED;
 
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
+#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
 	/* macintosh cannot handle >32K locals */
     char *name = (char *)HDmalloc((FIELDNAMELENMAX+1) * sizeof(char));
     uint8 *attrbuf = (uint8 *)HDmalloc((BUFFER) * sizeof(uint8));
@@ -600,7 +602,7 @@ dumpattr(int32 vid,
             }
 
           /* format output */
-          switch (i_type)  
+          switch (i_type & 0xff)  
             {
             case DFNT_CHAR:
             case DFNT_UCHAR:
@@ -679,7 +681,7 @@ done:
               HDfree(buf);
       }
     /* Normal cleanup */
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
+#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
    if(name != NULL)
    {
       HDfree(name);
