@@ -1,7 +1,7 @@
 c********************************************************************
 c   Copyright 1993, UCAR/Unidata
 c   See netcdf/COPYRIGHT file for copying and redistribution conditions.
-c   $Id: ftest-ia64.f,v 1.1 2000/05/23 18:07:07 acheng Exp $
+c   $Id: ftest-ia64.f 4582 2005-02-09 03:04:19Z epourmal $
 c********************************************************************/
 
 
@@ -479,7 +479,7 @@ c
       
       bvalidrg(1) = 1
       bvalidrg(2) = 250
-      call ncapt (ncid, bid, 'validrange', NCBYTE, 2,
+      call ncapt (ncid, bid, 'valid range', NCBYTE, 2,
      +bvalidrg, iret)
 
 c
@@ -488,7 +488,7 @@ c
 
       svalidrg(1) = -100
       svalidrg(2) = 100
-      call ncapt (ncid, sid, 'validrange', NCSHORT, 2, 
+      call ncapt (ncid, sid, 'valid range', NCSHORT, 2, 
      +svalidrg, iret)
 
 c
@@ -497,7 +497,7 @@ c
 
       lvalidrg(1) = 0
       lvalidrg(2) = 360
-      call ncapt (ncid, lid, 'validrange', NCLONG, 2,
+      call ncapt (ncid, lid, 'valid range', NCLONG, 2,
      +lvalidrg, iret)
       
 c
@@ -506,7 +506,7 @@ c
 
       rvalidrg(1) = 0.0
       rvalidrg(2) = 5000.0
-      call ncapt (ncid, fid, 'validrange', NCFLOAT, 2,
+      call ncapt (ncid, fid, 'valid range', NCFLOAT, 2,
      +rvalidrg, iret)
 
 c
@@ -515,7 +515,7 @@ c
 
       dvalidrg(1) = 0D0
       dvalidrg(2) = 500D0
-      call ncapt (ncid, did, 'validrange', NCDOUBLE, 2,
+      call ncapt (ncid, did, 'valid range', NCDOUBLE, 2,
      +dvalidrg, iret)
 
 c
@@ -565,11 +565,12 @@ c      character*31 dimnam(MAXNCDIM)
       data dimnam /'time', 'lat', 'lon', 'level',
      + 'length', 27*'0'/
       data dimsiz /4, 5, 5, 4, 80, 27*0/
-      data varnam/'bytev', 'shortv', 'longv', 'floatv', 'doublev', 
+      data varnam/'bytev', 'short v', 'longv', 'floatv', 'doublev', 
      + 'chv', 'cv'/
       
-      data attname/'validrange', '0', 'validrange', '0', 'validrange',
-     + '0', 'validrange', '0', 'validrange', '0', 'longname', 'id',
+      data attname/'valid range', '0', 'valid range',
+     + '0', 'valid range',
+     + '0', 'valid range', '0', 'valid range', '0', 'longname', 'id',
      + '0', '0'/
       data gattnam/'source','basetime'/
       end
@@ -818,7 +819,7 @@ c
 c     short
 c
       sdims(1) = timedim
-      sid = ncvdef (ncid, 'shortv', NCSHORT, 1, sdims, iret)
+      sid = ncvdef (ncid, 'short v', NCSHORT, 1, sdims, iret)
 c
 c     long
 c
