@@ -1,7 +1,7 @@
 c********************************************************************
 c   Copyright 1993, UCAR/Unidata
 c   See netcdf/COPYRIGHT file for copying and redistribution conditions.
-c   $Id: ftest-t3e.f,v 1.4 1998/03/03 23:38:55 acheng Exp $
+c   $Id: ftest-t3e.f 4582 2005-02-09 03:04:19Z epourmal $
 c********************************************************************/
 
 
@@ -106,6 +106,11 @@ c     test ncacpy
 c     test ncadel
       write(*, 100) 'ncadel'
       call tncadel(name2)
+
+c     test reading from NetCDF file
+      write(*, 100) 'NetCDF read'
+      call tread_netcdf()
+
       end
 c
 c     subroutine to test ncacpy
@@ -479,7 +484,7 @@ c
       
       bvalidrg(1) = 1
       bvalidrg(2) = 250
-      call ncapt (ncid, bid, 'validrange', NCBYTE, 2,
+      call ncapt (ncid, bid, 'valid range', NCBYTE, 2,
      +bvalidrg, iret)
 
 c
@@ -488,7 +493,7 @@ c
 
       svalidrg(1) = -100
       svalidrg(2) = 100
-      call ncapt (ncid, sid, 'validrange', NCSHORT, 2, 
+      call ncapt (ncid, sid, 'valid range', NCSHORT, 2, 
      +svalidrg, iret)
 
 c
@@ -497,7 +502,7 @@ c
 
       lvalidrg(1) = 0
       lvalidrg(2) = 360
-      call ncapt (ncid, lid, 'validrange', NCLONG, 2,
+      call ncapt (ncid, lid, 'valid range', NCLONG, 2,
      +lvalidrg, iret)
       
 c
@@ -506,7 +511,7 @@ c
 
       rvalidrg(1) = 0.0
       rvalidrg(2) = 5000.0
-      call ncapt (ncid, fid, 'validrange', NCFLOAT, 2,
+      call ncapt (ncid, fid, 'valid range', NCFLOAT, 2,
      +rvalidrg, iret)
 
 c
@@ -515,7 +520,7 @@ c
 
       dvalidrg(1) = 0D0
       dvalidrg(2) = 500D0
-      call ncapt (ncid, did, 'validrange', NCDOUBLE, 2,
+      call ncapt (ncid, did, 'valid range', NCDOUBLE, 2,
      +dvalidrg, iret)
 
 c
@@ -565,11 +570,12 @@ c      character*31 dimnam(MAXNCDIM)
       data dimnam /'time', 'lat', 'lon', 'level',
      + 'length', 27*'0'/
       data dimsiz /4, 5, 5, 4, 80, 27*0/
-      data varnam/'bytev', 'shortv', 'longv', 'floatv', 'doublev', 
+      data varnam/'bytev', 'short v', 'longv', 'floatv', 'doublev', 
      + 'chv', 'cv'/
       
-      data attname/'validrange', '0', 'validrange', '0', 'validrange',
-     + '0', 'validrange', '0', 'validrange', '0', 'longname', 'id',
+      data attname/'valid range', '0', 'valid range',
+     + '0', 'valid range',
+     + '0', 'valid range', '0', 'valid range', '0', 'longname', 'id',
      + '0', '0'/
       data gattnam/'source','basetime'/
       end
@@ -818,7 +824,7 @@ c
 c     short
 c
       sdims(1) = timedim
-      sid = ncvdef (ncid, 'shortv', NCSHORT, 1, sdims, iret)
+      sid = ncvdef (ncid, 'short v', NCSHORT, 1, sdims, iret)
 c
 c     long
 c
@@ -1220,3 +1226,196 @@ c
       call ncclos (ncid, iret)
       return
       end
+
+C        This routine reads varaibales and global attributes from
+C        the REAL NetCDF file test_nc.nc. The file was created by NetCDF v3.5 
+C        from the file test_nc.cdl that can be found in the mfhdf/fortran
+C        directory. Please do not generate test_nc.nc file from the test_nc.cdl
+C        using HDF4 ncgen. HDF4 ncgen generated HDF4 file!
+
+         subroutine tread_netcdf()
+         include 'netcdf.inc'
+
+C        Variables declarations
+
+         character*10 FILENAME
+         character*1024 new_filename
+         integer filename_len
+         integer status, ncid, var_id
+         integer time(12), date(12), start(3), count(3), int_attr(5)
+         real a(3,2), float_attr(3)
+         double precision c(3), double_attr(3)
+         integer*2 b(2,3,12), short_attr(2)
+         integer i, j, k, dlen
+         character*10 description
+
+C        Arrays to read data to.
+
+         integer time_val(12), date_val(12), int_attr_val(5)
+         integer*2 b_val(2,3,12), short_attr_val(2)
+         real a_val(3,2), float_attr_val(3)
+         double precision c_val(3), double_attr_val(3)
+         real epsilon
+         double precision depsilon
+         integer external fixname
+
+C        Arrays initialization
+         DATA time_val /1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12/
+         DATA date_val /840116, 840214, 840316, 840415, 840516, 840615, 
+     +              840716, 840816, 840915, 841016, 841115, 841216/
+         DATA a_val /1.0, 2.0, 3.0, 4.0, 5.0, 6.0/
+         DATA b_val /1, 1, 2, 2, 3, 3,
+     +           4, 4, 5, 5, 6, 6,
+     +           7, 7, 8, 8, 9, 9,
+     +           10, 10, 11, 11, 12, 12,
+     +           13, 13, 14, 14, 15, 15,
+     +           16, 16, 17, 17, 18, 18,
+     +           19, 19, 20, 20, 21, 22,
+     +           23, 23, 24, 24, 25, 25, 
+     +           26, 26, 27, 27, 28, 28,
+     +           29, 29, 30, 30, 31, 31,
+     +           32, 32, 33, 33, 34, 34,
+     +           35, 35, 36, 36, 37, 37/
+         DATA c_val /2.0, 3.0, 100/
+         DATA int_attr_val /-100, 200, -300, 400, -500/
+         DATA float_attr_val /1.0, 2.0, 3.0/
+         DATA short_attr_val /0, 1/
+         DATA double_attr_val /-1.0, 2.0, -7.0/
+         DATA epsilon /1.E-6/
+         DATA depsilon /1.E-12/
+         
+C        Modify filename to accomodate SRCDIR configure option
+
+         FILENAME = 'test_nc.nc'
+         filename_len = len(new_filename)
+         call fixname(FILENAME, new_filename, filename_len)
+
+         dlen = 10
+         ncid = ncopn(new_filename(1:filename_len), NCNOWRIT, status)
+         if (status .ne.0) then
+             write(*,*) 'ncopn failed'
+             goto 1000
+         endif
+
+         var_id = ncvid(ncid, 'time', status)
+         start(1) = 1 
+         count(1) = 12
+         call ncvgt(ncid, var_id, start, count, time, status)
+         if (status .ne. 0) write(*,*) 
+     +      'ncvgt failed for 32-bit integer variable time'
+         do i = 1, 12
+            if( time(i) .ne. time_val(i) ) 
+     +      write(*,*) 'Wrong time value at index  ', i 
+         enddo
+
+         var_id = ncvid(ncid, 'c', status)
+         start(1) = 1 
+         count(1) = 3
+         call ncvgt(ncid, var_id, start, count, c, status)
+         if (status .ne. 0) write(*,*)
+     +      'ncvgt failed for 64-bit float variable c'
+         do i = 1, 3
+            if( abs(c(i) - c_val(i)) .gt. depsilon ) 
+     +      write(*,*) 'Wrong c value at index  ', i 
+         enddo
+
+         var_id = ncvid(ncid, 'date', status)
+         start(1) = 1 
+         count(1) = 12
+         call ncvgt(ncid, var_id, start, count, date, status)
+         if (status .ne. 0) write(*,*) 
+     +      'ncvgt failed for 32-bit integer variable date'
+         do i = 1, 12
+            if( date(i) .ne. date_val(i) ) 
+     +      write(*,*) 'Wrong date value at index  ', i 
+         enddo
+
+
+         var_id = ncvid(ncid, 'a', status)
+         start(1) = 1 
+         start(2) = 1
+         count(1) = 3
+         count(2) = 2
+         call ncvgt(ncid, var_id, start, count, a, status)
+         if (status .ne. 0) write(*,*) 
+     +      'ncvgt failed for 32-bit real variable a'
+         do i = 1, 2
+            do j = 1, 3 
+            if( abs(a(j,i) - a_val(j,i)) .gt. epsilon ) 
+     +      write(*,*) 'Wrong a value at indecies  ', j, ',', i 
+            enddo
+         enddo
+
+
+         var_id = ncvid(ncid, 'b', status)
+         start(1) = 1 
+         start(2) = 1
+         start(3) = 1
+         count(1) = 2 
+         count(2) = 3
+         count(3) = 12
+         call ncvgt(ncid, var_id, start, count, b, status)
+         if (status .ne. 0) write(*,*) 
+     +      'ncvgt failed for 16-bit integer variable b'
+         do i = 1, 12
+            do j = 1, 3 
+               do k = 1, 2
+               if( b(k,j,i) .ne.  b_val(k,j,i)) 
+     +         write(*,*) 
+     +        'Wrong b value at indecies  ', k, ',', j, ',', i 
+               enddo
+            enddo
+         enddo
+
+
+C read global attributes
+
+         call ncagt(ncid, NCGLOBAL, 'int_attr', int_attr, status)
+         if (status .ne. 0) 
+     +   write(*,*) 'ncagt failed for 32-bit integer attribute int_attr'
+         do i = 1, 5
+            if( int_attr(i) .ne. int_attr_val(i) ) 
+     +      write(*,*) 'Wrong int_attr value at index  ', i 
+         enddo
+
+
+         call ncagt(ncid, NCGLOBAL, 'float_attr', float_attr, status)
+         if (status .ne. 0) 
+     +   write(*,*) 'ncagt failed for 32-bit float attribute float_attr'
+         do i = 1, 3 
+            if( abs(float_attr(i) - float_attr_val(i)) .gt. epsilon ) 
+     +      write(*,*) 'Wrong float_attr value at index  ', i 
+         enddo
+
+         call ncagt(ncid, NCGLOBAL, 'double_attr', double_attr, status)
+         if (status .ne. 0) 
+     +   write(*,*) 
+     +   'ncagt failed for 64-bit float attribute double_attr'
+         do i = 1, 3 
+            if( abs(double_attr(i) - double_attr_val(i)) .gt. depsilon ) 
+     +      write(*,*) 'Wrong double_attr value at index  ', i 
+         enddo
+
+
+         call ncagt(ncid, NCGLOBAL, 'short_attr', short_attr, status)
+         if (status .ne. 0) 
+     +   write(*,*) 
+     +   'ncagt failed for 16-bit integer attribute double_attr'
+         do i = 1, 2 
+            if( short_attr(i) .ne. short_attr_val(i) ) 
+     +      write(*,*) 'Wrong short_attr value at index  ', i 
+         enddo
+
+
+         call ncagtc(ncid, NCGLOBAL, 'Description', description, 
+     +               dlen, status)
+         if (status .ne. 0) 
+     +   write(*,*) 
+     +   'ncagt failed for character attribute Description'
+         if (description .ne. 'Attributes') 
+     +   write(*,*) 'Wrong values of the character attribute' 
+
+
+1000     continue
+         return
+         end
