@@ -2,7 +2,7 @@
  *	Copyright 1990, University Corporation for Atmospheric Research
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: jackets-aix.c,v 1.6 1997/11/05 22:19:48 koziol Exp $ */
+/* $Id: jackets-aix.c 4772 2006-11-01 16:53:11Z epourmal $ */
 /*
  * OVERVIEW
  *
@@ -34,7 +34,7 @@
 
 struct ncfils {			/* This will be a common block from Fortran */
     double dd;
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
     int ll;
 #else
     long ll;
@@ -65,7 +65,7 @@ struct ncfils {			/* This will be a common block from Fortran */
 
 struct ncfils {			/* This will be a common block from Fortran */
     double dd;
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
     int ll;
 #else
     long ll;
@@ -163,7 +163,7 @@ fstrncpy (target, source, maxlen)
 	*target++ = *source++;
     *target = '\0';
 }
-
+#ifdef WE_COULDNT_READ_NAMES_WITH_SPACES
 /* copy function used to copy strings terminated with blanks */
 static void
 nstrncpy (target, source, maxlen)
@@ -175,7 +175,25 @@ nstrncpy (target, source, maxlen)
 	*target++ = *source++;
     *target = '\0';
 }
+#endif
 
+/* copy function used to copy strings with embeded blanks and
+   terminated with blanks */
+static void
+nstrncpy (target, source, maxlen)
+    char *target;		/* space to be copied into */
+    char *source;		/* string to be copied */
+    int maxlen;			/* maximum length of *source */
+{
+/* Copy all string */
+    while (maxlen--) 
+        *target++ = *source++;
+    *target -- = '\0';
+/* Disregard all trailing spaces  */
+     while (*target == ' ')
+         *target-- = '\0';
+
+}
 
 /*
  * Compute product of dimensions.
@@ -412,7 +430,7 @@ stoig(shorts, ints, dims, basis, ndims)
 }
 #endif /* FORTRAN_HAS_NO_SHORT */
 
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
 /*
  * Convert multi-dimensional array of NCLONGs stored in ints to packed
  * array of longs, in malloc'ed space.  Returns pointer to longs or NULL
@@ -525,7 +543,7 @@ ltoig(longs, ints, dims, imap, ndims)
 
 /* used to set the C global variable ncopts from Fortran */
 void
-ncpopt(val)
+nncpopt(val)
     int		*val;	
 {
     ncopts = *val;
@@ -534,7 +552,7 @@ ncpopt(val)
 
 /* used to get the C global variable ncopts from Fortran */
 void
-ncgopt(val)
+nncgopt(val)
     int		*val;	
 {
     *val = ncopts;
@@ -545,7 +563,7 @@ ncgopt(val)
  * file is placed in define mode.
  */
 int
-nccre(pathname, clobmode, rcode, pathnamelen)
+nnccre(pathname, clobmode, rcode, pathnamelen)
     char	*pathname;	
     int		pathnamelen;
     int		*clobmode;	
@@ -566,7 +584,7 @@ nccre(pathname, clobmode, rcode, pathnamelen)
 
 /* opens an existing netCDF file for access */
 int
-ncopn(pathname, rwmode, rcode, pathnamelen)
+nncopn(pathname, rwmode, rcode, pathnamelen)
     char	*pathname;	
     int		pathnamelen;
     int		*rwmode;	
@@ -587,7 +605,7 @@ ncopn(pathname, rwmode, rcode, pathnamelen)
 
 /* adds a new dimension to an open netCDF file in define mode */
 int
-ncddef(cdfid, dimname, dimlen, rcode, dimnamelen)
+nncddef(cdfid, dimname, dimlen, rcode, dimnamelen)
     int		*cdfid;	
     char	*dimname;	
     int		dimnamelen;
@@ -612,7 +630,7 @@ ncddef(cdfid, dimname, dimlen, rcode, dimnamelen)
  * dimension
  */
 int
-ncdid(cdfid, dimname, rcode, dimnamelen)
+nncdid(cdfid, dimname, rcode, dimnamelen)
     int		*cdfid;	
     char	*dimname;	
     int		dimnamelen;
@@ -633,7 +651,7 @@ ncdid(cdfid, dimname, rcode, dimnamelen)
 
 /* adds a new variable to an open netCDF file in define mode */
 int
-ncvdef(cdfid, varname, datatype, ndims, dimarray, rcode, varnamelen)
+nncvdef(cdfid, varname, datatype, ndims, dimarray, rcode, varnamelen)
     int		*cdfid;	
     char	*varname;	
     int		varnamelen;
@@ -661,7 +679,7 @@ ncvdef(cdfid, varname, datatype, ndims, dimarray, rcode, varnamelen)
 
 /* returns the ID of a netCDF variable given its name */
 int
-ncvid(cdfid, varname, rcode, varnamelen)
+nncvid(cdfid, varname, rcode, varnamelen)
     int		*cdfid;	
     char	*varname;	
     int		varnamelen;
@@ -682,7 +700,7 @@ ncvid(cdfid, varname, rcode, varnamelen)
 
 /* returns number of bytes per netCDF data type */
 int
-nctlen(datatype, rcode)
+nnctlen(datatype, rcode)
     int		*datatype;	
     int		*rcode;	
 {
@@ -698,7 +716,7 @@ nctlen(datatype, rcode)
 
 /* closes an open netCDF file */
 void
-ncclos(cdfid, rcode)
+nncclos(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -709,7 +727,7 @@ ncclos(cdfid, rcode)
 
 /* puts an open netCDF into define mode */
 void
-ncredf(cdfid, rcode)
+nncredf(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -720,7 +738,7 @@ ncredf(cdfid, rcode)
 
 /* takes an open netCDF out of define mode */
 void
-ncendf(cdfid, rcode)
+nncendf(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -731,7 +749,7 @@ ncendf(cdfid, rcode)
 
 /* returns information about an open netCDF file given its netCDF ID */
 void
-ncinq(cdfid, ndims, nvars, natts, recdim, rcode)
+nncinq(cdfid, ndims, nvars, natts, recdim, rcode)
     int		*cdfid;	
     int		*ndims;	
     int		*nvars;	
@@ -753,7 +771,7 @@ ncinq(cdfid, ndims, nvars, natts, recdim, rcode)
  * is current
  */
 void
-ncsnc(cdfid, rcode)
+nncsnc(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -768,7 +786,7 @@ ncsnc(cdfid, rcode)
  * or attributes
  */
 void
-ncabor(cdfid, rcode)
+nncabor(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -779,7 +797,7 @@ ncabor(cdfid, rcode)
 
 /* returns the name and size of a dimension, given its ID */
 void
-ncdinq(cdfid, dimid, dimname, size, rcode, dimnamelen)
+nncdinq(cdfid, dimid, dimname, size, rcode, dimnamelen)
     int		*cdfid;	
     int		*dimid;	
     char	*dimname;	
@@ -807,7 +825,7 @@ ncdinq(cdfid, dimid, dimname, size, rcode, dimnamelen)
 
 /* renames an existing dimension in a netCDF open for writing */
 void
-ncdren(cdfid, dimid, dimname, rcode, dimnamelen)
+nncdren(cdfid, dimid, dimname, rcode, dimnamelen)
     int		*cdfid;	
     int		*dimid;	
     char	*dimname;	
@@ -824,7 +842,7 @@ ncdren(cdfid, dimid, dimname, rcode, dimnamelen)
 
 /* returns information about a netCDF variable, given its ID */
 void
-ncvinq(cdfid, varid, varname, datatype, ndims, dimarray, natts, rcode, varnamelen)
+nncvinq(cdfid, varid, varname, datatype, ndims, dimarray, natts, rcode, varnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*varname;	
@@ -857,7 +875,7 @@ ncvinq(cdfid, varid, varname, datatype, ndims, dimarray, natts, rcode, varnamele
 
 /* puts a single numeric data value into a variable of an open netCDF */
 void
-ncvpt1(cdfid, varid, indices, value, rcode)
+nncvpt1(cdfid, varid, indices, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*indices;	
@@ -899,7 +917,7 @@ ncvpt1(cdfid, varid, indices, value, rcode)
 	return;
     }				/* else */
 #endif				/* FORTRAN_HAS_NO_SHORT */
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
 #ifdef HDF
     if ((nc_type) datatype == NC_LONG && handle->file_type!=HDF_FILE) {
 	long          longs = *(int *)value;
@@ -925,7 +943,7 @@ ncvpt1(cdfid, varid, indices, value, rcode)
 
 /* puts a single character into an open netCDF file */
 void
-ncvp1c(cdfid, varid, indices, chval, rcode, chvallen)
+nncvp1c(cdfid, varid, indices, chval, rcode, chvallen)
     int		*cdfid;	
     int		*varid;	
     int		*indices;	
@@ -956,7 +974,7 @@ ncvp1c(cdfid, varid, indices, chval, rcode, chvallen)
  * netCDF file
  */
 void
-ncvpt(cdfid, varid, start, count, value, rcode)
+nncvpt(cdfid, varid, start, count, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1013,7 +1031,7 @@ ncvpt(cdfid, varid, start, count, value, rcode)
 	return;
     }				/* else */
 #endif				/* FORTRAN_HAS_NO_SHORT */
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
 #ifdef HDF
     if ((nc_type) datatype == NC_LONG && handle->file_type!=HDF_FILE) {
 	long *longs = itol (value, ncount, ndims);
@@ -1051,7 +1069,7 @@ ncvpt(cdfid, varid, start, count, value, rcode)
 
 /* writes a hypercube of character values into an open netCDF file */
 void
-ncvptc(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
+nncvptc(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1091,7 +1109,7 @@ ncvptc(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
  * an open netCDF file
  */
 void
-ncvptg(cdfid, varid, start, count, stride, basis, value, rcode)
+nncvptg(cdfid, varid, start, count, stride, basis, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1124,7 +1142,7 @@ ncvptg(cdfid, varid, start, count, stride, basis, value, rcode)
 	tmpbasis	= nctypelen(NC_LONG);
     else
 #endif
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
     if (datatype == NC_LONG)
 	tmpbasis	= sizeof(int);
     else
@@ -1181,7 +1199,7 @@ ncvptg(cdfid, varid, start, count, stride, basis, value, rcode)
 	return;
     }				/* else */
 #endif				/* FORTRAN_HAS_NO_SHORT */
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
 #ifdef HDF
     if ((nc_type) datatype == NC_LONG && handle->file_type!=HDF_FILE) {
 	long *longs = itolg (value, ncount, nbasis, ndims);
@@ -1223,7 +1241,7 @@ ncvptg(cdfid, varid, start, count, stride, basis, value, rcode)
  * an open netCDF file
  */
 void
-ncvpgc(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
+nncvpgc(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1266,7 +1284,7 @@ ncvpgc(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
 
 /* gets a single numeric value from a variable of an open netCDF file */
 void
-ncvgt1(cdfid, varid, indices, value, rcode)
+nncvgt1(cdfid, varid, indices, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*indices;	
@@ -1317,7 +1335,7 @@ ncvgt1(cdfid, varid, indices, value, rcode)
 	return;
     }				/* else */
 #endif				/* FORTRAN_HAS_NO_SHORT */
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
 #ifdef HDF
     if ((nc_type) datatype == NC_LONG && handle->file_type!=HDF_FILE) {
 	long          longs;
@@ -1354,7 +1372,7 @@ ncvgt1(cdfid, varid, indices, value, rcode)
  * netCDF file
  */
 void
-ncvg1c(cdfid, varid, indices, chval, rcode, chvallen)
+nncvg1c(cdfid, varid, indices, chval, rcode, chvallen)
     int		*cdfid;	
     int		*varid;	
     int		*indices;	
@@ -1386,7 +1404,7 @@ ncvg1c(cdfid, varid, indices, chval, rcode, chvallen)
  * netCDF file
  */
 void
-ncvgt(cdfid, varid, start, count, value, rcode)
+nncvgt(cdfid, varid, start, count, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1459,13 +1477,19 @@ ncvgt(cdfid, varid, start, count, value, rcode)
 	return;
     }				/* else */
 #endif				/* FORTRAN_HAS_NO_SHORT */
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
 #ifdef HDF
     if ((nc_type) datatype == NC_LONG && handle->file_type!=HDF_FILE) {
 	long iocount = dimprod (ncount, ndims);	/* product of dimensions */
+
+/* EIP  We need to use int instead of long on all platfroms where long is 8 bytes
 	long *longs = (long *) malloc (iocount * sizeof (long));
 	int *ip;
 	long *lp = longs;
+*/
+	int *longs = (int *) malloc (iocount * sizeof (int));
+	int *ip;
+	int *lp = longs;
 
 	if (longs == NULL) {
 	    *rcode = NC_SYSERR;
@@ -1513,7 +1537,7 @@ ncvgt(cdfid, varid, start, count, value, rcode)
 
 /* reads a hypercube of character values from a netCDF variable */
 void
-ncvgtc(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
+nncvgtc(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1559,7 +1583,7 @@ ncvgtc(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
  * open netCDF file
  */
 void
-ncvgtg(cdfid, varid, start, count, stride, basis, value, rcode)
+nncvgtg(cdfid, varid, start, count, stride, basis, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1592,7 +1616,8 @@ ncvgtg(cdfid, varid, start, count, stride, basis, value, rcode)
 	tmpbasis	= nctypelen(NC_LONG);
     else
 #endif
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
+
     if (datatype == NC_LONG)
 	tmpbasis	= sizeof(int);
     else
@@ -1663,7 +1688,8 @@ ncvgtg(cdfid, varid, start, count, stride, basis, value, rcode)
 	return;
     }				/* else */
 #endif				/* FORTRAN_HAS_NO_SHORT */
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
+
 #ifdef HDF
     if ((nc_type) datatype == NC_LONG && handle->file_type!=HDF_FILE) {
 	long iocount = dimprod (ncount, ndims);	/* product of dimensions */
@@ -1715,7 +1741,7 @@ ncvgtg(cdfid, varid, start, count, stride, basis, value, rcode)
  * of an open netCDF file
  */
 void
-ncvggc(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
+nncvggc(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1758,7 +1784,7 @@ ncvggc(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
 
 /* changes the name of a netCDF variable in an open netCDF file */
 void
-ncvren(cdfid, varid, varname, rcode, varnamelen)
+nncvren(cdfid, varid, varname, rcode, varnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*varname;	
@@ -1779,7 +1805,7 @@ ncvren(cdfid, varid, varname, rcode, varnamelen)
  * netCDF file
  */
 void
-ncapt(cdfid, varid, attname, datatype, attlen, value, rcode, attnamelen)
+nncapt(cdfid, varid, attname, datatype, attlen, value, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1829,7 +1855,8 @@ ncapt(cdfid, varid, attname, datatype, attlen, value, rcode, attnamelen)
 	return;
     }				/* else */
 #endif				/* FORTRAN_HAS_NO_SHORT */
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
+
 #ifdef HDF
     if ((nc_type) *datatype == NC_LONG && handle->file_type!=HDF_FILE) {
 	long *longs = itol (value, attlen, 1);
@@ -1873,7 +1900,7 @@ ncapt(cdfid, varid, attname, datatype, attlen, value, rcode, attnamelen)
  * of an open netCDF file
  */
 void
-ncaptc(cdfid, varid, attname, datatype, lenstr, string, rcode, attnamelen, stringlen)
+nncaptc(cdfid, varid, attname, datatype, lenstr, string, rcode, attnamelen, stringlen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1907,7 +1934,7 @@ ncaptc(cdfid, varid, attname, datatype, lenstr, string, rcode, attnamelen, strin
  * ID and name
  */
 void
-ncainq(cdfid, varid, attname, datatype, attlen, rcode, attnamelen)
+nncainq(cdfid, varid, attname, datatype, attlen, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1930,7 +1957,7 @@ ncainq(cdfid, varid, attname, datatype, attlen, rcode, attnamelen)
  * and name
  */
 void
-ncagt(cdfid, varid, attname, value, rcode, attnamelen)
+nncagt(cdfid, varid, attname, value, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1994,12 +2021,20 @@ ncagt(cdfid, varid, attname, value, rcode, attnamelen)
 	return;
     }				/* else */
 #endif				/* FORTRAN_HAS_NO_SHORT */
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
+
 #ifdef HDF
     if ((nc_type) datatype == NC_LONG && handle->file_type!=HDF_FILE) {
+/* EIP  We have to use int buffer to read data in on all platforms
+        where long is 8
+
 	long *longs = (long *) malloc (attlen * sizeof (long));
 	int *ip;
 	long *lp = longs;
+*/
+	int *longs = (int *) malloc (attlen * sizeof (int));
+	int *ip;
+	int *lp = longs;
 
 	if (longs == NULL) {
 	    *rcode = NC_SYSERR;
@@ -2047,7 +2082,7 @@ ncagt(cdfid, varid, attname, value, rcode, attnamelen)
  * ID and name
  */
 void
-ncagtc(cdfid, varid, attname, string, lenstr, rcode, attnamelen, stringlen)
+nncagtc(cdfid, varid, attname, string, lenstr, rcode, attnamelen, stringlen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -2084,7 +2119,7 @@ ncagtc(cdfid, varid, attname, string, lenstr, rcode, attnamelen, stringlen)
 
 /* copies an attribute from one open netCDF file to another */
 void
-ncacpy(incdfid, invarid, attname, outcdfid, outvarid, rcode, attnamelen)
+nncacpy(incdfid, invarid, attname, outcdfid, outvarid, rcode, attnamelen)
     int		*incdfid;	
     int		*invarid;	
     char	*attname;	
@@ -2108,7 +2143,7 @@ ncacpy(incdfid, invarid, attname, outcdfid, outvarid, rcode, attnamelen)
  * as an attribute of that variable
  */
 void
-ncanam(cdfid, varid, attnum, attname, rcode, attnamelen)
+nncanam(cdfid, varid, attnum, attname, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     int		*attnum;	
@@ -2134,7 +2169,7 @@ ncanam(cdfid, varid, attnum, attname, rcode, attnamelen)
 
 /* renames an attribute in an open netCDF file */
 void
-ncaren(cdfid, varid, attname, newname, rcode, attnamelen, newnamelen)
+nncaren(cdfid, varid, attname, newname, rcode, attnamelen, newnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -2158,7 +2193,7 @@ ncaren(cdfid, varid, attname, newname, rcode, attnamelen, newnamelen)
  * name
  */
 void
-ncadel(cdfid, varid, attname, rcode, attnamelen)
+nncadel(cdfid, varid, attname, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -2179,7 +2214,7 @@ ncadel(cdfid, varid, attname, rcode, attnamelen)
  * sets the fill mode of a netCDF file open for writing
  */
 int
-ncsfil(cdfid, fillmode, rcode)
+nncsfil(cdfid, fillmode, rcode)
     int		*cdfid;	
     int		*fillmode;	
     int		*rcode;	
