@@ -2,7 +2,7 @@
  *	Copyright 1990, University Corporation for Atmospheric Research
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: jackets-fbsd.c,v 1.4 1997/11/05 19:40:02 koziol Exp $ */
+/* $Id: jackets-fbsd.c 4772 2006-11-01 16:53:11Z epourmal $ */
 /*
  * OVERVIEW
  *
@@ -34,7 +34,7 @@
 
 struct ncfils {			/* This will be a common block from Fortran */
     double dd;
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
     int ll;
 #else
     long ll;
@@ -65,7 +65,7 @@ struct ncfils {			/* This will be a common block from Fortran */
 
 struct ncfils {			/* This will be a common block from Fortran */
     double dd;
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
     int ll;
 #else
     long ll;
@@ -163,7 +163,7 @@ fstrncpy (target, source, maxlen)
 	*target++ = *source++;
     *target = '\0';
 }
-
+#ifdef WE_COULDNT_READ_NAMES_WITH_SPACES
 /* copy function used to copy strings terminated with blanks */
 static void
 nstrncpy (target, source, maxlen)
@@ -175,7 +175,25 @@ nstrncpy (target, source, maxlen)
 	*target++ = *source++;
     *target = '\0';
 }
+#endif
 
+/* copy function used to copy strings with embeded blanks and
+   terminated with blanks */
+static void
+nstrncpy (target, source, maxlen)
+    char *target;		/* space to be copied into */
+    char *source;		/* string to be copied */
+    int maxlen;			/* maximum length of *source */
+{
+/* Copy all string */
+    while (maxlen--) 
+        *target++ = *source++;
+    *target -- = '\0';
+/* Disregard all trailing spaces  */
+     while (*target == ' ')
+         *target-- = '\0';
+
+}
 
 /*
  * Compute product of dimensions.
@@ -412,7 +430,7 @@ stoig(shorts, ints, dims, basis, ndims)
 }
 #endif /* FORTRAN_HAS_NO_SHORT */
 
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
 /*
  * Convert multi-dimensional array of NCLONGs stored in ints to packed
  * array of longs, in malloc'ed space.  Returns pointer to longs or NULL
@@ -525,7 +543,7 @@ ltoig(longs, ints, dims, imap, ndims)
 
 /* used to set the C global variable ncopts from Fortran */
 void
-ncpopt_(val)
+nncpopt(val)
     int		*val;	
 {
     ncopts = *val;
@@ -534,7 +552,7 @@ ncpopt_(val)
 
 /* used to get the C global variable ncopts from Fortran */
 void
-ncgopt_(val)
+nncgopt(val)
     int		*val;	
 {
     *val = ncopts;
@@ -545,7 +563,7 @@ ncgopt_(val)
  * file is placed in define mode.
  */
 int
-nccre_(pathname, clobmode, rcode, pathnamelen)
+nnccre(pathname, clobmode, rcode, pathnamelen)
     char	*pathname;	
     int		pathnamelen;
     int		*clobmode;	
@@ -566,7 +584,7 @@ nccre_(pathname, clobmode, rcode, pathnamelen)
 
 /* opens an existing netCDF file for access */
 int
-ncopn_(pathname, rwmode, rcode, pathnamelen)
+nncopn(pathname, rwmode, rcode, pathnamelen)
     char	*pathname;	
     int		pathnamelen;
     int		*rwmode;	
@@ -587,7 +605,7 @@ ncopn_(pathname, rwmode, rcode, pathnamelen)
 
 /* adds a new dimension to an open netCDF file in define mode */
 int
-ncddef_(cdfid, dimname, dimlen, rcode, dimnamelen)
+nncddef(cdfid, dimname, dimlen, rcode, dimnamelen)
     int		*cdfid;	
     char	*dimname;	
     int		dimnamelen;
@@ -612,7 +630,7 @@ ncddef_(cdfid, dimname, dimlen, rcode, dimnamelen)
  * dimension
  */
 int
-ncdid_(cdfid, dimname, rcode, dimnamelen)
+nncdid(cdfid, dimname, rcode, dimnamelen)
     int		*cdfid;	
     char	*dimname;	
     int		dimnamelen;
@@ -633,7 +651,7 @@ ncdid_(cdfid, dimname, rcode, dimnamelen)
 
 /* adds a new variable to an open netCDF file in define mode */
 int
-ncvdef_(cdfid, varname, datatype, ndims, dimarray, rcode, varnamelen)
+nncvdef(cdfid, varname, datatype, ndims, dimarray, rcode, varnamelen)
     int		*cdfid;	
     char	*varname;	
     int		varnamelen;
@@ -661,7 +679,7 @@ ncvdef_(cdfid, varname, datatype, ndims, dimarray, rcode, varnamelen)
 
 /* returns the ID of a netCDF variable given its name */
 int
-ncvid_(cdfid, varname, rcode, varnamelen)
+nncvid(cdfid, varname, rcode, varnamelen)
     int		*cdfid;	
     char	*varname;	
     int		varnamelen;
@@ -682,7 +700,7 @@ ncvid_(cdfid, varname, rcode, varnamelen)
 
 /* returns number of bytes per netCDF data type */
 int
-nctlen_(datatype, rcode)
+nnctlen(datatype, rcode)
     int		*datatype;	
     int		*rcode;	
 {
@@ -698,7 +716,7 @@ nctlen_(datatype, rcode)
 
 /* closes an open netCDF file */
 void
-ncclos_(cdfid, rcode)
+nncclos(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -709,7 +727,7 @@ ncclos_(cdfid, rcode)
 
 /* puts an open netCDF into define mode */
 void
-ncredf_(cdfid, rcode)
+nncredf(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -720,7 +738,7 @@ ncredf_(cdfid, rcode)
 
 /* takes an open netCDF out of define mode */
 void
-ncendf_(cdfid, rcode)
+nncendf(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -731,7 +749,7 @@ ncendf_(cdfid, rcode)
 
 /* returns information about an open netCDF file given its netCDF ID */
 void
-ncinq_(cdfid, ndims, nvars, natts, recdim, rcode)
+nncinq(cdfid, ndims, nvars, natts, recdim, rcode)
     int		*cdfid;	
     int		*ndims;	
     int		*nvars;	
@@ -753,7 +771,7 @@ ncinq_(cdfid, ndims, nvars, natts, recdim, rcode)
  * is current
  */
 void
-ncsnc_(cdfid, rcode)
+nncsnc(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -768,7 +786,7 @@ ncsnc_(cdfid, rcode)
  * or attributes
  */
 void
-ncabor_(cdfid, rcode)
+nncabor(cdfid, rcode)
     int		*cdfid;	
     int		*rcode;	
 {
@@ -779,7 +797,7 @@ ncabor_(cdfid, rcode)
 
 /* returns the name and size of a dimension, given its ID */
 void
-ncdinq_(cdfid, dimid, dimname, size, rcode, dimnamelen)
+nncdinq(cdfid, dimid, dimname, size, rcode, dimnamelen)
     int		*cdfid;	
     int		*dimid;	
     char	*dimname;	
@@ -807,7 +825,7 @@ ncdinq_(cdfid, dimid, dimname, size, rcode, dimnamelen)
 
 /* renames an existing dimension in a netCDF open for writing */
 void
-ncdren_(cdfid, dimid, dimname, rcode, dimnamelen)
+nncdren(cdfid, dimid, dimname, rcode, dimnamelen)
     int		*cdfid;	
     int		*dimid;	
     char	*dimname;	
@@ -824,7 +842,7 @@ ncdren_(cdfid, dimid, dimname, rcode, dimnamelen)
 
 /* returns information about a netCDF variable, given its ID */
 void
-ncvinq_(cdfid, varid, varname, datatype, ndims, dimarray, natts, rcode, varnamelen)
+nncvinq(cdfid, varid, varname, datatype, ndims, dimarray, natts, rcode, varnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*varname;	
@@ -857,7 +875,7 @@ ncvinq_(cdfid, varid, varname, datatype, ndims, dimarray, natts, rcode, varnamel
 
 /* puts a single numeric data value into a variable of an open netCDF */
 void
-ncvpt1_(cdfid, varid, indices, value, rcode)
+nncvpt1(cdfid, varid, indices, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*indices;	
@@ -903,7 +921,7 @@ ncvpt1_(cdfid, varid, indices, value, rcode)
 
 /* puts a single character into an open netCDF file */
 void
-ncvp1c_(cdfid, varid, indices, chval, rcode, chvallen)
+nncvp1c(cdfid, varid, indices, chval, rcode, chvallen)
     int		*cdfid;	
     int		*varid;	
     int		*indices;	
@@ -934,7 +952,7 @@ ncvp1c_(cdfid, varid, indices, chval, rcode, chvallen)
  * netCDF file
  */
 void
-ncvpt_(cdfid, varid, start, count, value, rcode)
+nncvpt(cdfid, varid, start, count, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -995,7 +1013,7 @@ ncvpt_(cdfid, varid, start, count, value, rcode)
 
 /* writes a hypercube of character values into an open netCDF file */
 void
-ncvptc_(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
+nncvptc(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1035,7 +1053,7 @@ ncvptc_(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
  * an open netCDF file
  */
 void
-ncvptg_(cdfid, varid, start, count, stride, basis, value, rcode)
+nncvptg(cdfid, varid, start, count, stride, basis, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1065,7 +1083,7 @@ ncvptg_(cdfid, varid, start, count, stride, basis, value, rcode)
 	tmpbasis	= nctypelen(NC_LONG);
     else
 #endif
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
     if (datatype == NC_LONG)
 	tmpbasis	= sizeof(int);
     else
@@ -1133,7 +1151,7 @@ ncvptg_(cdfid, varid, start, count, stride, basis, value, rcode)
  * an open netCDF file
  */
 void
-ncvpgc_(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
+nncvpgc(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1176,7 +1194,7 @@ ncvpgc_(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
 
 /* gets a single numeric value from a variable of an open netCDF file */
 void
-ncvgt1_(cdfid, varid, indices, value, rcode)
+nncvgt1(cdfid, varid, indices, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*indices;	
@@ -1234,7 +1252,7 @@ ncvgt1_(cdfid, varid, indices, value, rcode)
  * netCDF file
  */
 void
-ncvg1c_(cdfid, varid, indices, chval, rcode, chvallen)
+nncvg1c(cdfid, varid, indices, chval, rcode, chvallen)
     int		*cdfid;	
     int		*varid;	
     int		*indices;	
@@ -1266,7 +1284,7 @@ ncvg1c_(cdfid, varid, indices, chval, rcode, chvallen)
  * netCDF file
  */
 void
-ncvgt_(cdfid, varid, start, count, value, rcode)
+nncvgt(cdfid, varid, start, count, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1343,7 +1361,7 @@ ncvgt_(cdfid, varid, start, count, value, rcode)
 
 /* reads a hypercube of character values from a netCDF variable */
 void
-ncvgtc_(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
+nncvgtc(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1389,7 +1407,7 @@ ncvgtc_(cdfid, varid, start, count, string, lenstr, rcode, stringlen)
  * open netCDF file
  */
 void
-ncvgtg_(cdfid, varid, start, count, stride, basis, value, rcode)
+nncvgtg(cdfid, varid, start, count, stride, basis, value, rcode)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1419,7 +1437,7 @@ ncvgtg_(cdfid, varid, start, count, stride, basis, value, rcode)
 	tmpbasis	= nctypelen(NC_LONG);
     else
 #endif
-#if defined __alpha || (_MIPS_SZLONG == 64)
+#if defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__
     if (datatype == NC_LONG)
 	tmpbasis	= sizeof(int);
     else
@@ -1501,7 +1519,7 @@ ncvgtg_(cdfid, varid, start, count, stride, basis, value, rcode)
  * of an open netCDF file
  */
 void
-ncvggc_(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
+nncvggc(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
     int		*cdfid;	
     int		*varid;	
     int		*start;	
@@ -1544,7 +1562,7 @@ ncvggc_(cdfid, varid, start, count, stride, basis, string, rcode, stringlen)
 
 /* changes the name of a netCDF variable in an open netCDF file */
 void
-ncvren_(cdfid, varid, varname, rcode, varnamelen)
+nncvren(cdfid, varid, varname, rcode, varnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*varname;	
@@ -1565,7 +1583,7 @@ ncvren_(cdfid, varid, varname, rcode, varnamelen)
  * netCDF file
  */
 void
-ncapt_(cdfid, varid, attname, datatype, attlen, value, rcode, attnamelen)
+nncapt(cdfid, varid, attname, datatype, attlen, value, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1623,7 +1641,7 @@ ncapt_(cdfid, varid, attname, datatype, attlen, value, rcode, attnamelen)
  * of an open netCDF file
  */
 void
-ncaptc_(cdfid, varid, attname, datatype, lenstr, string, rcode, attnamelen, stringlen)
+nncaptc(cdfid, varid, attname, datatype, lenstr, string, rcode, attnamelen, stringlen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1657,7 +1675,7 @@ ncaptc_(cdfid, varid, attname, datatype, lenstr, string, rcode, attnamelen, stri
  * ID and name
  */
 void
-ncainq_(cdfid, varid, attname, datatype, attlen, rcode, attnamelen)
+nncainq(cdfid, varid, attname, datatype, attlen, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1680,7 +1698,7 @@ ncainq_(cdfid, varid, attname, datatype, attlen, rcode, attnamelen)
  * and name
  */
 void
-ncagt_(cdfid, varid, attname, value, rcode, attnamelen)
+nncagt(cdfid, varid, attname, value, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1751,7 +1769,7 @@ ncagt_(cdfid, varid, attname, value, rcode, attnamelen)
  * ID and name
  */
 void
-ncagtc_(cdfid, varid, attname, string, lenstr, rcode, attnamelen, stringlen)
+nncagtc(cdfid, varid, attname, string, lenstr, rcode, attnamelen, stringlen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1788,7 +1806,7 @@ ncagtc_(cdfid, varid, attname, string, lenstr, rcode, attnamelen, stringlen)
 
 /* copies an attribute from one open netCDF file to another */
 void
-ncacpy_(incdfid, invarid, attname, outcdfid, outvarid, rcode, attnamelen)
+nncacpy(incdfid, invarid, attname, outcdfid, outvarid, rcode, attnamelen)
     int		*incdfid;	
     int		*invarid;	
     char	*attname;	
@@ -1812,7 +1830,7 @@ ncacpy_(incdfid, invarid, attname, outcdfid, outvarid, rcode, attnamelen)
  * as an attribute of that variable
  */
 void
-ncanam_(cdfid, varid, attnum, attname, rcode, attnamelen)
+nncanam(cdfid, varid, attnum, attname, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     int		*attnum;	
@@ -1838,7 +1856,7 @@ ncanam_(cdfid, varid, attnum, attname, rcode, attnamelen)
 
 /* renames an attribute in an open netCDF file */
 void
-ncaren_(cdfid, varid, attname, newname, rcode, attnamelen, newnamelen)
+nncaren(cdfid, varid, attname, newname, rcode, attnamelen, newnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1862,7 +1880,7 @@ ncaren_(cdfid, varid, attname, newname, rcode, attnamelen, newnamelen)
  * name
  */
 void
-ncadel_(cdfid, varid, attname, rcode, attnamelen)
+nncadel(cdfid, varid, attname, rcode, attnamelen)
     int		*cdfid;	
     int		*varid;	
     char	*attname;	
@@ -1883,7 +1901,7 @@ ncadel_(cdfid, varid, attname, rcode, attnamelen)
  * sets the fill mode of a netCDF file open for writing
  */
 int
-ncsfil_(cdfid, fillmode, rcode)
+nncsfil(cdfid, fillmode, rcode)
     int		*cdfid;	
     int		*fillmode;	
     int		*rcode;	
