@@ -1,10 +1,25 @@
-C
+C * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+C  Copyright by The HDF Group.                                               *
+C  Copyright by the Board of Trustees of the University of Illinois.         *
+C  All rights reserved.                                                      *
+C                                                                            *
+C  This file is part of HDF.  The full HDF copyright notice, including       *
+C  terms governing use, modification, and redistribution, is contained in    *
+C  the files COPYING and Copyright.html.  COPYING can be found at the root   *
+C  of the source code distribution tree; Copyright.html can be found at      *
+C  http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+C  access to either file, you may request a copy from help@hdfgroup.org.     *
+C * * * * * * * * *  * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 C     Testing the Fortran interface for the multiple SD routines
 C
       program hdftest
 
       implicit none
 
+      include 'mffunc.inc'
+      integer hxsdir, hxscdir
+      external hxsdir, hxscdir
+
       integer fid1, fid2
       integer fid_empty
 
@@ -28,18 +43,6 @@ C
       character catt(2), icatt(2)
       integer*4   i32(2), ii32(2), max32, min32
       integer*4 natt(2), inatt(2)
-
-      integer sfstart,  sfcreate,  sfendacc, sfend,    sfsfill
-      integer sfrdata,  sfwdata,   sfdimid,  sfsdmname
-      integer sffinfo,  sfn2index, sfsdmstr, sfsdtstr, sfsdscale
-      integer sfscal,   sfselect,  sfginfo,  sfgdinfo, sfgainfo
-      integer sffattr,  sfsrange,  sfgrange, sfgfill,  sfsflmd
-      integer sfgcal,   sfgdscale, sfgdtstr, sfgdmstr
-      integer sfid2ref, sfref2index, sfsdmvc, sfisdmvc
-      integer sfsextf,  hxsdir,    hxscdir
-      integer sfwcdata, sfrcdata,  sfscfill, sfgcfill
-      integer sfscatt,  sfrcatt,   sfsnatt,  sfrnatt
-      integer sfchempty
       integer SD_UNLIMITED, SD_DIMVAL_BW_INCOMP, DFNT_INT32
       integer DFNT_FLOAT32, DFNT_CHAR8
       integer SD_DIMVAL_BW_COMP, SD_FILL, SD_NOFILL
@@ -1209,7 +1212,9 @@ C
      .             sds_index(N_COMP_TYPES)
          integer   RANK, comp_type, c_out
          integer   comp_arg(N_COMP_ARG)
+         integer   comp_prm_out(N_COMP_ARG)
          integer   comp_type_out(N_COMP_TYPES)
+         integer   comp_typesd
          integer   d_dims(2)
          integer   ch_dims(2),ch_dims_out(2), start_dims(2)
          integer   start(2), stride(2), edges(2)
@@ -1228,10 +1233,11 @@ C
 C
 C  SDS functions declarations
 C
-         integer   sfstart, sfcreate, sfendacc, sfend,
-     .             sfn2index, sfselect,
-     .             sfsfill, sfschnk, sfscchnk, sfwchnk, 
-     .             sfgichnk, sfrchnk, sfwdata, sfrdata
+C         integer   sfstart, sfcreate, sfendacc, sfend,
+C     .             sfn2index, sfselect, sfgcompress,
+C     .             sfsfill, sfschnk, sfscchnk, sfwchnk, 
+C     .             sfgichnk, sfrchnk, sfwdata, sfrdata
+         include 'mffunc.inc'
 C
 C  Initial data declarations( change if you which to test larger arrays )
 C
@@ -1325,12 +1331,12 @@ C
      .           nbit_fill_one,
      .           nbit_start_bit,
      .           nbit_bit_len
-          parameter ( deflate_level    = 1,
+          parameter ( deflate_level    = 6,
      .                skphuff_skp_size = 2,
      .                nbit_sign_ext    = 0,
      .                nbit_fill_one    = 0,
-     .                nbit_start_bit   = 0,
-     .                nbit_bit_len     = 31 )
+     .                nbit_start_bit   = 6,
+     .                nbit_bit_len     = 7 )
 
 
 C
@@ -1580,6 +1586,60 @@ C
                 print *, 'sfselect failed for', i, ' -th dataset'
                 err_chunk = err_chunk + 1
             endif
+C
+C  Find out type of compression used and compression parameters.
+C
+            status = sfgcompress(sds_id(i), comp_typesd, comp_prm_out)
+	    if (status .eq. -1) then
+            print *, 'sfgcompress failed for', i, ' -th dataset'
+                err_chunk = err_chunk + 1
+            endif
+            if (name(i) .eq. 'Nocomp_data') then
+                if (comp_typesd .ne. COMP_CODE_NONE) then
+            print *, 'wrong compression type for Nocomp_data dataset'
+                err_chunk = err_chunk + 1
+                endif
+            endif
+            if (name(i) .eq. 'Rlcomp_data') then
+                if (comp_typesd .ne. COMP_CODE_RLE) then
+            print *, 'wrong compression type for Rlcomp_data dataset'
+                err_chunk = err_chunk + 1
+                endif
+            endif
+            if (name(i) .eq. 'Hucomp_data') then
+                if (comp_typesd .ne. COMP_CODE_SKPHUFF) then
+            print *, 'wrong compression type for Hucomp_data dataset'
+                err_chunk = err_chunk + 1
+                endif
+                if (comp_prm_out(1). ne. skphuff_skp_size) then
+         print *, 'wrong compression parameter for Hucomp_data dataset'
+                err_chunk = err_chunk + 1
+                endif
+
+            endif
+            if (name(i) .eq. 'Gzcomp_data') then
+                if (comp_typesd .ne. COMP_CODE_DEFLATE) then
+          print *, 'wrong compression type for Gzcomp_data dataset'
+                endif
+                if (comp_prm_out(1). ne. deflate_level) then
+          print *, 'wrong compression parameter for Gzcomp_data dataset'
+                err_chunk = err_chunk + 1
+                endif
+            endif
+
+            if (name(i) .eq. 'Nbcomp_data') then
+                if (comp_typesd .ne. COMP_CODE_NBIT) then
+          print *, 'wrong compression type for Nbcomp_data dataset'
+                endif
+                if ((comp_prm_out(1) .ne. nbit_sign_ext) .or.
+     .          (comp_prm_out(2) .ne. nbit_fill_one) .or.
+     .          (comp_prm_out(3) .ne. nbit_start_bit) .or.
+     .          (comp_prm_out(4) .ne. nbit_bit_len)) then
+          print *, 'wrong compression parameter for Nbcomp_data dataset'
+                err_chunk = err_chunk + 1
+                endif
+            endif
+
 201      continue
 
 C
@@ -1734,10 +1794,11 @@ C
 C
 C  SDS functions declarations
 C
-         integer   sfstart, sfcreate, sfendacc, sfend,
-     .             sfn2index, sfselect,
-     .             sfsfill, sfschnk, sfscchnk, sfwcchnk, 
-     .             sfgichnk, sfrcchnk, sfwcdata, sfrcdata
+C         integer   sfstart, sfcreate, sfendacc, sfend,
+C     .             sfn2index, sfselect,
+C     .             sfsfill, sfschnk, sfscchnk, sfwcchnk, 
+C     .             sfgichnk, sfrcchnk, sfwcdata, sfrcdata
+         include 'mffunc.inc'
 C
 C  Initial data declarations( change if you which to test larger arrays )
 C
@@ -1831,12 +1892,12 @@ C
      .           nbit_fill_one,
      .           nbit_start_bit,
      .           nbit_bit_len
-          parameter ( deflate_level    = 1,
+          parameter ( deflate_level    = 6,
      .                skphuff_skp_size = 2,
      .                nbit_sign_ext    = 0,
      .                nbit_fill_one    = 0,
-     .                nbit_start_bit   = 0,
-     .                nbit_bit_len     = 31 )
+     .                nbit_start_bit   = 6,
+     .                nbit_bit_len     = 7 )
 
 
 C
@@ -2221,8 +2282,8 @@ C
          integer   sd_id(N_COMP_TYPES),
      .             sds_id(N_COMP_TYPES),
      .             sds_index(N_COMP_TYPES)
-         integer   RANK, comp_type
-         integer   comp_arg(N_COMP_ARG)
+         integer   RANK, comp_type, comp_type_out
+         integer   comp_arg(N_COMP_ARG), comp_prm_out(N_COMP_ARG)
          integer   d_dims(2)
          integer   start(2), stride(2), edges(2)
          integer   status, fill_value
@@ -2239,10 +2300,11 @@ C
 C
 C  SDS functions declarations
 C
-         integer   sfstart, sfcreate, sfendacc, sfend,
-     .             sfn2index, sfselect,
-     .             sfsfill, sfrdata,
-     .             sfwdata, sfscompress
+C         integer   sfstart, sfcreate, sfendacc, sfend,
+C     .             sfn2index, sfselect,
+C     .             sfsfill, sfrdata,
+C     .             sfwdata, sfscompress, sfgcompress
+         include 'mffunc.inc'
 C
 C  Initial data declarations( change if you which to test larger arrays )
 C
@@ -2317,7 +2379,7 @@ C  will be passed to SFSCHUNK function via comp_arg parameter)
 C
          integer deflate_level,
      .           skphuff_skp_size
-          parameter ( deflate_level    = 1,
+          parameter ( deflate_level    = 6,
      .                skphuff_skp_size = 2 )
 
 
@@ -2475,6 +2537,46 @@ C
                 print *, 'sfselect failed for', i, ' -th dataset'
                 err_compress = err_compress + 1
             endif
+C
+C  Find out type of compression used and compression parameters.
+C
+            status = sfgcompress(sds_id(i), comp_type_out, comp_prm_out)
+	    if (status .eq. -1) then
+            print *, 'sfgcompress failed for', i, ' -th dataset'
+                err_compress = err_compress + 1
+            endif
+            if (name(i) .eq. 'Nocomp_data') then
+                if (comp_type_out .ne. COMP_CODE_NONE) then
+            print *, 'wrong compression type for Nocomp_data dataset'
+                err_compress = err_compress + 1
+                endif
+            endif
+            if (name(i) .eq. 'Rlcomp_data') then
+                if (comp_type_out .ne. COMP_CODE_RLE) then
+            print *, 'wrong compression type for Rlcomp_data dataset'
+                err_compress = err_compress + 1
+                endif
+            endif
+            if (name(i) .eq. 'Hucomp_data') then
+                if (comp_type_out .ne. COMP_CODE_SKPHUFF) then
+            print *, 'wrong compression type for Hucomp_data dataset'
+                err_compress = err_compress + 1
+                endif
+                if (comp_prm_out(1). ne. skphuff_skp_size) then
+         print *, 'wrong compression parameter for Hucomp_data dataset'
+                err_compress = err_compress + 1
+                endif
+
+            endif
+            if (name(i) .eq. 'Gzcomp_data') then
+                if (comp_type_out .ne. COMP_CODE_DEFLATE) then
+          print *, 'wrong compression type for Gzcomp_data dataset'
+                endif
+                if (comp_prm_out(1). ne. deflate_level) then
+          print *, 'wrong compression parameter for Gzcomp_data dataset'
+                err_compress = err_compress + 1
+                endif
+            endif
 
 
 C
