@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.44 $";
+static char RcsId[] = "@(#)$Revision: 4933 $";
 #endif
 
-/* $Id: hdfsds.c,v 1.44 1998/02/02 21:50:51 smitchel Exp $ */
+/* $Id: hdfsds.c 4933 2007-09-08 03:33:59Z bmribler $ */
 
 /***************************************************************************
  *
@@ -1132,6 +1133,10 @@ hdf_read_ndgs(NC *handle)
 #else /* NOT_YET */
                             vars[current_var]->ndg_ref  = Hnewref(handle->hdf_file);
 #endif /* NOT_YET */
+			    /* Indicate that it is unknown whether the current
+			       variable is an SDS or a coordinate variable.
+			       bugzilla 624 - BMR - 05/16/2007 */
+			    vars[current_var]->var_type  = UNKNOWN;
 
                             /*
                              * See if a scales record has been stored and if there have
@@ -1294,6 +1299,12 @@ hdf_read_ndgs(NC *handle)
                 vars[current_var]->data_ref = sdRef;
                 vars[current_var]->HDFtype  = HDFtype;
 
+		/* Indicate that it is unknown whether the current variable 
+		   is an SDS or a coordinate variable.  bugzilla 624 - BMR - 
+		   05/16/2007 */
+                vars[current_var]->var_type  = UNKNOWN;
+
+
                 /*
                  * NOTE:  If the user changes the file and saves setting this
                  *   to ndgRef will blow away the old ndgs (but they will get
@@ -1647,6 +1658,7 @@ hdf_read_ndgs(NC *handle)
                 else
                     vars[current_var]->attrs = NULL;
             
+
             
                 current_var++;
 
@@ -1733,7 +1745,6 @@ hdf_read_ndgs(NC *handle)
         
       } /* outermost for loop to loop between NDGs and SDGs */
 
-
 done:
     if (ret_value == FAIL)
       { /* FAIL cleanup? */
