@@ -1,11 +1,23 @@
-/*
- *	Copyright 1993, University Corporation for Atmospheric Research
- *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
- */
-/* $Id: local_nc.h,v 1.50 1999/02/25 19:02:43 koziol Exp $ */
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright 1993, University Corporation for Atmospheric Research           *
+ * See netcdf/COPYRIGHT file for copying and redistribution conditions.      *
+ *                                                                           *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+
+/* $Id: local_nc.h 5011 2008-01-14 04:32:45Z bmribler $ */
 #ifndef _LOCAL_NC_
 #define _LOCAL_NC_
-
+#include "h4config.h"
 /*
  *	netcdf library 'private' data structures, objects and interfaces
  */
@@ -54,7 +66,11 @@
 #endif /* !macintosh */
 #endif /* NO_SYSTEM_XDR_INCLUDES */
 
+#ifdef H4_HAVE_NETCDF
 #include	"netcdf.h" /* needed for defs of nc_type, ncvoid, ... */
+#else
+#include "hdf4_netcdf.h"
+#endif
 
 /* ptr argument type in internal functions */
 #define Void    char
@@ -67,6 +83,7 @@
 #include "hdf.h"
 #include "vg.h"
 #include "hfile.h"
+#include "mfhdfi.h"
 
 #define ATTR_TAG  DFTAG_VH
 #define DIM_TAG   DFTAG_VG
@@ -205,29 +222,33 @@ typedef struct {
 	size_t szof ;		/* sizeof each value */
 	long begin ;  /* seek index, often an off_t */
 #ifdef HDF
-	NC *cdf;    /* handle of the file where this var belongs to  */
-	int32 vgid;     /* id of the variable's Vgroup */
-    uint16 data_ref;  /* ref of the variable's data storage (if exists) */
-    uint16 data_tag;  /* tag of the variable's data storage (if exists) */
-    uint16 ndg_ref;   /* ref of ndg for this dataset */
-    intn   data_offset; /* non-traditional data may not begin at 0 */
-    int32  block_size;  /* size of the blocks for unlimited dim. datasets */
-    int numrecs;  /* number of records this has been filled to */
-    int32 aid;    /* aid for DFTAG_SD data */
-    int32 HDFtype; /* type of this variable as HDF thinks */
-    int32 HDFsize; /* size of this variable as HDF thinks */
+	NC *cdf;	/* handle of the file where this var belongs to  */
+	int32 vgid;	/* id of the variable's Vgroup */
+	uint16 data_ref;    /* ref of the variable's data storage (if exists) */
+	uint16 data_tag;    /* tag of the variable's data storage (if exists) */
+	uint16 ndg_ref;     /* ref of ndg for this dataset */
+	hdf_vartype_t var_type; /* IS_SDSVAR == is an SDS variable 
+			       IS_CRDVAR == is a coordinate variable 
+			       UNKNOWN == because the var was created prior to
+					this distinction */
+	intn   data_offset; /* non-traditional data may not begin at 0 */
+	int32  block_size;  /* size of the blocks for unlimited dim. datasets */
+	int numrecs;	/* number of records this has been filled to */
+	int32 aid;	/* aid for DFTAG_SD data */
+	int32 HDFtype;	/* type of this variable as HDF thinks */
+	int32 HDFsize;	/* size of this variable as HDF thinks */
     /* These next two flags control when space in the file is allocated
         for a new dataset.  They are used (currently) in SDwritedata() and
         hdf_get_vp_aid() to allocate the full length of a new fixed-size dataset
         which is not writing fill values, instead of letting them get created
         as an "appendable" dataset and probably get converted into a linked-
         block special element when they don't need to be one */
-    int32   created;    /* BOOLEAN == is newly created */
-    int32   set_length; /* BOOLEAN == needs length set */
-    int32   is_ragged; /* BOOLEAN == is a ragged array */
-    int32 * rag_list;  /* size of ragged array lines */
-    int32   rag_fill;  /* last line in rag_list to be set */
-    vix_t * vixHead;   /* list of VXR records for CDF data storage */
+	int32   created;    /* BOOLEAN == is newly created */
+	int32   set_length; /* BOOLEAN == needs length set */
+	int32   is_ragged;  /* BOOLEAN == is a ragged array */
+	int32 * rag_list;   /* size of ragged array lines */
+	int32   rag_fill;   /* last line in rag_list to be set */
+	vix_t * vixHead;    /* list of VXR records for CDF data storage */
 #endif
 } NC_var ;
 
@@ -261,10 +282,10 @@ extern const char *cdf_routine_name ; /* defined in lerror.c */
 extern "C" {
 #endif
 
-/* If using the real netCDF library and API (use -DHAVE_NETCDF)
+/* If using the real netCDF library and API (when --disable-netcdf configure flag is used)
    need to mangle the HDF versions of netCDF API function names 
    to not conflict w/ oriinal netCDF ones */
-#ifdef HAVE_NETCDF
+#ifndef H4_HAVE_NETCDF
 #define nc_serror        HNAME(nc_serror)
 #define NCadvise         HNAME(NCadvise)
 #define NC_computeshapes HNAME(NC_computeshapes)
@@ -324,7 +345,49 @@ extern "C" {
 #define NCgenio          HNAME(NCgenio)      /* from putgetg.c */
 #define NC_var_shape     HNAME(NC_var_shape) /* from var.c */
 #endif
-#endif /* HAVE_NETCDF ie. NOT USING HDF version of netCDF ncxxx API */
+#endif /* !H4_HAVE_NETCDF ie. NOT USING HDF version of netCDF ncxxx API */
+
+#define nncpopt           H4_F77_FUNC(ncpopt, NCPOPT)
+#define nncgopt           H4_F77_FUNC(ncgopt, NCGOPT)
+#define nnccre            H4_F77_FUNC(nccre, NCCRE)
+#define nncopn            H4_F77_FUNC(ncopn, NCOPN)
+#define nncddef           H4_F77_FUNC(ncddef, NCDDEF)
+#define nncdid            H4_F77_FUNC(ncdid, NCDID)
+#define nncvdef           H4_F77_FUNC(ncvdef, NCVDEF)
+#define nncvid            H4_F77_FUNC(ncvid, NCVID)
+#define nnctlen           H4_F77_FUNC(nctlen, NCTLEN)
+#define nncclos           H4_F77_FUNC(ncclos, NCCLOS)
+#define nncredf           H4_F77_FUNC(ncredf, NCREDF)
+#define nncendf           H4_F77_FUNC(ncendf, NCENDF)
+#define nncinq            H4_F77_FUNC(ncinq, NCINQ)
+#define nncsnc            H4_F77_FUNC(ncsnc, NCSNC)
+#define nncabor           H4_F77_FUNC(ncabor, NCABOR)
+#define nncdinq           H4_F77_FUNC(ncdinq, NCDINQ)
+#define nncdren           H4_F77_FUNC(ncdren, NCDREN)
+#define nncvinq           H4_F77_FUNC(ncvinq, NCVINQ)
+#define nncvpt1           H4_F77_FUNC(ncvpt1, NCVPT1)
+#define nncvp1c           H4_F77_FUNC(ncvp1c, NCVP1C)
+#define nncvpt            H4_F77_FUNC(ncvpt, NCVPT)
+#define nncvptc           H4_F77_FUNC(ncvptc, NCVPTC)
+#define nncvptg           H4_F77_FUNC(ncvptg, NCVPTG)
+#define nncvpgc           H4_F77_FUNC(ncvpgc, NCVPGC)
+#define nncvgt1           H4_F77_FUNC(ncvgt1, NCVGT1)
+#define nncvg1c           H4_F77_FUNC(ncvg1c, NCVG1C)
+#define nncvgt            H4_F77_FUNC(ncvgt, NCVGT)
+#define nncvgtc           H4_F77_FUNC(ncvgtc, NCVGTC)
+#define nncvgtg           H4_F77_FUNC(ncvgtg, NCVGTG)
+#define nncvggc           H4_F77_FUNC(ncvggc, NCVGGC)
+#define nncvren           H4_F77_FUNC(ncvren, NCVREN)
+#define nncapt            H4_F77_FUNC(ncapt, NCAPT)
+#define nncaptc           H4_F77_FUNC(ncaptc, NCAPTC)
+#define nncainq           H4_F77_FUNC(ncainq, NCAINQ)
+#define nncagt            H4_F77_FUNC(ncagt, NCAGT)
+#define nncagtc           H4_F77_FUNC(ncagtc, NCAGTC)
+#define nncacpy           H4_F77_FUNC(ncacpy, NCACPY)
+#define nncanam           H4_F77_FUNC(ncanam, NCANAM)
+#define nncaren           H4_F77_FUNC(ncaren, NCAREN)
+#define nncadel           H4_F77_FUNC(ncadel, NCADEL)
+#define nncsfil           H4_F77_FUNC(ncsfil, NCSFIL)
 
 extern void		nc_serror			PROTO((
 	const char *fmt,
@@ -634,6 +697,18 @@ extern intn NCgenio
 extern intn NC_var_shape
     PROTO((NC_var *var,NC_array *dims));
 
+extern intn NC_reset_maxopenfiles
+    PROTO((intn req_max));
+
+extern intn NC_get_maxopenfiles
+    PROTO(());
+
+extern intn NC_get_systemlimit
+    PROTO(());
+
+extern int NC_get_numopencdfs
+    PROTO(());
+
 /* CDF stuff. don't need anymore? -GV */
 extern nc_type cdf_unmap_type
     PROTO((int type));
