@@ -1,8 +1,20 @@
-/*
- *	Copyright 1993, University Corporation for Atmospheric Research
- *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
- */
-/*	$Id: putget.c,v 1.73 2000/08/29 13:56:53 koziol Exp $ */
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright 1993, University Corporation for Atmospheric Research           *
+ * See netcdf/COPYRIGHT file for copying and redistribution conditions.      *
+ *                                                                           *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+
+/*	$Id: putget.c 5160 2009-01-22 22:55:08Z epourmal $ */
 
 #include	<string.h>
 #include	"local_nc.h"
@@ -64,6 +76,18 @@ const long array[] ;
 
 #define xdr_NCsetpos(xdrs, pos) xdr_setpos((xdrs),(pos))
 
+/*
+ * Check if an ncxxx function has called the current function
+ */
+static bool_t nc_API(caller)
+const char *caller;
+{
+    char *nc_api=NULL;
+    nc_api = strstr(caller, "nc");
+    if (nc_api == caller)
+        return TRUE;
+}
+
 /*
  * At the current position, add a record containing the fill values.
  */
@@ -73,7 +97,7 @@ XDR *xdrs ;
 NC_var **vpp ;
 unsigned numvars ;
 {
-	int ii ;
+	unsigned ii ;
 
 	for(ii = 0 ; ii < numvars ; ii++, vpp++)
 	{
@@ -90,10 +114,18 @@ unsigned numvars ;
 }
 
 
-/* 
+/*
  * Check whether coords are valid for the variable.
- * For 'record' variables add and fill records out
- * to the requested recno == coords[0] as a side effect.
+ * For 'record' variables:
+ *    + if the accessing is writing, add and fill records out with
+ *	user-provided fill values or predefined fill values to the
+ *	requested recno == coords[0], as a side effect.
+ *    + if the accessing is reading, fill records with fill values up
+ *	to the requested recno when an nc API (ie. ncvarget) leads to
+ *	this, and flag as an error when an SD API (ie. SDreaddata) does.
+ *    + update NC_var.numrecs to reflect the filled records
+ *    + update NC.numrecs to NC_var.numrecs if NC_var.numrecs is larger
+ * -BMR, 12/09/2008
  */
 bool_t
 NCcoordck(handle, vp, coords)
@@ -104,10 +136,16 @@ const long *coords ;
 	const long *ip ;
 	unsigned long *up ;
 	const long *boundary ;
-	long unfilled ;
+	long unfilled ;	/* number of records that need to be filled */
 
 	if( IS_RECVAR(vp) )
       {
+      /* For the variable with unlimited dimension we need to check that 
+         the size of the first dimension is non-negative, there is no
+         upper bound for it; the sizes of the rest of the dimensions are 
+         checked as for the regular fixed size variable (see the "for" loop 
+         further down) 
+                                                    EIP 01/13/09    */
           boundary = coords + 1 ;
           if(*coords < 0)
               goto bad ;
@@ -116,6 +154,7 @@ const long *coords ;
 	
 	up = vp->shape + vp->assoc->count - 1 ;
 	ip = coords + vp->assoc->count - 1 ;
+
 #ifdef CDEBUG
 	fprintf(stderr,"	NCcoordck: coords %p, *coords %ld, count %ld, ip %p, boundary %p, *ip %ld\n",
             coords, *coords, vp->assoc->count, ip , boundary, *ip) ;
@@ -126,11 +165,17 @@ const long *coords ;
           fprintf(stderr,"	NCcoordck: ip %p, *ip %ld, up %p, *up %lu\n",
                   ip, *ip, up, *up ) ;
 #endif /* CDEBUG */
-          if( *ip < 0 || *ip >= *up )
+          if( *ip < 0 || *ip >= (long)*up )
               goto bad ;
       }
 
+    /********************************************************************/
+    /* The following block (#ifdef HDF) is for hdf4 API and hdf4/nc API */
+    /********************************************************************/
+
 #ifdef HDF
+    /* If file is an HDF file (ie., not netCDF, created with HDF API or
+	HDF/nc API) and the variable has unlimited dimension */
     if(handle->file_type == HDF_FILE && IS_RECVAR(vp)) 
       {
           void     *strg = NULL;
@@ -139,36 +184,57 @@ const long *coords ;
           int count, byte_count;
           int len;
             
+        /* Determine if fill values need to be written.  For example, if
+           vp's numrecs is 5, and the accessed index is 8 (*ip), then recs
+           #5,6,7 will be filled with fill value.  Note: maybe '<' should be
+	   "<=", but adding it alone caused ill-effects so a through study
+	   is needed, plus '<' doesn't really cause problem, it just meant
+	   when unfilled = 0, we'll fill 0 record below. -BMR, 12/8/2008*/
           if((unfilled = *ip - vp->numrecs) < 0) 
               return TRUE;   
 
 #ifdef CDEBUG
 fprintf(stderr, "NCcoordck: check 3.6, unfilled=%d\n",unfilled);
 #endif /* CDEBUG */
+
+        /* If we get here from an nc API, then reading beyond the end of the
+           current variable will write fill values to the gap between the end
+           of this variable and the max numrecs in the file.  It will only fail
+           for reading beyond the end if the calling function is from the SD
+           API. */
+
           /* check to see if we are trying to read beyond the end */
           if(handle->xdrs->x_op != XDR_ENCODE)
-              goto bad ;
+	  {
+	     if (!nc_API(cdf_routine_name)) /* from an SD API call */
+                  goto bad ; /* cannot read beyong the end of var */
+	     else	/* from an nc API call */
+		if (*ip >= handle->numrecs)
+                  goto bad ; /* only fail if reading pass max numrecs in file */
+	  }
 
-          /* else */
+          /* If NOFILL is not requested, proceed to write fill values */
           if ((handle->flags & NC_NOFILL) == 0) 
             {
-                /* make sure we can write to this sucker */
+                /* make sure we can write to this variable */
                 if(vp->aid == FAIL && hdf_get_vp_aid(handle, vp) == FAIL) 
                     return(FALSE);
             
-                /*
-                 * Set up the array strg to hold the fill values
-                 */
+		/* strg and strg1 are to hold fill value and its conversion */
                 len = (vp->len / vp->HDFsize) * vp->szof;
                 strg = (Void *) HDmalloc(len);
                 strg1 = (Void *) HDmalloc(len);
                 if (NULL == strg || NULL == strg1)
                     return FALSE;
 
+		/* Find the attribute _FillValue to get the user's fill value */
                 attr = NC_findattr(&vp->attrs, _FillValue);
 
+		/* If the attribute is found, fill strg with the fill value */
                 if(attr != NULL)
                     HDmemfill(strg,(*attr)->data->values,vp->szof,(vp->len/vp->HDFsize));
+		/* otherwise, fill strg with predefined fill values such as
+                FILL_SHORT, FILL_BYTE,... */
                 else 
                     NC_arrayfill(strg, len, vp->type);
 
@@ -201,6 +267,7 @@ fprintf(stderr, "NCcoordck: check 3.6, unfilled=%d\n",unfilled);
                 if (FAIL == DFKconvert(strg, strg1, vp->HDFtype, count, DFACC_WRITE, 0, 0))
                     return FALSE;
 
+		/* Write fill value to each record for all "unfilled" records */
                 for(; unfilled >= 0; unfilled--, vp->numrecs++)
                   {
                       if (FAIL == Hwrite(vp->aid, byte_count, (uint8 *) strg1))
@@ -219,7 +286,7 @@ fprintf(stderr, "NCcoordck: check 3.6, unfilled=%d\n",unfilled);
 #ifdef CDEBUG
 fprintf(stderr, "NCcoordck: check 10.0, vp->numrecs=%d\n",vp->numrecs);
 #endif /* CDEBUG */
-        if((*ip + 1) > handle->numrecs) 
+        if((*ip + 1) > (long)(handle->numrecs)) 
           {
               handle->numrecs = *ip + 1;
               handle->flags |= NC_NDIRTY;
@@ -229,8 +296,11 @@ fprintf(stderr, "NCcoordck: check 10.0, vp->numrecs=%d\n",vp->numrecs);
     }
 #endif /* HDF */
 
+    /**********************************************/
+    /* The following block is for netCDF API file */
+    /**********************************************/
 
-	if( IS_RECVAR(vp) && (unfilled = *ip - handle->numrecs) >= 0 )
+    if( IS_RECVAR(vp) && (unfilled = *ip - handle->numrecs) >= 0 )
       {
           /* check to see if we are trying to read beyond the end */
           if(handle->xdrs->x_op != XDR_ENCODE)
@@ -582,7 +652,7 @@ Void *values ;
 	case NC_LONG :
 #if defined _CRAYMPP
 		return( xdr_short(xdrs, (nclong *)values) ) ;
-#elif defined __alpha || (_MIPS_SZLONG == 64) || defined IA64
+#elif defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__ || defined __powerpc64__ 
 		return( xdr_int(xdrs, (nclong *)values) ) ;
 #else
 		return( xdr_long(xdrs, (nclong *)values) ) ;
@@ -845,9 +915,17 @@ NC_var *vp;
               block_size = vp->block_size;
           else 
             { /* try figuring out a good value using some heuristics */
-                block_size = vp->len*BLOCK_MULT;
-                if (block_size > MAX_BLOCK_SIZE)
+		/* User's suggested fix for bug #602 - Apr, 2005 */
+                /* This check avoids overflowing the int32 block_size */
+                /* if the user has a huge value for vp->len */ 
+                if(vp->len > MAX_BLOCK_SIZE)
                     block_size = MAX_BLOCK_SIZE;
+                else
+                  {
+                    block_size = vp->len*BLOCK_MULT;
+                    if (block_size > MAX_BLOCK_SIZE)
+                        block_size = MAX_BLOCK_SIZE;
+                  }
             } /* end else */
 
           vp->aid = HLcreate(handle->hdf_file, DATA_TAG, vsid, block_size,
@@ -1669,29 +1747,6 @@ nssdc_xdr_NCvdata(NC *handle,
     fprintf(stderr, "\tbyte_count %d   vp->HDFsize %d\n", byte_count, vp->HDFsize);
 #endif
 
-#ifdef QAK
-    /* Read or write the data into / from values */
-    if(handle->xdrs->x_op == XDR_DECODE) {
-        status = HI_READ((hdf_file_t) handle->cdf_fp, tBuf, byte_count);
-        if(status == FAIL) return FALSE;
-        
-        /* convert tBuf into values */
-        DFKnumin(tBuf, values, (uint32) count, 0, 0);
-        
-    } else {
-
-#ifdef CDF_WRITE      
-        /*  convert values into tBuf */
-        DFKnumout(values, tBuf, (uint32) count, 0, 0);
-        
-        status = Hwrite(vp->aid, byte_count, tBuf);
-        if(status != byte_count) return FALSE;
-#endif /* CDF_WRITE */
-
-    }
-#endif /* QAK */
-    
-
 #ifdef DEBUG
     fprintf(stderr, " * * * Done with call to nssdc_xdr_NCvdata * * *\n");
 #endif
@@ -1899,7 +1954,7 @@ Void *values ;
 	case NC_LONG :
 #if defined _CRAYMPP
                 xdr_NC_fnct = xdr_short;
-#elif defined __alpha || (_MIPS_SZLONG == 64) || defined IA64
+#elif defined __alpha || (_MIPS_SZLONG == 64) || defined __ia64 || (defined __sun && defined _LP64) || defined AIX5L64 || defined __x86_64__ || defined __powerpc64__
 		xdr_NC_fnct = xdr_int ;
 #else
 		xdr_NC_fnct = xdr_long ;
@@ -1977,8 +2032,9 @@ const long *edges ;
      *  regular dimensions of an unlimited dimension dataset are being written
      *  out, it's ok to write out a "block" of all those slices at once. -QAK
      */
-	if( IS_RECVAR(vp) && (edp-1==edges) && !partial)
+/*	if( IS_RECVAR(vp) && (edp-1==edges) && !partial)
         edp=edges;
+*/
 
 	/* shp, edp reference last index s.t. shape[ii] == edge[ii] */
 	return(edp) ;
@@ -2006,8 +2062,12 @@ Void *values ;
           return -1 ;
       }
 
-	/* check to see if we are trying to read beyond the end */
-	newrecs = (*start + *edges) - handle->numrecs ;
+        /* check to see if we are trying to read beyond the end;
+           Modification: (BMR - 11/10/2006) - replaced "handle->numrecs"
+           with "vp->numrecs" to fix bug 525, ie. writing two unlimited
+           1D datasets without closing the file in between the two writes
+           caused the second dataset to contain garbage. */
+	newrecs = (*start + *edges) - vp->numrecs ;
 	if(handle->xdrs->x_op != XDR_ENCODE && newrecs > 0)
       {
           NCadvise(NC_EINVALCOORDS, "%s: Invalid Coordinates",
@@ -2059,8 +2119,10 @@ Void *values ;
 #ifdef HDF
 	if(newrecs > 0)
       {
-          handle->numrecs += newrecs ;
+	/* Update var's numrecs first and then handle->numrecs if the first
+	   exceeds the latter (part of bugzilla 1378) - BMR, 12/30/2008 */
 	  vp->numrecs += newrecs;
+	  handle->numrecs = MAX(vp->numrecs, handle->numrecs);
           if(handle->flags & NC_NSYNC) /* write out header->numrecs NOW */
             {
                 if(!xdr_numrecs(handle->xdrs, handle) )
@@ -2163,7 +2225,7 @@ void *values ;
 	/* now edp = edp0 - 1 */
 
 	{ /* inline */
-        long  coords[MAX_VAR_DIMS], upper[MAX_VAR_DIMS];
+        long  coords[H4_MAX_VAR_DIMS], upper[H4_MAX_VAR_DIMS];
         long  *cc ;
         const long *mm ;
         u_long offset ;
@@ -2418,7 +2480,7 @@ long *recsizes ;
 {
 	NC *handle ;
 	int nrvars ;
-	NC_var *rvp[MAX_NC_VARS] ; 
+	NC_var *rvp[H4_MAX_NC_VARS] ; 
 
 	cdf_routine_name = "ncrecinq" ;
 
@@ -2452,9 +2514,9 @@ long recnum ;
 Void **datap ;
 {
 	int nrvars ;
-	NC_var *rvp[MAX_NC_VARS] ; 
+	NC_var *rvp[H4_MAX_NC_VARS] ; 
 	int ii ;
-	long coords[MAX_VAR_DIMS];
+	long coords[H4_MAX_VAR_DIMS];
 	u_long offset ;
 	unsigned iocount ;
 
