@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Id: generate.c,v 1.10 1998/12/08 21:38:02 koziol Exp $
+ *   $Id: generate.c 4998 2007-11-16 03:14:03Z epourmal $
  *********************************************************************/
 
 #include <stdio.h>
@@ -28,8 +28,8 @@ gen_netcdf(filename)
 {
     int idim, ivar, iatt;
     int istat;
-    int dimids[MAX_NC_DIMS];
-    int varids[MAX_NC_VARS];
+    int dimids[H4_MAX_NC_DIMS];
+    int varids[H4_MAX_NC_VARS];
 
     ncid = nccreate (filename, NC_CLOBBER);
 
@@ -95,13 +95,19 @@ gen_c(filename)
     int scalar_atts, vector_atts;
     char *val_string;
     char stmnt[C_MAX_STMNT];
-    char s2[MAX_NC_NAME + 2];
+    char s2[H4_MAX_NC_NAME + 2];
 
     static const char *ctypes[] = {"char","short","nclong","float","double"};
     int ntypes = (sizeof ctypes) / (sizeof ctypes[0]);
 
     /* wrap in main program */
+    cline("#include \"h4config.h\"");
+    cline("#ifdef H4_HAVE_NETCDF");
     cline("#include \"netcdf.h\"");
+    cline("#else");
+    cline("#include \"hdf4_netcdf.h\"");
+    cline("#endif");
+/*    cline("#include \"netcdf.h\""); */
     cline("");
     cline("int");
     sprintf(stmnt, "main() {\t\t\t/* create %s */", filename);
@@ -383,7 +389,7 @@ gen_fortran(filename)
     int vector_atts;
     char *val_string;
     char stmnt[FORT_MAX_STMNT];
-    char s2[MAX_NC_NAME + 2];
+    char s2[H4_MAX_NC_NAME + 2];
     /* Need how many netCDF types there are, because we create an array
      * for each type of attribute. */
     int ntypes = 6;		/* number of netCDF types, NC_BYTE, ... */
